type token =
  | IDENT of (string * Cabs.cabsloc)
  | QUALIFIER of (string * Cabs.cabsloc)
  | CST_CHAR of (int64 list * Cabs.cabsloc)
  | CST_WCHAR of (int64 list * Cabs.cabsloc)
  | CST_INT of (string * Cabs.cabsloc)
  | CST_FLOAT of (string * Cabs.cabsloc)
  | NAMED_TYPE of (string * Cabs.cabsloc)
  | CST_STRING of (int64 list * Cabs.cabsloc)
  | CST_WSTRING of (int64 list * Cabs.cabsloc)
  | EOF
  | CHAR of (Cabs.cabsloc)
  | INT of (Cabs.cabsloc)
  | BOOL of (Cabs.cabsloc)
  | DOUBLE of (Cabs.cabsloc)
  | FLOAT of (Cabs.cabsloc)
  | VOID of (Cabs.cabsloc)
  | INT64 of (Cabs.cabsloc)
  | INT32 of (Cabs.cabsloc)
  | ENUM of (Cabs.cabsloc)
  | STRUCT of (Cabs.cabsloc)
  | TYPEDEF of (Cabs.cabsloc)
  | UNION of (Cabs.cabsloc)
  | SIGNED of (Cabs.cabsloc)
  | UNSIGNED of (Cabs.cabsloc)
  | LONG of (Cabs.cabsloc)
  | SHORT of (Cabs.cabsloc)
  | VOLATILE of (Cabs.cabsloc)
  | EXTERN of (Cabs.cabsloc)
  | STATIC of (Cabs.cabsloc)
  | CONST of (Cabs.cabsloc)
  | RESTRICT of (Cabs.cabsloc)
  | AUTO of (Cabs.cabsloc)
  | REGISTER of (Cabs.cabsloc)
  | UNIFORM of (Cabs.cabsloc)
  | IN of (Cabs.cabsloc)
  | OUT of (Cabs.cabsloc)
  | THREAD of (Cabs.cabsloc)
  | SIZEOF of (Cabs.cabsloc)
  | ALIGNOF of (Cabs.cabsloc)
  | EQ
  | PLUS_EQ
  | MINUS_EQ
  | STAR_EQ
  | SLASH_EQ
  | PERCENT_EQ
  | AND_EQ
  | PIPE_EQ
  | CIRC_EQ
  | INF_INF_EQ
  | SUP_SUP_EQ
  | ARROW
  | DOT
  | EQ_EQ
  | EXCLAM_EQ
  | INF
  | SUP
  | INF_EQ
  | SUP_EQ
  | PLUS of (Cabs.cabsloc)
  | MINUS of (Cabs.cabsloc)
  | STAR of (Cabs.cabsloc)
  | SLASH
  | PERCENT
  | TILDE of (Cabs.cabsloc)
  | AND of (Cabs.cabsloc)
  | PIPE
  | CIRC
  | EXCLAM of (Cabs.cabsloc)
  | AND_AND of (Cabs.cabsloc)
  | PIPE_PIPE
  | INF_INF
  | SUP_SUP
  | PLUS_PLUS of (Cabs.cabsloc)
  | MINUS_MINUS of (Cabs.cabsloc)
  | RPAREN
  | LPAREN of (Cabs.cabsloc)
  | RBRACE of (Cabs.cabsloc)
  | LBRACE of (Cabs.cabsloc)
  | LBRACKET
  | RBRACKET
  | COLON
  | SEMICOLON of (Cabs.cabsloc)
  | COMMA
  | ELLIPSIS
  | QUEST
  | BREAK of (Cabs.cabsloc)
  | CONTINUE of (Cabs.cabsloc)
  | GOTO of (Cabs.cabsloc)
  | RETURN of (Cabs.cabsloc)
  | SWITCH of (Cabs.cabsloc)
  | CASE of (Cabs.cabsloc)
  | DEFAULT of (Cabs.cabsloc)
  | WHILE of (Cabs.cabsloc)
  | DO of (Cabs.cabsloc)
  | FOR of (Cabs.cabsloc)
  | IF of (Cabs.cabsloc)
  | TRY of (Cabs.cabsloc)
  | EXCEPT of (Cabs.cabsloc)
  | FINALLY of (Cabs.cabsloc)
  | ELSE
  | ATTRIBUTE of (Cabs.cabsloc)
  | INLINE of (Cabs.cabsloc)
  | ASM of (Cabs.cabsloc)
  | TYPEOF of (Cabs.cabsloc)
  | FUNCTION__ of (Cabs.cabsloc)
  | PRETTY_FUNCTION__ of (Cabs.cabsloc)
  | LABEL__
  | BUILTIN_VA_ARG of (Cabs.cabsloc)
  | ATTRIBUTE_USED of (Cabs.cabsloc)
  | BUILTIN_VA_LIST
  | BLOCKATTRIBUTE
  | BUILTIN_TYPES_COMPAT of (Cabs.cabsloc)
  | BUILTIN_OFFSETOF of (Cabs.cabsloc)
  | DECLSPEC of (Cabs.cabsloc)
  | MSASM of (string * Cabs.cabsloc)
  | MSATTR of (string * Cabs.cabsloc)
  | PRAGMA_LINE of (string * Cabs.cabsloc)
  | PRAGMA of (Cabs.cabsloc)
  | PRAGMA_EOL
  | AT_TRANSFORM of (Cabs.cabsloc)
  | AT_TRANSFORMEXPR of (Cabs.cabsloc)
  | AT_SPECIFIER of (Cabs.cabsloc)
  | AT_EXPR of (Cabs.cabsloc)
  | AT_NAME

open Parsing;;
# 44 "src/frontc/cparser.mly"
open Cabs
open Cabshelper
module E = Errormsg

let parse_error msg : unit =       (* sm: c++-mode highlight hack: -> ' <- *)
  E.parse_error msg

let print = print_string

(* unit -> string option *)
(*
let getComments () =
  match !comments with
    [] -> None
  | _ -> 
      let r = Some(String.concat "\n" (List.rev !comments)) in
      comments := [];
      r
*)

let cabslu = {lineno = -10; 
	      filename = "cabs loc unknown"; 
	      byteno = -10;
              ident = 0;}

(* cabsloc -> cabsloc *)
(*
let handleLoc l =
  l.clcomment <- getComments();
  l
*)

(*
** Expression building
*)
let smooth_expression lst =
  match lst with
    [] -> NOTHING
  | [expr] -> expr
  | _ -> COMMA (lst)


let currentFunctionName = ref "<outside any function>"
    
let announceFunctionName ((n, decl, _, _):name) =
  !Lexerhack.add_identifier n;
  (* Start a context that includes the parameter names and the whole body. 
   * Will pop when we finish parsing the function body *)
  !Lexerhack.push_context ();
  (* Go through all the parameter names and mark them as identifiers *)
  let rec findProto = function
      PROTO (d, args, _) when isJUSTBASE d -> 
        List.iter (fun (_, (an, _, _, _)) -> !Lexerhack.add_identifier an) args

    | PROTO (d, _, _) -> findProto d
    | PARENTYPE (_, d, _) -> findProto d
    | PTR (_, d) -> findProto d
    | ARRAY (d, _, _) -> findProto d
    | _ -> parse_error "Cannot find the prototype in a function definition";
           raise Parsing.Parse_error 

  and isJUSTBASE = function
      JUSTBASE -> true
    | PARENTYPE (_, d, _) -> isJUSTBASE d
    | _ -> false
  in
  findProto decl;
  currentFunctionName := n



let applyPointer (ptspecs: attribute list list) (dt: decl_type)  
       : decl_type = 
  (* Outer specification first *)
  let rec loop = function
      [] -> dt
    | attrs :: rest -> PTR(attrs, loop rest)
  in
  loop ptspecs

let doDeclaration (loc: cabsloc) (specs: spec_elem list) (nl: init_name list) : definition = 
  if isTypedef specs then begin
    (* Tell the lexer about the new type names *)
    List.iter (fun ((n, _, _, _), _) -> !Lexerhack.add_type n) nl;
    TYPEDEF ((specs, List.map (fun (n, _) -> n) nl), loc)
  end else
    if nl = [] then
      ONLYTYPEDEF (specs, loc)
    else begin
      (* Tell the lexer about the new variable names *)
      List.iter (fun ((n, _, _, _), _) -> !Lexerhack.add_identifier n) nl;
      DECDEF ((specs, nl), loc)  
    end


let doFunctionDef (loc: cabsloc)
                  (lend: cabsloc)
                  (specs: spec_elem list) 
                  (n: name) 
                  (b: block) : definition = 
  let fname = (specs, n) in
  FUNDEF (fname, b, loc, lend)


let doOldParDecl (names: string list)
                 ((pardefs: name_group list), (isva: bool)) 
    : single_name list * bool =
  let findOneName n =
    (* Search in pardefs for the definition for this parameter *)
    let rec loopGroups = function
        [] -> ([SpecType Tint], (n, JUSTBASE, [], cabslu))
      | (specs, names) :: restgroups ->
          let rec loopNames = function
              [] -> loopGroups restgroups
            | ((n',_, _, _) as sn) :: _ when n' = n -> (specs, sn)
            | _ :: restnames -> loopNames restnames
          in
          loopNames names
    in
    loopGroups pardefs
  in
  let args = List.map findOneName names in
  (args, isva)

let checkConnective (s : string) : unit =
begin
  (* checking this means I could possibly have more connectives, with *)
  (* different meaning *)
  if (s <> "to") then (
    parse_error "transformer connective must be 'to'";
    raise Parsing.Parse_error
  )
  else ()
end

let int64_to_char value =
  if (compare value (Int64.of_int 255) > 0) || (compare value Int64.zero < 0) then
    begin
      let msg = Printf.sprintf "cparser:intlist_to_string: character 0x%Lx too big" value in
      parse_error msg;
      raise Parsing.Parse_error
    end
  else
    Char.chr (Int64.to_int value)

(* takes a not-nul-terminated list, and converts it to a string. *)
let rec intlist_to_string (str: int64 list):string =
  match str with
    [] -> ""  (* add nul-termination *)
  | value::rest ->
      let this_char = int64_to_char value in
      (String.make 1 this_char) ^ (intlist_to_string rest)

let fst3 (result, _, _) = result
let snd3 (_, result, _) = result
let trd3 (_, _, result) = result


(*
   transform:  __builtin_offsetof(type, member)
   into     :  (size_t) (&(type * ) 0)->member
 *)

let transformOffsetOf (speclist, dtype) member =
  let rec addPointer = function
    | JUSTBASE ->
	PTR([], JUSTBASE)
    | PARENTYPE (attrs1, dtype, attrs2) ->
	PARENTYPE (attrs1, addPointer dtype, attrs2)
    | ARRAY (dtype, attrs, expr) ->
	ARRAY (addPointer dtype, attrs, expr)
    | PTR (attrs, dtype) ->
	PTR (attrs, addPointer dtype)
    | PROTO (dtype, names, variadic) ->
	PROTO (addPointer dtype, names, variadic)
  in
  let nullType = (speclist, addPointer dtype) in
  let nullExpr = CONSTANT (CONST_INT "0") in
  let castExpr = CAST (nullType, SINGLE_INIT nullExpr) in

  let rec replaceBase = function
    | VARIABLE field ->
	MEMBEROFPTR (castExpr, field)
    | MEMBEROF (base, field) ->
	MEMBEROF (replaceBase base, field)
    | INDEX (base, index) ->
	INDEX (replaceBase base, index)
    | _ ->
	parse_error "malformed offset expression in __builtin_offsetof";
        raise Parsing.Parse_error 
  in
  let memberExpr = replaceBase member in
  let addrExpr = UNARY (ADDROF, memberExpr) in
  (* slight cheat: hard-coded assumption that size_t == unsigned int *)
  let sizeofType = [SpecType Tunsigned], JUSTBASE in
  let resultExpr = CAST (sizeofType, SINGLE_INIT addrExpr) in
  resultExpr

# 328 "src/frontc/cparser.ml"
let yytransl_const = [|
    0 (* EOF *);
  295 (* EQ *);
  296 (* PLUS_EQ *);
  297 (* MINUS_EQ *);
  298 (* STAR_EQ *);
  299 (* SLASH_EQ *);
  300 (* PERCENT_EQ *);
  301 (* AND_EQ *);
  302 (* PIPE_EQ *);
  303 (* CIRC_EQ *);
  304 (* INF_INF_EQ *);
  305 (* SUP_SUP_EQ *);
  306 (* ARROW *);
  307 (* DOT *);
  308 (* EQ_EQ *);
  309 (* EXCLAM_EQ *);
  310 (* INF *);
  311 (* SUP *);
  312 (* INF_EQ *);
  313 (* SUP_EQ *);
  317 (* SLASH *);
  318 (* PERCENT *);
  321 (* PIPE *);
  322 (* CIRC *);
  325 (* PIPE_PIPE *);
  326 (* INF_INF *);
  327 (* SUP_SUP *);
  330 (* RPAREN *);
  334 (* LBRACKET *);
  335 (* RBRACKET *);
  336 (* COLON *);
  338 (* COMMA *);
  339 (* ELLIPSIS *);
  340 (* QUEST *);
  355 (* ELSE *);
  362 (* LABEL__ *);
  365 (* BUILTIN_VA_LIST *);
  366 (* BLOCKATTRIBUTE *);
  374 (* PRAGMA_EOL *);
  379 (* AT_NAME *);
    0|]

let yytransl_block = [|
  257 (* IDENT *);
  258 (* QUALIFIER *);
  259 (* CST_CHAR *);
  260 (* CST_WCHAR *);
  261 (* CST_INT *);
  262 (* CST_FLOAT *);
  263 (* NAMED_TYPE *);
  264 (* CST_STRING *);
  265 (* CST_WSTRING *);
  266 (* CHAR *);
  267 (* INT *);
  268 (* BOOL *);
  269 (* DOUBLE *);
  270 (* FLOAT *);
  271 (* VOID *);
  272 (* INT64 *);
  273 (* INT32 *);
  274 (* ENUM *);
  275 (* STRUCT *);
  276 (* TYPEDEF *);
  277 (* UNION *);
  278 (* SIGNED *);
  279 (* UNSIGNED *);
  280 (* LONG *);
  281 (* SHORT *);
  282 (* VOLATILE *);
  283 (* EXTERN *);
  284 (* STATIC *);
  285 (* CONST *);
  286 (* RESTRICT *);
  287 (* AUTO *);
  288 (* REGISTER *);
  289 (* UNIFORM *);
  290 (* IN *);
  291 (* OUT *);
  292 (* THREAD *);
  293 (* SIZEOF *);
  294 (* ALIGNOF *);
  314 (* PLUS *);
  315 (* MINUS *);
  316 (* STAR *);
  319 (* TILDE *);
  320 (* AND *);
  323 (* EXCLAM *);
  324 (* AND_AND *);
  328 (* PLUS_PLUS *);
  329 (* MINUS_MINUS *);
  331 (* LPAREN *);
  332 (* RBRACE *);
  333 (* LBRACE *);
  337 (* SEMICOLON *);
  341 (* BREAK *);
  342 (* CONTINUE *);
  343 (* GOTO *);
  344 (* RETURN *);
  345 (* SWITCH *);
  346 (* CASE *);
  347 (* DEFAULT *);
  348 (* WHILE *);
  349 (* DO *);
  350 (* FOR *);
  351 (* IF *);
  352 (* TRY *);
  353 (* EXCEPT *);
  354 (* FINALLY *);
  356 (* ATTRIBUTE *);
  357 (* INLINE *);
  358 (* ASM *);
  359 (* TYPEOF *);
  360 (* FUNCTION__ *);
  361 (* PRETTY_FUNCTION__ *);
  363 (* BUILTIN_VA_ARG *);
  364 (* ATTRIBUTE_USED *);
  367 (* BUILTIN_TYPES_COMPAT *);
  368 (* BUILTIN_OFFSETOF *);
  369 (* DECLSPEC *);
  370 (* MSASM *);
  371 (* MSATTR *);
  372 (* PRAGMA_LINE *);
  373 (* PRAGMA *);
  375 (* AT_TRANSFORM *);
  376 (* AT_TRANSFORMEXPR *);
  377 (* AT_SPECIFIER *);
  378 (* AT_EXPR *);
    0|]

let yylhs = "\255\255\
\001\000\002\000\003\000\003\000\003\000\051\000\004\000\004\000\
\004\000\004\000\004\000\004\000\004\000\004\000\004\000\004\000\
\004\000\055\000\055\000\055\000\056\000\056\000\057\000\057\000\
\057\000\057\000\057\000\058\000\058\000\058\000\058\000\058\000\
\058\000\058\000\058\000\058\000\058\000\058\000\059\000\059\000\
\059\000\061\000\061\000\061\000\061\000\061\000\061\000\061\000\
\061\000\061\000\061\000\061\000\061\000\061\000\061\000\062\000\
\062\000\063\000\063\000\063\000\063\000\064\000\064\000\064\000\
\065\000\065\000\065\000\066\000\066\000\066\000\066\000\066\000\
\067\000\067\000\067\000\068\000\068\000\069\000\069\000\070\000\
\070\000\071\000\071\000\072\000\072\000\073\000\073\000\074\000\
\074\000\074\000\074\000\074\000\074\000\074\000\074\000\074\000\
\074\000\074\000\074\000\011\000\009\000\009\000\009\000\009\000\
\009\000\009\000\010\000\075\000\018\000\018\000\019\000\019\000\
\019\000\076\000\076\000\076\000\013\000\013\000\021\000\021\000\
\060\000\060\000\020\000\020\000\020\000\077\000\077\000\022\000\
\022\000\022\000\023\000\023\000\078\000\016\000\016\000\012\000\
\012\000\014\000\014\000\014\000\079\000\079\000\015\000\015\000\
\017\000\017\000\035\000\035\000\080\000\081\000\081\000\036\000\
\036\000\036\000\036\000\036\000\037\000\037\000\038\000\038\000\
\008\000\008\000\008\000\008\000\008\000\008\000\008\000\008\000\
\008\000\008\000\008\000\008\000\008\000\008\000\008\000\008\000\
\008\000\008\000\008\000\008\000\008\000\008\000\008\000\008\000\
\083\000\083\000\031\000\031\000\041\000\041\000\040\000\040\000\
\024\000\024\000\024\000\024\000\024\000\024\000\024\000\024\000\
\024\000\024\000\087\000\087\000\088\000\088\000\025\000\025\000\
\025\000\025\000\025\000\025\000\025\000\025\000\025\000\025\000\
\025\000\025\000\025\000\025\000\025\000\025\000\025\000\025\000\
\025\000\025\000\025\000\025\000\025\000\025\000\025\000\025\000\
\025\000\025\000\025\000\025\000\026\000\026\000\026\000\026\000\
\026\000\026\000\044\000\044\000\043\000\043\000\043\000\030\000\
\030\000\030\000\029\000\029\000\042\000\045\000\045\000\045\000\
\045\000\045\000\091\000\092\000\092\000\093\000\093\000\093\000\
\028\000\028\000\028\000\028\000\027\000\094\000\094\000\039\000\
\039\000\054\000\054\000\054\000\095\000\095\000\095\000\049\000\
\050\000\050\000\034\000\034\000\048\000\048\000\046\000\046\000\
\046\000\046\000\047\000\047\000\032\000\033\000\033\000\033\000\
\033\000\033\000\052\000\052\000\052\000\052\000\052\000\052\000\
\005\000\005\000\006\000\006\000\006\000\089\000\089\000\089\000\
\089\000\089\000\084\000\084\000\096\000\096\000\096\000\096\000\
\096\000\098\000\098\000\090\000\090\000\053\000\053\000\053\000\
\100\000\100\000\100\000\100\000\100\000\100\000\100\000\100\000\
\100\000\100\000\100\000\101\000\101\000\101\000\101\000\101\000\
\101\000\102\000\102\000\102\000\102\000\102\000\102\000\102\000\
\102\000\102\000\102\000\102\000\103\000\104\000\104\000\104\000\
\104\000\105\000\105\000\105\000\106\000\106\000\106\000\107\000\
\107\000\107\000\107\000\107\000\108\000\108\000\108\000\109\000\
\109\000\110\000\110\000\111\000\111\000\112\000\112\000\113\000\
\113\000\114\000\114\000\099\000\115\000\115\000\115\000\116\000\
\116\000\082\000\082\000\097\000\097\000\007\000\007\000\007\000\
\085\000\085\000\086\000\086\000\117\000\117\000\119\000\119\000\
\120\000\120\000\118\000\118\000\121\000\121\000\122\000\122\000\
\123\000\123\000\000\000\000\000"

let yylen = "\002\000\
\002\000\001\000\000\000\002\000\002\000\000\000\001\000\001\000\
\003\000\005\000\005\000\001\000\006\000\004\000\008\000\008\000\
\003\000\001\000\001\000\004\000\000\000\001\000\001\000\001\000\
\001\000\003\000\004\000\001\000\002\000\004\000\006\000\006\000\
\006\000\003\000\003\000\002\000\002\000\006\000\001\000\003\000\
\002\000\001\000\002\000\002\000\002\000\004\000\002\000\004\000\
\002\000\002\000\002\000\002\000\002\000\002\000\002\000\001\000\
\004\000\001\000\003\000\003\000\003\000\001\000\003\000\003\000\
\001\000\003\000\003\000\001\000\003\000\003\000\003\000\003\000\
\001\000\003\000\003\000\001\000\003\000\001\000\003\000\001\000\
\003\000\001\000\003\000\001\000\003\000\001\000\005\000\001\000\
\003\000\003\000\003\000\003\000\003\000\003\000\003\000\003\000\
\003\000\003\000\003\000\001\000\001\000\001\000\001\000\001\000\
\001\000\001\000\001\000\001\000\001\000\002\000\001\000\002\000\
\002\000\001\000\001\000\001\000\001\000\003\000\001\000\003\000\
\000\000\001\000\003\000\002\000\001\000\001\000\000\000\003\000\
\004\000\005\000\000\000\001\000\002\000\000\000\001\000\000\000\
\001\000\001\000\003\000\003\000\000\000\001\000\003\000\003\000\
\003\000\003\000\005\000\003\000\001\000\000\000\002\000\000\000\
\002\000\002\000\002\000\002\000\000\000\004\000\001\000\003\000\
\001\000\002\000\001\000\003\000\005\000\003\000\003\000\005\000\
\008\000\004\000\004\000\006\000\002\000\002\000\003\000\002\000\
\002\000\003\000\004\000\007\000\001\000\005\000\004\000\003\000\
\002\000\001\000\003\000\002\000\001\000\003\000\001\000\003\000\
\002\000\002\000\002\000\002\000\002\000\002\000\002\000\002\000\
\002\000\004\000\000\000\001\000\000\000\001\000\001\000\001\000\
\001\000\001\000\001\000\001\000\001\000\001\000\001\000\001\000\
\001\000\002\000\003\000\005\000\004\000\006\000\005\000\002\000\
\005\000\004\000\006\000\005\000\002\000\006\000\005\000\007\000\
\006\000\001\000\004\000\004\000\000\000\003\000\002\000\004\000\
\002\000\003\000\001\000\003\000\001\000\004\000\002\000\001\000\
\003\000\003\000\001\000\003\000\003\000\001\000\004\000\005\000\
\005\000\004\000\001\000\000\000\002\000\000\000\002\000\003\000\
\002\000\002\000\001\000\003\000\002\000\005\000\003\000\001\000\
\003\000\000\000\004\000\004\000\001\000\003\000\001\000\003\000\
\000\000\001\000\002\000\001\000\003\000\001\000\004\000\003\000\
\004\000\004\000\001\000\000\000\002\000\002\000\002\000\004\000\
\005\000\003\000\001\000\001\000\001\000\001\000\001\000\001\000\
\000\000\002\000\000\000\002\000\005\000\004\000\002\000\001\000\
\001\000\001\000\000\000\002\000\001\000\002\000\001\000\001\000\
\001\000\004\000\002\000\001\000\002\000\003\000\004\000\001\000\
\001\000\001\000\003\000\002\000\001\000\001\000\001\000\003\000\
\003\000\003\000\001\000\001\000\003\000\002\000\003\000\003\000\
\004\000\001\000\002\000\004\000\002\000\004\000\002\000\002\000\
\002\000\002\000\002\000\002\000\001\000\001\000\003\000\003\000\
\003\000\001\000\003\000\003\000\001\000\003\000\003\000\001\000\
\003\000\003\000\003\000\003\000\001\000\003\000\003\000\001\000\
\003\000\001\000\003\000\001\000\003\000\001\000\003\000\001\000\
\003\000\001\000\005\000\001\000\001\000\003\000\003\000\000\000\
\001\000\003\000\003\000\003\000\003\000\000\000\002\000\002\000\
\001\000\002\000\000\000\003\000\000\000\001\000\001\000\003\000\
\005\000\005\000\000\000\003\000\000\000\003\000\000\000\002\000\
\001\000\003\000\002\000\002\000"

let yydefred = "\000\000\
\000\000\000\000\000\000\000\000\058\001\234\000\208\000\211\000\
\209\000\215\000\214\000\207\000\213\000\000\000\000\000\000\000\
\000\000\216\000\217\000\212\000\210\000\047\001\000\000\000\000\
\043\001\048\001\000\000\000\000\044\001\045\001\046\001\057\001\
\000\000\000\000\000\000\000\000\000\000\000\000\056\001\072\001\
\000\000\000\000\000\000\000\000\163\001\000\000\002\000\000\000\
\000\000\000\000\007\000\008\000\000\000\000\000\000\000\012\000\
\000\000\164\001\000\000\000\000\018\000\019\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\204\000\193\000\000\000\000\000\000\000\114\000\115\000\
\116\000\000\000\000\000\109\000\194\000\195\000\196\000\197\000\
\005\000\000\000\199\000\000\000\000\000\000\000\055\001\000\000\
\000\000\074\001\083\001\079\001\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\078\001\000\000\
\084\001\000\000\101\001\102\001\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\132\001\000\000\
\000\000\000\000\001\000\004\000\000\000\188\000\039\001\000\000\
\000\000\000\000\026\001\000\000\206\000\198\000\006\000\149\000\
\037\001\000\000\000\000\200\000\201\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\248\000\000\000\000\000\
\067\001\000\000\000\000\000\000\000\000\069\001\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\009\000\110\000\000\000\000\000\
\000\000\023\000\103\000\104\000\101\000\102\000\111\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\024\000\
\105\000\000\000\025\000\000\000\000\000\000\000\028\000\000\000\
\056\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\088\000\100\000\000\000\000\000\
\000\000\076\001\000\000\000\000\086\001\000\000\000\000\091\001\
\000\000\093\001\095\001\096\001\097\001\100\001\098\001\099\001\
\000\000\000\000\000\000\070\001\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\065\001\063\001\064\001\
\000\000\000\000\061\001\000\000\000\000\187\000\000\000\000\000\
\000\000\254\000\013\001\000\000\000\000\000\000\017\000\000\000\
\014\000\000\000\000\000\009\001\010\001\000\000\000\000\000\000\
\005\001\040\001\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\239\000\000\000\000\000\000\000\000\000\
\000\000\000\000\221\000\241\000\000\000\000\000\000\000\226\000\
\000\000\000\000\000\000\000\000\000\000\000\000\137\001\000\000\
\054\001\000\000\000\000\045\000\000\000\047\000\049\000\050\000\
\051\000\054\000\052\000\053\000\055\000\000\000\043\000\044\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\235\000\113\000\112\000\027\001\000\000\236\000\000\000\
\000\000\036\000\037\000\000\000\000\000\029\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\139\001\000\000\000\000\138\001\
\085\001\080\001\081\001\000\000\000\000\075\001\082\001\071\001\
\087\001\088\001\000\000\103\001\104\001\105\001\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\202\000\062\001\024\001\050\001\190\000\000\000\117\000\192\000\
\000\000\000\000\000\000\000\000\253\000\000\000\000\000\148\000\
\000\000\000\000\000\000\000\000\017\001\000\000\000\000\012\001\
\000\000\000\000\000\000\000\000\007\001\000\000\252\000\250\000\
\249\000\231\000\066\001\020\000\000\000\000\000\000\000\242\000\
\247\000\238\000\000\000\000\000\000\000\220\000\223\000\000\000\
\225\000\228\000\000\000\010\000\141\001\140\001\011\000\000\000\
\000\000\000\000\144\000\000\000\000\000\143\000\000\000\026\000\
\000\000\000\000\000\000\000\000\000\000\035\000\034\000\000\000\
\135\000\000\000\000\000\000\000\089\000\090\000\091\000\092\000\
\093\000\094\000\095\000\096\000\097\000\098\000\099\000\059\000\
\060\000\061\000\058\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\137\000\000\000\135\001\134\001\000\000\
\000\000\089\001\000\000\000\000\000\000\000\000\000\000\000\000\
\125\000\000\000\122\000\000\000\000\000\000\000\000\000\000\000\
\015\001\000\000\000\000\000\000\000\000\052\001\000\000\000\000\
\151\000\000\000\000\000\161\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\181\000\000\000\000\000\000\000\163\000\000\000\000\000\
\023\001\000\000\000\000\013\000\000\000\000\000\003\001\029\001\
\000\000\000\000\008\001\230\000\233\000\000\000\000\000\244\000\
\240\000\222\000\227\000\000\000\000\000\000\000\140\000\139\000\
\000\000\057\000\000\000\000\000\000\000\027\000\000\000\030\000\
\146\000\145\000\000\000\131\001\000\000\000\000\000\000\000\000\
\000\000\126\000\000\000\133\000\118\000\124\000\255\000\000\000\
\000\000\142\000\000\000\000\000\002\001\160\000\158\000\000\000\
\000\000\176\000\177\000\000\000\000\000\174\000\000\000\000\000\
\000\000\000\000\173\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\154\000\162\000\153\000\147\000\
\156\000\000\000\000\000\032\001\000\000\000\000\000\000\232\000\
\246\000\000\000\000\000\000\000\039\000\000\000\087\000\000\000\
\000\000\132\000\128\000\000\000\000\000\120\000\123\000\014\001\
\001\001\000\001\000\000\184\000\000\000\000\000\178\000\000\000\
\175\000\000\000\166\000\000\000\000\000\167\000\000\000\000\000\
\000\000\186\000\000\000\000\000\000\000\000\000\143\001\144\001\
\000\000\022\001\019\001\020\001\031\001\034\001\033\001\038\000\
\031\000\032\000\000\000\033\000\041\000\015\000\016\000\129\000\
\000\000\053\001\170\000\060\001\179\000\171\000\000\000\000\000\
\185\000\000\000\000\000\000\000\183\000\108\000\000\000\000\000\
\040\000\130\000\000\000\168\000\000\000\165\000\182\000\146\001\
\000\000\000\000\172\000\000\000\000\000\000\000\000\000\151\001\
\000\000\000\000\000\000\000\000\000\000\148\001\000\000\000\000\
\180\000\169\000\158\001\000\000\152\001\000\000\000\000\156\001\
\000\000\000\000\000\000\160\001\154\001\153\001\000\000\162\001"

let yydgoto = "\003\000\
\045\000\046\000\047\000\048\000\026\001\197\001\164\002\083\002\
\208\000\209\000\098\001\035\002\049\002\084\002\211\000\002\002\
\118\001\083\000\212\000\050\002\051\002\052\002\187\002\169\000\
\050\000\170\000\135\000\155\000\158\000\159\000\051\000\052\000\
\053\000\214\000\086\002\087\002\038\001\202\001\152\000\136\000\
\137\000\063\001\064\001\065\001\210\001\211\001\212\001\173\002\
\139\000\066\001\054\000\055\000\171\000\207\001\034\001\053\001\
\215\000\216\000\182\002\054\002\217\000\218\000\219\000\220\000\
\221\000\222\000\223\000\224\000\225\000\226\000\227\000\228\000\
\229\000\230\000\247\002\084\000\131\002\055\002\139\002\146\000\
\204\001\095\000\211\002\197\002\248\002\002\003\085\000\142\000\
\057\000\068\000\198\001\156\000\049\001\035\001\091\002\028\001\
\184\000\069\000\232\000\113\000\114\000\115\000\116\000\117\000\
\118\000\119\000\120\000\121\000\122\000\123\000\124\000\125\000\
\126\000\127\000\233\000\080\001\006\003\014\003\007\003\008\003\
\009\003\024\003\028\003"

let yysindex = "\082\001\
\134\014\134\014\000\000\246\254\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\206\255\125\000\071\017\
\152\000\000\000\000\000\000\000\000\000\000\000\142\015\071\017\
\000\000\000\000\071\017\071\017\000\000\000\000\000\000\000\000\
\134\014\022\255\071\017\041\255\109\255\111\255\000\000\000\000\
\107\024\145\255\150\255\178\255\000\000\028\001\000\000\134\014\
\038\000\106\017\000\000\000\000\040\255\072\000\071\017\000\000\
\071\017\000\000\064\000\068\016\000\000\000\000\099\000\224\255\
\111\255\032\000\069\000\102\255\091\255\041\011\074\000\142\255\
\071\017\000\000\000\000\041\011\089\000\154\255\000\000\000\000\
\000\000\180\016\059\255\000\000\000\000\000\000\000\000\000\000\
\000\000\050\000\000\000\059\255\181\010\238\023\000\000\093\255\
\174\000\000\000\000\000\000\000\153\012\229\012\107\024\107\024\
\107\024\107\024\107\024\107\024\107\024\190\000\000\000\208\254\
\000\000\045\255\000\000\000\000\228\000\177\000\232\000\026\001\
\059\001\049\000\132\000\166\000\211\000\021\255\000\000\170\014\
\049\013\035\001\000\000\000\000\078\007\000\000\000\000\213\000\
\235\000\030\001\000\000\100\255\000\000\000\000\000\000\000\000\
\000\000\207\000\242\000\000\000\000\000\012\001\016\001\033\001\
\068\016\042\001\022\001\044\001\086\001\000\000\050\001\050\000\
\000\000\141\001\099\000\099\000\068\001\000\000\066\001\041\011\
\038\255\073\001\041\011\041\011\041\011\076\001\100\001\041\011\
\041\011\081\001\134\014\038\000\000\000\000\000\025\024\108\001\
\137\001\000\000\000\000\000\000\000\000\000\000\000\000\125\013\
\201\013\049\013\049\013\049\013\049\013\049\013\049\013\159\001\
\021\014\021\014\000\006\139\001\146\001\149\001\200\001\000\000\
\000\000\205\001\000\000\220\255\042\001\210\001\000\000\140\001\
\000\000\016\002\002\001\062\001\060\001\084\001\083\001\231\001\
\223\001\239\001\000\002\033\000\000\000\000\000\065\000\245\001\
\255\001\000\000\199\023\072\002\000\000\073\002\000\006\000\000\
\000\006\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\005\002\075\002\219\001\000\000\143\255\143\255\107\024\107\024\
\107\024\107\024\107\024\107\024\107\024\107\024\107\024\107\024\
\107\024\107\024\107\024\107\024\107\024\107\024\107\024\107\024\
\107\024\107\024\007\002\009\002\012\002\000\000\000\000\000\000\
\090\002\042\001\000\000\078\007\042\001\000\000\178\011\078\007\
\048\001\000\000\000\000\017\002\094\002\242\001\000\000\064\000\
\000\000\071\017\030\002\000\000\000\000\000\000\155\255\177\015\
\000\000\000\000\049\013\151\001\065\002\063\002\076\002\050\001\
\050\001\099\000\041\011\000\000\049\013\041\011\066\002\067\002\
\070\002\100\255\000\000\000\000\078\002\081\002\041\011\000\000\
\083\002\084\002\041\011\088\002\030\001\093\000\000\000\092\002\
\000\000\082\002\000\006\000\000\000\006\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\006\000\000\000\000\
\117\000\099\002\108\002\109\002\110\002\049\013\071\017\071\017\
\184\002\000\000\000\000\000\000\000\000\114\002\000\000\143\255\
\143\255\000\000\000\000\011\009\087\009\000\000\049\013\049\013\
\049\013\049\013\049\013\049\013\049\013\049\013\049\013\049\013\
\049\013\049\013\049\013\049\013\049\013\049\013\049\013\049\013\
\049\013\049\013\049\013\049\013\049\013\049\013\049\013\049\013\
\049\013\049\013\049\013\011\009\000\000\064\024\064\024\000\000\
\000\000\000\000\000\000\117\002\119\002\000\000\000\000\000\000\
\000\000\000\000\115\002\000\000\000\000\000\000\228\000\228\000\
\177\000\177\000\232\000\232\000\232\000\232\000\026\001\026\001\
\059\001\049\000\132\000\166\000\211\000\116\002\194\002\196\002\
\000\000\000\000\000\000\000\000\000\000\032\008\000\000\000\000\
\042\001\064\000\078\007\123\002\000\000\068\016\087\007\000\000\
\121\002\118\002\111\255\133\005\000\000\076\255\120\002\000\000\
\251\000\195\011\202\007\129\002\000\000\022\001\000\000\000\000\
\000\000\000\000\000\000\000\000\133\002\136\002\050\001\000\000\
\000\000\000\000\049\013\042\255\041\011\000\000\000\000\137\002\
\000\000\000\000\145\002\000\000\000\000\000\000\000\000\167\002\
\168\002\180\002\000\000\011\009\011\009\000\000\255\011\000\000\
\176\002\181\002\185\002\192\002\251\000\000\000\000\000\186\002\
\000\000\195\002\063\255\197\002\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\002\001\002\001\062\001\062\001\060\001\
\060\001\060\001\060\001\084\001\084\001\083\001\231\001\223\001\
\239\001\000\002\200\002\000\000\199\002\000\000\000\000\206\002\
\206\002\000\000\107\024\210\002\211\002\000\000\143\255\049\013\
\000\000\207\002\000\000\235\002\212\002\201\002\178\011\216\002\
\000\000\217\002\163\009\059\255\219\002\000\000\094\002\207\000\
\000\000\186\002\214\002\000\000\215\002\218\002\088\255\111\008\
\220\002\049\013\221\002\220\002\061\007\222\002\220\002\040\255\
\151\000\000\000\133\005\225\002\133\005\000\000\224\002\133\005\
\000\000\226\002\229\002\000\000\228\002\042\001\000\000\000\000\
\068\016\011\009\000\000\000\000\000\000\227\002\078\007\000\000\
\000\000\000\000\000\000\206\002\206\002\206\002\000\000\000\000\
\032\008\000\000\071\017\071\017\143\255\000\000\042\001\000\000\
\000\000\000\000\049\013\000\000\134\014\049\013\026\255\177\255\
\032\008\000\000\178\011\000\000\000\000\000\000\000\000\071\017\
\118\000\000\000\232\002\238\002\000\000\000\000\000\000\078\255\
\043\000\000\000\000\000\233\002\011\009\000\000\234\002\239\009\
\061\007\164\000\000\000\061\007\236\002\237\002\123\006\061\007\
\077\001\151\000\151\000\223\002\000\000\000\000\000\000\000\000\
\000\000\076\255\215\016\000\000\239\002\244\002\241\002\000\000\
\000\000\248\002\252\002\000\003\000\000\098\000\000\000\006\003\
\026\003\000\000\000\000\026\255\049\013\000\000\000\000\000\000\
\000\000\000\000\078\007\000\000\061\007\043\000\000\000\022\003\
\000\000\117\000\000\000\061\007\049\013\000\000\043\000\220\002\
\034\003\000\000\011\009\020\003\220\002\040\255\000\000\000\000\
\116\003\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\126\003\000\000\000\000\000\000\000\000\000\000\
\049\003\000\000\000\000\000\000\000\000\000\000\050\003\048\003\
\000\000\054\003\061\007\040\255\000\000\000\000\116\003\057\003\
\000\000\000\000\061\007\000\000\011\009\000\000\000\000\000\000\
\060\003\067\003\000\000\068\003\143\003\069\003\066\003\000\000\
\059\255\070\003\061\007\071\003\060\003\000\000\060\003\079\003\
\000\000\000\000\000\000\082\003\000\000\059\010\116\003\000\000\
\093\003\097\003\090\003\000\000\000\000\000\000\116\003\000\000"

let yyrindex = "\000\000\
\024\000\025\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\114\000\
\000\000\000\000\000\000\000\000\000\000\000\000\048\000\114\000\
\000\000\000\000\114\000\114\000\000\000\000\000\000\000\000\000\
\017\000\000\000\114\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\017\000\
\034\000\104\000\000\000\000\000\000\000\000\000\114\000\000\000\
\114\000\000\000\033\016\099\003\000\000\000\000\000\000\000\000\
\000\000\000\000\225\001\000\000\047\000\105\003\087\002\000\000\
\114\000\000\000\000\000\105\003\204\002\000\000\000\000\000\000\
\000\000\000\000\030\015\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\212\001\
\074\002\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\191\002\000\000\000\000\208\016\168\024\142\007\104\001\
\013\007\013\011\056\010\095\003\226\005\247\000\000\000\182\003\
\000\000\000\000\000\000\000\000\053\255\000\000\000\000\102\003\
\000\000\233\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\020\004\000\000\000\000\000\000\110\003\047\255\000\000\
\000\000\007\000\111\003\000\000\232\255\000\000\118\003\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\105\003\
\034\000\000\000\105\003\105\003\105\003\065\003\000\000\105\003\
\105\003\000\000\030\255\034\000\000\000\000\000\113\003\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\194\017\018\001\000\000\000\000\028\018\
\000\000\025\019\090\019\029\020\224\020\031\022\208\022\070\023\
\209\008\105\009\001\010\050\008\000\000\000\000\000\000\121\003\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\070\000\000\000\152\003\034\000\000\000\000\000\092\255\
\142\000\000\000\000\000\000\000\000\000\143\004\000\000\000\000\
\000\000\056\000\000\000\000\000\000\000\087\000\119\003\000\000\
\000\000\000\000\000\000\120\003\000\000\000\000\000\000\118\003\
\118\003\000\000\105\003\000\000\000\000\105\003\098\001\128\003\
\000\000\000\000\000\000\000\000\000\000\000\000\105\003\000\000\
\000\000\000\000\105\003\000\000\135\001\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\123\003\193\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\119\003\000\000\000\000\
\000\000\000\000\000\000\127\003\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\122\003\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\096\017\135\024\
\203\024\236\024\164\014\015\025\048\025\083\025\108\023\106\025\
\196\010\033\014\149\015\124\003\002\006\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\131\003\000\000\000\000\
\034\000\033\016\190\008\000\000\000\000\099\003\168\000\000\000\
\133\003\000\000\000\000\141\003\000\000\034\000\048\255\000\000\
\060\000\182\000\223\000\000\000\000\000\111\003\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\118\003\000\000\
\000\000\000\000\000\000\034\000\105\003\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\215\255\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\155\019\220\019\094\020\159\020\033\021\
\098\021\163\021\228\021\090\022\149\022\011\023\129\023\029\009\
\181\009\119\011\000\000\000\000\000\000\000\000\000\000\052\003\
\058\016\000\000\000\000\000\000\000\000\186\025\000\000\000\000\
\000\000\142\003\000\000\076\012\000\000\000\000\000\000\000\000\
\000\000\000\000\144\003\000\000\000\000\000\000\000\000\020\004\
\000\000\129\255\232\025\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\125\003\000\000\141\003\000\000\141\003\000\000\000\000\141\003\
\000\000\140\003\000\000\000\000\000\000\207\255\000\000\000\000\
\099\003\144\003\000\000\000\000\000\000\000\000\138\001\000\000\
\000\000\000\000\000\000\118\018\208\018\000\000\000\000\000\000\
\131\003\000\000\000\000\000\000\000\000\000\000\208\000\000\000\
\000\000\000\000\000\000\000\000\030\255\000\000\101\011\000\000\
\131\003\000\000\000\000\000\000\000\000\000\000\000\000\062\255\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\202\006\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\232\025\000\000\147\003\000\000\
\000\000\125\003\125\003\000\000\000\000\000\000\000\000\000\000\
\000\000\034\000\056\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\101\011\000\000\000\000\000\000\000\000\
\000\000\000\000\230\000\000\000\000\000\176\007\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\176\007\000\000\
\000\000\000\000\147\003\010\005\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\138\000\148\003\
\000\000\000\000\000\000\000\000\158\003\000\000\000\000\000\000\
\036\000\000\000\000\000\000\000\000\000\161\003\154\000\000\000\
\000\000\000\000\000\000\000\000\036\000\000\000\198\255\000\000\
\000\000\000\000\000\000\162\003\000\000\000\000\000\000\000\000\
\000\000\000\000\163\003\000\000\000\000\000\000\000\000\000\000"

let yygindex = "\000\000\
\000\000\236\004\230\255\111\004\060\255\041\003\071\000\064\254\
\000\000\233\255\165\255\160\253\231\254\226\255\238\253\000\000\
\059\002\000\000\000\000\000\000\000\000\208\253\055\002\018\000\
\000\000\217\255\000\000\118\255\192\003\124\255\183\255\000\000\
\000\000\089\255\204\255\158\255\182\002\187\002\242\254\000\000\
\216\003\223\255\000\000\019\003\108\004\000\000\000\000\151\255\
\107\255\228\255\121\255\000\000\002\000\172\253\042\000\227\254\
\000\000\000\000\000\000\205\254\107\001\063\001\154\001\162\001\
\027\001\160\001\106\003\107\003\108\003\109\003\114\003\000\000\
\131\002\051\002\180\254\202\255\000\000\000\000\154\002\000\000\
\000\000\203\255\000\000\060\002\013\002\000\000\089\002\000\000\
\137\255\001\001\006\000\081\254\051\003\000\000\096\002\234\254\
\102\004\000\000\003\000\000\000\000\000\000\000\095\000\049\002\
\061\002\221\001\064\002\254\003\255\003\253\003\000\004\042\004\
\000\000\251\254\112\255\000\000\001\002\000\000\000\000\002\002\
\000\000\000\000\240\001"

let yytablesize = 6972
let yytable = "\082\000\
\145\000\210\000\056\000\056\000\046\001\192\001\089\000\036\001\
\181\000\060\000\199\001\161\000\182\001\027\001\043\001\138\000\
\003\000\111\000\049\000\049\000\140\000\132\000\061\002\003\000\
\003\000\205\001\221\001\222\001\182\000\006\000\056\001\057\001\
\251\000\074\000\056\000\100\001\175\000\020\001\079\001\143\000\
\074\000\074\000\237\000\112\000\074\000\074\000\042\001\041\001\
\045\001\056\000\049\000\192\002\074\000\049\001\153\002\067\000\
\071\000\156\002\077\000\049\001\160\002\018\001\209\002\046\001\
\059\000\049\000\079\000\141\000\185\000\252\000\111\000\156\001\
\074\000\157\001\074\000\089\002\047\002\154\000\186\002\111\000\
\111\000\111\000\111\000\111\000\111\000\111\000\220\002\188\001\
\148\002\017\001\074\000\193\001\049\001\234\000\253\000\254\000\
\090\000\133\000\049\001\180\000\061\000\133\000\061\000\048\002\
\018\001\003\000\062\000\109\001\062\000\165\000\213\000\249\000\
\049\001\174\000\242\002\092\000\144\000\061\001\062\001\178\000\
\044\001\061\001\255\000\042\001\041\001\047\001\049\001\049\001\
\060\001\056\000\049\001\068\001\069\001\070\001\049\001\133\000\
\073\001\074\001\018\001\186\002\158\002\121\002\061\000\061\000\
\244\001\049\000\077\001\149\002\062\000\062\000\101\001\049\001\
\076\001\200\001\061\000\061\000\004\003\108\001\196\002\111\000\
\062\000\062\000\080\000\081\000\027\001\214\001\049\001\235\000\
\027\001\027\001\154\000\240\001\099\001\241\001\032\001\049\001\
\199\001\174\002\164\000\058\002\056\000\223\001\242\001\093\000\
\110\001\094\000\101\001\199\001\101\001\240\002\064\000\250\001\
\251\001\102\002\244\002\191\001\049\000\243\000\244\000\245\000\
\246\000\247\000\248\000\065\000\006\000\157\001\061\000\025\001\
\099\001\006\000\099\001\111\000\062\000\025\001\049\001\215\001\
\203\002\036\001\173\000\206\002\213\000\128\000\066\000\212\002\
\066\000\225\001\129\000\079\000\107\001\209\001\177\000\111\000\
\111\000\111\000\111\000\111\000\111\000\111\000\111\000\111\000\
\111\000\111\000\111\000\111\000\111\000\111\000\111\000\111\000\
\111\000\111\000\111\000\077\001\130\000\187\001\059\002\188\002\
\213\000\163\001\213\000\189\002\235\002\038\002\039\002\025\001\
\066\000\066\000\249\001\238\002\094\002\025\001\096\002\072\000\
\006\000\078\000\049\001\224\001\066\000\066\000\226\001\006\000\
\006\000\025\001\063\000\131\000\025\001\134\002\101\001\232\001\
\101\001\049\001\025\001\235\001\049\001\124\002\161\001\162\001\
\025\001\101\001\160\000\157\001\005\000\157\001\157\001\068\001\
\203\000\064\000\254\002\251\000\099\001\068\001\099\001\018\001\
\119\002\251\000\003\003\206\001\049\001\178\002\065\000\099\001\
\150\000\154\000\049\001\080\000\081\000\166\000\025\001\147\000\
\066\000\025\001\018\003\027\001\025\001\190\002\032\000\027\001\
\011\001\025\001\001\000\002\000\025\001\001\002\004\002\026\001\
\011\001\027\001\027\001\027\001\003\000\026\001\164\001\165\001\
\166\001\133\000\191\001\157\000\213\000\147\001\213\000\205\000\
\205\000\191\002\162\000\203\000\025\001\149\001\205\000\213\000\
\013\001\203\000\203\000\149\001\148\001\036\002\134\000\049\001\
\213\000\213\000\203\000\068\001\183\000\061\000\111\000\111\000\
\203\000\025\001\085\002\062\000\018\001\027\001\049\001\103\002\
\018\001\049\001\149\001\157\001\157\001\051\001\034\000\025\001\
\025\001\163\000\150\001\025\001\227\002\065\002\172\000\025\001\
\061\000\254\001\255\001\038\000\025\001\039\000\062\000\056\002\
\030\001\026\001\177\002\205\000\026\001\176\000\237\001\051\001\
\030\001\068\001\203\000\228\002\090\002\203\000\150\001\117\001\
\162\002\205\000\205\000\163\002\051\001\205\000\049\001\205\000\
\205\000\205\000\144\002\203\000\203\000\105\002\243\001\203\000\
\025\001\203\000\203\000\203\000\193\002\014\001\244\001\244\001\
\046\001\070\000\027\003\179\002\180\002\088\002\051\001\240\000\
\242\000\026\001\027\003\145\001\128\002\111\002\112\002\154\000\
\097\002\145\001\051\001\191\001\051\001\180\000\051\001\051\001\
\064\000\046\001\205\000\150\001\076\000\049\001\015\001\053\002\
\038\001\150\001\003\001\004\001\203\000\065\000\154\002\027\001\
\165\002\051\001\167\002\204\002\051\001\169\002\205\002\066\000\
\051\001\051\001\093\002\064\000\005\000\238\000\234\002\051\001\
\087\001\088\001\089\001\090\001\091\001\092\001\051\001\051\001\
\065\000\085\002\138\000\085\002\049\001\250\000\085\002\138\000\
\138\000\138\000\066\000\111\000\022\001\191\001\016\001\023\001\
\024\001\198\002\025\001\161\002\138\002\025\001\032\000\000\001\
\001\001\002\001\185\002\021\001\140\002\191\001\029\001\191\001\
\049\001\151\002\084\001\086\001\035\001\005\001\006\001\049\001\
\049\001\005\000\049\001\095\001\096\001\038\001\049\001\049\001\
\037\001\191\000\191\000\030\001\056\002\130\001\131\001\132\001\
\130\001\047\001\039\001\138\002\031\001\130\001\130\001\130\001\
\130\001\022\001\025\001\027\001\023\001\024\001\198\002\007\001\
\008\001\009\001\010\001\032\000\088\002\210\002\088\002\198\002\
\127\002\088\002\110\001\028\001\025\001\040\001\034\000\025\001\
\041\001\233\002\184\002\028\001\180\000\133\000\180\000\048\001\
\075\000\180\000\042\001\038\000\130\001\039\000\011\001\012\001\
\086\000\239\002\154\000\087\000\088\000\050\001\200\002\133\001\
\134\001\099\001\194\001\091\000\051\001\195\001\056\000\025\001\
\036\002\135\001\136\001\052\001\213\000\213\000\141\001\142\001\
\090\002\137\001\138\001\139\001\140\001\055\001\049\000\148\000\
\058\001\149\000\059\001\034\000\067\001\196\001\216\001\157\000\
\071\001\206\001\053\002\117\001\117\001\075\001\181\002\093\001\
\038\000\245\002\039\000\024\002\025\002\026\002\027\002\117\001\
\117\001\117\001\053\002\117\001\117\001\213\002\214\002\072\001\
\180\000\117\001\245\000\245\000\036\002\081\001\117\001\117\001\
\117\001\117\001\026\003\117\001\206\001\112\001\113\001\255\002\
\016\002\017\002\018\002\019\002\019\002\019\002\019\002\019\002\
\019\002\019\002\019\002\019\002\019\002\019\002\019\002\019\002\
\019\002\019\002\082\001\114\001\115\001\102\001\116\001\191\000\
\191\000\117\001\049\001\049\001\103\001\117\001\036\002\104\001\
\229\000\229\000\229\000\171\001\172\001\173\001\174\001\229\000\
\215\002\216\002\229\000\229\000\229\000\229\000\229\000\229\000\
\229\000\016\003\229\000\229\000\229\000\229\000\229\000\229\000\
\229\000\229\000\229\000\229\000\229\000\229\000\229\000\229\000\
\229\000\229\000\229\000\229\000\229\000\073\001\073\001\073\001\
\073\001\073\001\073\001\073\001\073\001\073\001\073\001\073\001\
\073\001\073\001\105\001\073\001\073\001\073\001\106\001\073\001\
\073\001\073\001\073\001\111\001\229\000\073\001\020\002\021\002\
\144\001\073\001\073\001\073\001\073\001\073\001\143\001\073\001\
\022\002\023\002\229\000\229\000\028\002\029\002\229\000\145\001\
\229\000\229\000\229\000\167\001\168\001\114\002\119\001\120\001\
\121\001\122\001\123\001\124\001\125\001\126\001\127\001\128\001\
\129\001\169\001\170\001\146\001\229\000\229\000\151\001\229\000\
\152\001\073\001\175\001\176\001\154\001\155\001\158\001\159\001\
\160\001\229\000\183\001\229\000\184\001\185\001\218\000\218\000\
\218\000\229\000\186\001\229\000\200\001\218\000\201\001\203\001\
\218\000\218\000\218\000\218\000\218\000\218\000\218\000\208\001\
\218\000\218\000\218\000\218\000\218\000\218\000\218\000\218\000\
\218\000\218\000\218\000\218\000\218\000\218\000\218\000\218\000\
\218\000\218\000\218\000\077\001\077\001\077\001\077\001\077\001\
\077\001\077\001\077\001\077\001\077\001\077\001\077\001\077\001\
\219\001\077\001\077\001\077\001\218\001\077\001\077\001\077\001\
\077\001\227\001\218\000\077\001\228\001\220\001\229\001\077\001\
\077\001\230\001\077\001\077\001\231\001\077\001\233\001\234\001\
\218\000\218\000\239\001\236\001\218\000\238\001\218\000\218\000\
\218\000\005\002\006\002\007\002\008\002\009\002\010\002\011\002\
\012\002\013\002\014\002\015\002\245\001\246\001\247\001\248\001\
\252\001\019\002\218\000\218\000\253\001\218\000\040\002\077\001\
\041\002\042\002\044\002\043\002\045\002\060\002\064\002\218\000\
\092\002\218\000\063\002\224\000\224\000\224\000\098\002\218\000\
\100\002\218\000\224\000\101\002\106\002\224\000\224\000\224\000\
\224\000\224\000\224\000\224\000\107\002\224\000\224\000\224\000\
\224\000\224\000\224\000\224\000\224\000\224\000\224\000\224\000\
\224\000\224\000\224\000\224\000\224\000\224\000\224\000\224\000\
\108\002\109\002\090\001\090\001\090\001\090\001\090\001\090\001\
\090\001\090\001\090\001\090\001\090\001\110\002\090\001\090\001\
\090\001\115\002\090\001\090\001\090\001\090\001\116\002\224\000\
\090\001\118\002\117\002\244\001\120\002\090\001\090\001\090\001\
\090\001\130\002\090\001\122\002\133\002\224\000\224\000\123\002\
\150\001\224\000\113\002\224\000\224\000\224\000\125\002\126\002\
\129\002\135\002\136\002\132\002\141\002\145\002\152\002\146\002\
\159\002\217\002\147\002\168\002\155\002\172\002\176\002\224\000\
\224\000\166\002\224\000\170\002\090\001\171\002\194\002\195\002\
\221\002\199\002\201\002\207\002\224\000\222\002\224\000\223\002\
\219\000\219\000\219\000\224\002\224\000\225\002\224\000\219\000\
\208\002\226\002\219\000\219\000\219\000\219\000\219\000\219\000\
\219\000\230\002\219\000\219\000\219\000\219\000\219\000\219\000\
\219\000\219\000\219\000\219\000\219\000\219\000\219\000\219\000\
\219\000\219\000\219\000\219\000\219\000\231\002\237\002\092\001\
\092\001\092\001\092\001\092\001\092\001\092\001\092\001\092\001\
\092\001\092\001\241\002\092\001\092\001\092\001\243\002\092\001\
\092\001\092\001\092\001\246\002\219\000\092\001\249\002\250\002\
\252\002\251\002\092\001\092\001\092\001\092\001\253\002\092\001\
\001\003\005\003\219\000\219\000\010\003\011\003\219\000\012\003\
\219\000\219\000\219\000\015\003\013\003\019\003\017\003\049\001\
\049\001\022\003\049\001\049\001\049\001\049\001\049\001\049\001\
\049\001\023\003\126\001\126\001\219\000\219\000\029\003\219\000\
\126\001\092\001\030\003\031\003\004\001\126\001\126\001\126\001\
\126\001\219\000\126\001\219\000\237\000\006\000\189\000\016\001\
\006\001\219\000\136\001\219\000\049\001\049\001\049\001\127\001\
\127\001\021\000\133\001\022\000\036\001\127\001\006\000\142\001\
\134\000\136\000\127\001\127\001\127\001\127\001\121\000\127\001\
\243\000\049\001\049\001\049\001\126\001\159\000\049\001\049\001\
\152\000\119\000\049\001\049\001\021\001\147\001\141\000\049\001\
\049\001\049\001\049\001\136\000\049\001\049\001\049\001\136\000\
\049\001\049\001\155\001\159\001\161\001\058\000\019\001\062\002\
\229\002\127\001\232\002\217\001\189\001\143\002\104\002\033\001\
\030\002\142\002\031\002\175\002\032\002\183\002\033\002\049\001\
\049\001\236\002\049\001\000\003\034\002\054\001\049\001\049\001\
\099\002\218\002\177\001\179\001\178\001\020\003\032\003\180\001\
\021\003\049\001\049\001\157\000\157\000\157\000\157\000\157\000\
\157\000\157\000\157\000\157\000\157\000\157\000\157\000\157\000\
\157\000\157\000\157\000\157\000\000\000\157\000\157\000\157\000\
\157\000\157\000\157\000\157\000\157\000\157\000\157\000\157\000\
\157\000\157\000\157\000\157\000\157\000\157\000\157\000\157\000\
\157\000\157\000\181\001\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\157\000\157\000\157\000\
\000\000\000\000\157\000\157\000\000\000\000\000\157\000\157\000\
\000\000\000\000\000\000\157\000\157\000\000\000\157\000\157\000\
\157\000\000\000\000\000\000\000\157\000\000\000\000\000\000\000\
\157\000\157\000\157\000\157\000\157\000\157\000\157\000\157\000\
\157\000\157\000\157\000\157\000\000\000\000\000\000\000\157\000\
\157\000\157\000\157\000\157\000\157\000\000\000\157\000\000\000\
\000\000\157\000\157\000\157\000\157\000\157\000\157\000\157\000\
\157\000\000\000\000\000\000\000\157\000\157\000\150\000\150\000\
\150\000\150\000\150\000\150\000\150\000\150\000\150\000\150\000\
\150\000\150\000\150\000\150\000\150\000\150\000\150\000\000\000\
\150\000\150\000\150\000\150\000\150\000\150\000\150\000\150\000\
\150\000\150\000\150\000\150\000\150\000\150\000\150\000\150\000\
\150\000\150\000\150\000\150\000\150\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\150\000\150\000\150\000\000\000\000\000\150\000\150\000\000\000\
\000\000\150\000\150\000\000\000\000\000\000\000\150\000\150\000\
\000\000\150\000\150\000\150\000\000\000\000\000\000\000\150\000\
\000\000\000\000\000\000\150\000\150\000\150\000\150\000\150\000\
\150\000\150\000\150\000\150\000\150\000\150\000\150\000\000\000\
\000\000\000\000\150\000\150\000\150\000\150\000\150\000\150\000\
\000\000\150\000\000\000\000\000\000\000\150\000\150\000\150\000\
\150\000\150\000\150\000\150\000\000\000\000\000\000\000\150\000\
\150\000\164\000\164\000\164\000\164\000\164\000\164\000\164\000\
\164\000\164\000\164\000\164\000\164\000\164\000\164\000\164\000\
\164\000\164\000\000\000\164\000\164\000\164\000\164\000\164\000\
\164\000\164\000\164\000\164\000\164\000\164\000\164\000\164\000\
\164\000\164\000\164\000\164\000\164\000\164\000\164\000\164\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\164\000\164\000\164\000\000\000\000\000\
\164\000\164\000\000\000\000\000\164\000\164\000\000\000\000\000\
\000\000\164\000\164\000\000\000\164\000\164\000\164\000\000\000\
\000\000\000\000\164\000\000\000\000\000\000\000\164\000\164\000\
\164\000\164\000\164\000\164\000\164\000\164\000\164\000\164\000\
\164\000\164\000\000\000\000\000\000\000\164\000\164\000\164\000\
\164\000\164\000\164\000\000\000\164\000\000\000\000\000\000\000\
\164\000\164\000\164\000\164\000\164\000\164\000\164\000\000\000\
\000\000\000\000\164\000\164\000\066\002\067\002\005\000\187\000\
\188\000\189\000\190\000\006\000\079\000\191\000\007\000\008\000\
\009\000\010\000\011\000\012\000\013\000\000\000\014\000\015\000\
\016\000\017\000\018\000\019\000\020\000\021\000\022\000\073\000\
\024\000\025\000\026\000\027\000\028\000\029\000\030\000\031\000\
\032\000\192\000\193\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\194\000\195\000\
\196\000\000\000\000\000\197\000\198\000\000\000\000\000\199\000\
\200\000\000\000\000\000\000\000\201\000\202\000\000\000\203\000\
\000\000\144\000\000\000\000\000\000\000\068\002\000\000\000\000\
\000\000\069\002\070\002\071\002\072\002\073\002\074\002\075\002\
\076\002\077\002\078\002\079\002\080\002\000\000\000\000\000\000\
\034\000\035\000\081\002\037\000\080\000\081\000\000\000\204\000\
\000\000\000\000\000\000\205\000\206\000\038\000\082\002\039\000\
\040\000\041\000\000\000\000\000\000\000\044\000\207\000\097\001\
\186\000\005\000\187\000\188\000\189\000\190\000\006\000\079\000\
\191\000\007\000\008\000\009\000\010\000\011\000\012\000\013\000\
\000\000\014\000\015\000\016\000\017\000\018\000\019\000\020\000\
\021\000\022\000\073\000\024\000\025\000\026\000\027\000\028\000\
\029\000\030\000\031\000\032\000\192\000\193\000\128\001\000\000\
\000\000\000\000\000\000\128\001\000\000\000\000\000\000\000\000\
\128\001\128\001\128\001\128\001\000\000\128\001\000\000\000\000\
\000\000\194\000\195\000\196\000\000\000\000\000\197\000\198\000\
\000\000\000\000\199\000\200\000\000\000\000\000\129\001\201\000\
\202\000\000\000\203\000\129\001\144\000\000\000\000\000\000\000\
\129\001\129\001\129\001\129\001\000\000\129\001\000\000\128\001\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\034\000\035\000\000\000\037\000\080\000\
\081\000\000\000\204\000\000\000\000\000\000\000\205\000\206\000\
\038\000\000\000\039\000\000\000\000\000\000\000\000\000\129\001\
\044\000\207\000\000\002\186\000\005\000\187\000\188\000\189\000\
\190\000\006\000\079\000\191\000\007\000\008\000\009\000\010\000\
\011\000\012\000\013\000\000\000\014\000\015\000\016\000\017\000\
\018\000\019\000\020\000\021\000\022\000\073\000\024\000\025\000\
\026\000\027\000\028\000\029\000\030\000\031\000\032\000\192\000\
\193\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\194\000\195\000\196\000\000\000\
\000\000\197\000\198\000\000\000\000\000\199\000\200\000\000\000\
\000\000\000\000\201\000\202\000\000\000\203\000\000\000\000\000\
\000\000\059\001\059\001\000\000\059\001\059\001\059\001\059\001\
\000\000\059\001\059\001\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\034\000\035\000\
\000\000\037\000\080\000\081\000\000\000\204\000\000\000\000\000\
\000\000\205\000\206\000\038\000\000\000\039\000\059\001\059\001\
\000\000\000\000\000\000\044\000\207\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\059\001\059\001\059\001\000\000\000\000\
\059\001\059\001\000\000\000\000\059\001\059\001\000\000\000\000\
\000\000\059\001\059\001\000\000\059\001\155\000\059\001\000\000\
\000\000\000\000\059\001\000\000\000\000\000\000\059\001\059\001\
\059\001\059\001\059\001\059\001\059\001\059\001\059\001\059\001\
\059\001\059\001\000\000\000\000\000\000\000\000\000\000\059\001\
\000\000\059\001\059\001\000\000\059\001\000\000\000\000\000\000\
\059\001\059\001\000\000\059\001\066\002\157\002\000\000\187\000\
\188\000\189\000\190\000\059\001\079\000\191\000\000\000\000\000\
\000\000\000\000\000\000\000\000\120\001\120\001\120\001\005\000\
\120\001\120\001\000\000\000\000\000\000\000\000\120\001\000\000\
\005\000\000\000\000\000\120\001\120\001\120\001\120\001\000\000\
\120\001\192\000\193\000\000\000\000\000\000\000\000\000\022\001\
\000\000\000\000\023\001\024\001\000\000\000\000\000\000\000\000\
\022\001\032\000\000\000\023\001\024\001\000\000\194\000\195\000\
\196\000\000\000\032\000\197\000\198\000\000\000\000\000\199\000\
\200\000\000\000\120\001\000\000\201\000\202\000\000\000\203\000\
\000\000\144\000\000\000\000\000\000\000\068\002\000\000\000\000\
\000\000\069\002\070\002\071\002\072\002\073\002\074\002\075\002\
\076\002\077\002\078\002\079\002\080\002\025\001\000\000\000\000\
\000\000\000\000\081\002\000\000\080\000\081\000\025\001\204\000\
\000\000\000\000\000\000\205\000\206\000\000\000\082\002\059\001\
\059\001\034\000\059\001\059\001\059\001\059\001\207\000\059\001\
\059\001\000\000\034\000\000\000\196\001\000\000\038\000\000\000\
\039\000\112\001\112\001\112\001\112\001\112\001\112\001\038\000\
\000\000\039\000\000\000\005\000\000\000\112\001\112\001\112\001\
\000\000\112\001\112\001\000\000\059\001\059\001\000\000\112\001\
\000\000\000\000\000\000\000\000\112\001\112\001\112\001\112\001\
\000\000\112\001\000\000\022\001\000\000\000\000\023\001\024\001\
\000\000\059\001\059\001\059\001\000\000\032\000\059\001\059\001\
\000\000\000\000\059\001\059\001\000\000\000\000\000\000\059\001\
\059\001\000\000\059\001\000\000\059\001\000\000\000\000\000\000\
\059\001\000\000\000\000\112\001\059\001\059\001\059\001\059\001\
\059\001\059\001\059\001\059\001\059\001\059\001\059\001\059\001\
\000\000\000\000\000\000\000\000\095\002\059\001\000\000\059\001\
\059\001\025\001\059\001\000\000\000\000\000\000\059\001\059\001\
\046\002\059\001\187\000\188\000\189\000\190\000\062\000\079\000\
\191\000\059\001\000\000\000\000\000\000\034\000\000\000\000\000\
\000\000\000\000\000\000\086\000\000\000\000\000\000\000\000\000\
\000\000\000\000\038\000\000\000\039\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\192\000\193\000\000\000\000\000\
\000\000\000\000\000\000\086\000\000\000\000\000\086\000\086\000\
\000\000\000\000\047\002\000\000\000\000\086\000\000\000\000\000\
\000\000\194\000\195\000\196\000\000\000\000\000\197\000\198\000\
\000\000\000\000\199\000\200\000\000\000\000\000\000\000\201\000\
\202\000\000\000\203\000\000\000\190\001\048\002\000\002\186\000\
\000\000\187\000\188\000\189\000\190\000\000\000\079\000\191\000\
\000\000\000\000\000\000\086\000\000\000\086\000\000\000\000\000\
\086\000\086\000\086\000\086\000\086\000\000\000\000\000\080\000\
\081\000\000\000\204\000\000\000\000\000\000\000\205\000\206\000\
\000\000\000\000\000\000\192\000\193\000\086\000\000\000\000\000\
\000\000\207\000\066\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\086\000\000\000\086\000\000\000\000\000\000\000\
\194\000\195\000\196\000\000\000\000\000\197\000\198\000\000\000\
\000\000\199\000\200\000\000\000\000\000\000\000\201\000\202\000\
\000\000\203\000\000\000\000\000\000\000\049\001\049\001\150\002\
\049\001\049\001\049\001\049\001\000\000\049\001\049\001\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\080\000\000\000\000\000\000\000\080\000\081\000\
\000\000\204\000\000\000\000\000\000\000\205\000\206\000\000\000\
\000\000\000\000\049\001\049\001\000\000\000\000\000\000\000\000\
\207\000\000\000\080\000\000\000\000\000\080\000\080\000\000\000\
\000\000\000\000\000\000\000\000\080\000\000\000\000\000\049\001\
\049\001\049\001\000\000\000\000\049\001\049\001\000\000\000\000\
\049\001\049\001\000\000\000\000\000\000\049\001\049\001\000\000\
\049\001\000\000\000\002\186\000\049\001\187\000\188\000\189\000\
\190\000\080\000\079\000\191\000\080\000\080\000\000\000\000\000\
\000\000\000\000\080\000\000\000\080\000\000\000\081\000\080\000\
\080\000\080\000\080\000\080\000\080\000\049\001\049\001\000\000\
\049\001\000\000\000\000\000\000\049\001\049\001\000\000\192\000\
\193\000\000\000\000\000\000\000\080\000\000\000\081\000\049\001\
\000\000\081\000\081\000\000\000\000\000\000\000\000\000\000\000\
\081\000\080\000\000\000\080\000\194\000\195\000\196\000\000\000\
\000\000\197\000\198\000\000\000\000\000\199\000\200\000\000\000\
\000\000\000\000\201\000\202\000\000\000\203\000\003\002\186\000\
\000\000\187\000\188\000\189\000\190\000\081\000\079\000\191\000\
\081\000\081\000\000\000\000\000\000\000\000\000\081\000\000\000\
\081\000\000\000\082\000\081\000\081\000\081\000\081\000\081\000\
\081\000\000\000\080\000\081\000\000\000\204\000\000\000\000\000\
\000\000\205\000\206\000\192\000\193\000\000\000\000\000\000\000\
\081\000\000\000\082\000\000\000\207\000\082\000\082\000\000\000\
\000\000\000\000\000\000\000\000\082\000\081\000\000\000\081\000\
\194\000\195\000\196\000\000\000\000\000\197\000\198\000\000\000\
\000\000\199\000\200\000\000\000\000\000\000\000\201\000\202\000\
\000\000\203\000\137\002\186\000\000\000\187\000\188\000\189\000\
\190\000\000\000\079\000\191\000\082\000\082\000\000\000\000\000\
\000\000\000\000\082\000\000\000\082\000\000\000\083\000\082\000\
\082\000\082\000\082\000\082\000\082\000\000\000\080\000\081\000\
\000\000\204\000\000\000\000\000\000\000\205\000\206\000\192\000\
\193\000\000\000\000\000\000\000\082\000\000\000\083\000\000\000\
\207\000\083\000\083\000\000\000\000\000\000\000\000\000\000\000\
\083\000\082\000\000\000\082\000\194\000\195\000\196\000\000\000\
\000\000\197\000\198\000\000\000\000\000\199\000\200\000\000\000\
\000\000\000\000\201\000\202\000\000\000\203\000\202\002\186\000\
\000\000\187\000\188\000\189\000\190\000\000\000\079\000\191\000\
\083\000\083\000\000\000\000\000\000\000\000\000\083\000\000\000\
\083\000\000\000\084\000\083\000\083\000\083\000\083\000\083\000\
\083\000\000\000\080\000\081\000\000\000\204\000\000\000\000\000\
\000\000\205\000\206\000\192\000\193\000\000\000\000\000\000\000\
\083\000\000\000\084\000\000\000\207\000\084\000\084\000\000\000\
\000\000\000\000\000\000\000\000\084\000\083\000\000\000\083\000\
\194\000\195\000\196\000\000\000\000\000\197\000\198\000\000\000\
\000\000\199\000\200\000\000\000\000\000\000\000\201\000\202\000\
\000\000\203\000\025\003\186\000\000\000\187\000\188\000\189\000\
\190\000\000\000\079\000\191\000\000\000\084\000\000\000\000\000\
\000\000\000\000\084\000\000\000\084\000\000\000\000\000\084\000\
\084\000\084\000\084\000\084\000\084\000\000\000\080\000\081\000\
\000\000\204\000\000\000\000\000\000\000\205\000\206\000\192\000\
\193\000\000\000\000\000\000\000\084\000\000\000\000\000\000\000\
\207\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\084\000\000\000\084\000\194\000\195\000\196\000\000\000\
\124\001\197\000\198\000\124\001\124\001\199\000\200\000\000\000\
\000\000\124\001\201\000\202\000\000\000\203\000\124\001\124\001\
\124\001\124\001\000\000\124\001\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\080\000\081\000\000\000\204\000\000\000\000\000\
\000\000\205\000\206\000\000\000\000\000\124\001\000\000\000\000\
\000\000\000\000\000\000\000\000\207\000\186\000\005\000\187\000\
\188\000\189\000\190\000\006\000\079\000\191\000\007\000\008\000\
\009\000\010\000\011\000\012\000\013\000\000\000\014\000\015\000\
\016\000\017\000\018\000\019\000\020\000\021\000\022\000\073\000\
\024\000\025\000\026\000\027\000\028\000\029\000\030\000\031\000\
\032\000\192\000\193\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\194\000\195\000\
\196\000\000\000\000\000\197\000\198\000\000\000\000\000\199\000\
\200\000\000\000\000\000\000\000\201\000\202\000\000\000\203\000\
\000\000\000\000\000\000\121\001\121\001\121\001\000\000\121\001\
\121\001\000\000\000\000\000\000\000\000\121\001\000\000\000\000\
\000\000\000\000\121\001\121\001\121\001\121\001\000\000\121\001\
\034\000\035\000\000\000\037\000\080\000\081\000\000\000\204\000\
\000\000\000\000\000\000\205\000\206\000\038\000\000\000\039\000\
\167\000\000\000\005\000\000\000\000\000\044\000\207\000\006\000\
\000\000\000\000\007\000\008\000\009\000\010\000\011\000\012\000\
\013\000\121\001\014\000\015\000\016\000\017\000\018\000\019\000\
\020\000\021\000\022\000\073\000\024\000\025\000\026\000\027\000\
\028\000\029\000\030\000\031\000\032\000\122\001\122\001\000\000\
\122\001\122\001\000\000\000\000\000\000\000\000\122\001\000\000\
\000\000\000\000\000\000\122\001\122\001\122\001\122\001\000\000\
\122\001\000\000\000\000\000\000\000\000\131\000\000\000\131\000\
\131\000\131\000\131\000\000\000\131\000\131\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\085\000\168\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\122\001\000\000\000\000\000\000\000\000\000\000\
\000\000\131\000\131\000\131\000\034\000\035\000\000\000\037\000\
\085\000\000\000\000\000\085\000\085\000\000\000\000\000\000\000\
\000\000\038\000\085\000\039\000\040\000\041\000\131\000\131\000\
\131\000\044\000\000\000\131\000\131\000\000\000\000\000\131\000\
\131\000\000\000\000\000\000\000\131\000\131\000\000\000\131\000\
\000\000\131\000\186\000\000\000\187\000\188\000\189\000\190\000\
\000\000\079\000\191\000\085\000\000\000\000\000\000\000\000\000\
\085\000\000\000\085\000\000\000\005\000\085\000\085\000\085\000\
\085\000\085\000\085\000\000\000\131\000\131\000\000\000\131\000\
\000\000\000\000\000\000\131\000\131\000\000\000\192\000\193\000\
\000\000\000\000\085\000\000\000\022\001\000\000\131\000\023\001\
\024\001\000\000\000\000\000\000\000\000\000\000\032\000\085\000\
\000\000\085\000\000\000\194\000\195\000\196\000\000\000\000\000\
\197\000\198\000\000\000\000\000\199\000\200\000\000\000\000\000\
\000\000\201\000\202\000\000\000\203\000\000\000\190\001\186\000\
\000\000\187\000\188\000\189\000\190\000\000\000\079\000\191\000\
\000\000\000\000\000\000\000\000\000\000\095\002\000\000\000\000\
\195\001\000\000\025\001\000\000\000\000\000\000\000\000\000\000\
\000\000\080\000\081\000\000\000\204\000\000\000\000\000\000\000\
\205\000\206\000\000\000\192\000\193\000\000\000\034\000\000\000\
\196\001\000\000\000\000\207\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\038\000\000\000\039\000\000\000\000\000\
\194\000\195\000\196\000\000\000\000\000\197\000\198\000\000\000\
\000\000\199\000\200\000\000\000\000\000\000\000\201\000\202\000\
\000\000\203\000\000\000\113\002\127\000\000\000\127\000\127\000\
\127\000\127\000\000\000\127\000\127\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\080\000\081\000\
\000\000\204\000\000\000\000\000\000\000\205\000\206\000\000\000\
\127\000\127\000\000\000\000\000\000\000\000\000\000\000\000\000\
\207\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\127\000\127\000\127\000\
\000\000\000\000\127\000\127\000\000\000\000\000\127\000\127\000\
\000\000\000\000\000\000\127\000\127\000\000\000\127\000\000\000\
\127\000\186\000\000\000\187\000\188\000\189\000\190\000\000\000\
\079\000\191\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\127\000\127\000\000\000\127\000\000\000\
\000\000\000\000\127\000\127\000\000\000\192\000\193\000\000\000\
\000\000\000\000\000\000\000\000\000\000\127\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\194\000\195\000\196\000\000\000\000\000\197\000\
\198\000\000\000\000\000\199\000\200\000\000\000\000\000\000\000\
\201\000\202\000\000\000\239\000\000\000\186\000\000\000\187\000\
\188\000\189\000\190\000\000\000\079\000\191\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\080\000\081\000\000\000\204\000\000\000\000\000\000\000\205\000\
\206\000\192\000\193\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\207\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\194\000\195\000\
\196\000\000\000\000\000\197\000\198\000\000\000\000\000\199\000\
\200\000\000\000\000\000\000\000\201\000\202\000\000\000\241\000\
\000\000\186\000\000\000\187\000\188\000\189\000\190\000\000\000\
\079\000\191\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\080\000\081\000\000\000\204\000\
\000\000\000\000\000\000\205\000\206\000\192\000\193\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\207\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\194\000\195\000\196\000\000\000\000\000\197\000\
\198\000\000\000\000\000\199\000\200\000\000\000\000\000\000\000\
\201\000\202\000\000\000\203\000\000\000\186\000\000\000\187\000\
\188\000\189\000\190\000\000\000\079\000\191\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\080\000\081\000\000\000\204\000\000\000\000\000\000\000\205\000\
\206\000\192\000\193\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\207\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\194\000\195\000\
\196\000\000\000\000\000\197\000\198\000\000\000\000\000\199\000\
\200\000\000\000\000\000\000\000\201\000\202\000\000\000\083\001\
\000\000\186\000\000\000\187\000\188\000\189\000\190\000\000\000\
\079\000\191\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\080\000\081\000\000\000\204\000\
\000\000\000\000\000\000\205\000\206\000\192\000\193\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\207\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\194\000\195\000\196\000\000\000\000\000\197\000\
\198\000\000\000\000\000\199\000\200\000\000\000\000\000\000\000\
\201\000\202\000\000\000\085\001\000\000\186\000\000\000\187\000\
\188\000\189\000\190\000\000\000\079\000\191\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\080\000\081\000\000\000\204\000\000\000\000\000\000\000\205\000\
\206\000\192\000\193\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\207\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\194\000\195\000\
\196\000\000\000\000\000\197\000\198\000\000\000\000\000\199\000\
\200\000\000\000\000\000\000\000\201\000\202\000\000\000\094\001\
\000\000\123\001\123\001\000\000\123\001\123\001\000\000\000\000\
\000\000\000\000\123\001\000\000\000\000\000\000\000\000\123\001\
\123\001\123\001\123\001\000\000\123\001\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\080\000\081\000\000\000\204\000\
\000\000\000\000\000\000\205\000\206\000\000\000\004\000\005\000\
\000\000\000\000\000\000\000\000\006\000\000\000\207\000\007\000\
\008\000\009\000\010\000\011\000\012\000\013\000\123\001\014\000\
\015\000\016\000\017\000\018\000\019\000\020\000\021\000\022\000\
\023\000\024\000\025\000\026\000\027\000\028\000\029\000\030\000\
\031\000\032\000\004\000\005\000\000\000\000\000\000\000\000\000\
\006\000\000\000\000\000\007\000\008\000\009\000\010\000\011\000\
\012\000\013\000\000\000\014\000\015\000\016\000\017\000\018\000\
\019\000\020\000\021\000\022\000\023\000\024\000\025\000\026\000\
\027\000\028\000\029\000\030\000\031\000\032\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\033\000\113\001\
\113\001\113\001\113\001\113\001\113\001\000\000\000\000\000\000\
\000\000\000\000\000\000\113\001\113\001\113\001\000\000\113\001\
\113\001\034\000\035\000\036\000\037\000\113\001\000\000\000\000\
\000\000\000\000\113\001\113\001\113\001\113\001\038\000\113\001\
\039\000\040\000\041\000\000\000\042\000\043\000\044\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\034\000\035\000\036\000\
\037\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\113\001\038\000\000\000\039\000\040\000\041\000\107\000\
\042\000\043\000\044\000\000\000\107\000\000\000\000\000\107\000\
\107\000\107\000\107\000\107\000\107\000\107\000\000\000\107\000\
\107\000\107\000\107\000\107\000\107\000\107\000\107\000\107\000\
\107\000\107\000\107\000\107\000\107\000\107\000\107\000\107\000\
\107\000\107\000\000\000\000\000\107\000\107\000\107\000\107\000\
\107\000\107\000\107\000\107\000\107\000\107\000\107\000\107\000\
\107\000\107\000\107\000\107\000\107\000\107\000\107\000\107\000\
\107\000\107\000\107\000\107\000\000\000\107\000\107\000\107\000\
\000\000\107\000\107\000\107\000\107\000\107\000\107\000\107\000\
\107\000\107\000\107\000\107\000\107\000\107\000\107\000\107\000\
\107\000\107\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\107\000\107\000\000\000\107\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\107\000\005\000\
\107\000\000\000\000\000\107\000\006\000\079\000\107\000\007\000\
\008\000\009\000\010\000\011\000\012\000\013\000\000\000\014\000\
\015\000\016\000\017\000\018\000\019\000\020\000\021\000\022\000\
\073\000\024\000\025\000\026\000\027\000\028\000\029\000\030\000\
\031\000\032\000\005\000\000\000\000\000\000\000\000\000\006\000\
\000\000\000\000\007\000\008\000\009\000\010\000\011\000\012\000\
\013\000\000\000\014\000\015\000\016\000\017\000\018\000\019\000\
\020\000\021\000\022\000\073\000\024\000\025\000\026\000\027\000\
\028\000\029\000\030\000\031\000\032\000\125\001\000\000\000\000\
\125\001\125\001\000\000\000\000\000\000\000\000\125\001\000\000\
\000\000\000\000\000\000\125\001\125\001\125\001\125\001\000\000\
\125\001\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\034\000\035\000\000\000\037\000\080\000\081\000\000\000\
\000\000\000\000\000\000\153\000\000\000\000\000\038\000\000\000\
\039\000\000\000\000\000\213\001\000\000\000\000\044\000\000\000\
\000\000\000\000\125\001\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\034\000\035\000\000\000\037\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\038\000\003\001\039\000\000\000\000\000\000\000\003\001\
\000\000\044\000\003\001\003\001\003\001\003\001\003\001\003\001\
\003\001\000\000\003\001\003\001\003\001\003\001\003\001\003\001\
\003\001\003\001\003\001\003\001\003\001\003\001\003\001\003\001\
\003\001\003\001\003\001\003\001\003\001\005\000\000\000\000\000\
\000\000\000\000\006\000\000\000\000\000\007\000\008\000\009\000\
\010\000\011\000\012\000\013\000\000\000\014\000\015\000\016\000\
\017\000\018\000\019\000\020\000\021\000\022\000\073\000\024\000\
\025\000\026\000\027\000\028\000\029\000\030\000\031\000\032\000\
\000\000\000\000\003\001\003\001\000\000\094\001\094\001\094\001\
\094\001\094\001\094\001\094\001\094\001\094\001\094\001\094\001\
\000\000\094\001\094\001\094\001\000\000\094\001\094\001\094\001\
\094\001\000\000\000\000\094\001\003\001\003\001\000\000\003\001\
\094\001\094\001\094\001\094\001\000\000\094\001\153\000\000\000\
\000\000\003\001\000\000\003\001\000\000\000\000\000\000\000\000\
\000\000\003\001\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\034\000\
\035\000\000\000\037\000\000\000\000\000\000\000\000\000\094\001\
\000\000\000\000\000\000\000\000\038\000\005\000\039\000\000\000\
\000\000\000\000\006\000\000\000\044\000\007\000\008\000\009\000\
\010\000\011\000\012\000\013\000\000\000\014\000\015\000\016\000\
\017\000\018\000\019\000\020\000\021\000\022\000\073\000\024\000\
\025\000\026\000\027\000\028\000\029\000\030\000\031\000\032\000\
\005\000\000\000\000\000\000\000\000\000\006\000\000\000\000\000\
\007\000\008\000\009\000\010\000\011\000\012\000\013\000\000\000\
\014\000\015\000\016\000\017\000\018\000\019\000\020\000\021\000\
\022\000\073\000\024\000\025\000\026\000\027\000\028\000\029\000\
\030\000\031\000\032\000\000\000\000\000\000\000\000\000\000\000\
\179\000\000\000\000\000\106\001\106\001\106\001\106\001\106\001\
\106\001\106\001\106\001\000\000\000\000\000\000\000\000\106\001\
\106\001\106\001\000\000\106\001\106\001\106\001\106\001\034\000\
\035\000\106\001\037\000\000\000\000\000\000\000\106\001\106\001\
\106\001\106\001\000\000\106\001\038\000\000\000\039\000\000\000\
\000\000\219\002\000\000\000\000\044\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\034\000\035\000\000\000\037\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\106\001\000\000\038\000\
\005\000\039\000\000\000\000\000\000\000\006\000\000\000\044\000\
\007\000\008\000\009\000\010\000\011\000\012\000\013\000\000\000\
\014\000\015\000\016\000\017\000\018\000\019\000\020\000\021\000\
\022\000\073\000\024\000\025\000\026\000\027\000\028\000\029\000\
\030\000\031\000\032\000\005\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\007\000\008\000\009\000\010\000\011\000\
\012\000\013\000\000\000\014\000\015\000\016\000\017\000\018\000\
\019\000\020\000\021\000\022\000\073\000\024\000\025\000\026\000\
\027\000\028\000\029\000\030\000\031\000\032\000\000\000\000\000\
\000\000\000\000\000\000\107\001\107\001\107\001\107\001\107\001\
\107\001\107\001\107\001\000\000\000\000\000\000\000\000\107\001\
\107\001\107\001\000\000\107\001\107\001\107\001\107\001\000\000\
\000\000\107\001\034\000\035\000\000\000\037\000\107\001\107\001\
\107\001\107\001\000\000\107\001\000\000\000\000\000\000\038\000\
\000\000\039\000\000\000\000\000\000\000\000\000\000\000\044\000\
\000\000\000\000\000\000\106\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\034\000\035\000\000\000\
\037\000\000\000\000\000\000\000\000\000\107\001\000\000\000\000\
\000\000\000\000\038\000\106\000\039\000\000\000\106\000\106\000\
\000\000\000\000\044\000\000\000\000\000\106\000\000\000\000\000\
\106\000\106\000\106\000\106\000\106\000\106\000\106\000\106\000\
\106\000\106\000\106\000\106\000\106\000\106\000\106\000\106\000\
\106\000\106\000\106\000\106\000\106\000\106\000\106\000\106\000\
\000\000\106\000\106\000\106\000\000\000\106\000\106\000\106\000\
\106\000\106\000\106\000\106\000\106\000\106\000\000\000\106\000\
\106\000\106\000\106\000\106\000\106\000\106\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\042\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\106\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\106\000\000\000\106\000\042\000\000\000\106\000\
\042\000\042\000\000\000\000\000\000\000\000\000\000\000\042\000\
\000\000\000\000\042\000\042\000\042\000\042\000\042\000\042\000\
\042\000\042\000\042\000\042\000\042\000\000\000\000\000\042\000\
\042\000\042\000\042\000\042\000\042\000\042\000\042\000\042\000\
\042\000\042\000\000\000\042\000\042\000\042\000\000\000\042\000\
\042\000\042\000\042\000\000\000\000\000\042\000\000\000\042\000\
\000\000\000\000\042\000\042\000\042\000\042\000\042\000\042\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\046\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\042\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\042\000\000\000\042\000\046\000\
\000\000\042\000\046\000\046\000\000\000\000\000\000\000\000\000\
\000\000\046\000\000\000\000\000\046\000\046\000\046\000\046\000\
\046\000\046\000\046\000\046\000\046\000\046\000\046\000\000\000\
\000\000\046\000\046\000\046\000\046\000\046\000\046\000\046\000\
\046\000\046\000\046\000\046\000\000\000\046\000\046\000\046\000\
\000\000\046\000\046\000\046\000\046\000\000\000\000\000\046\000\
\000\000\046\000\000\000\000\000\046\000\046\000\046\000\046\000\
\046\000\046\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\048\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\046\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\046\000\000\000\
\046\000\048\000\000\000\046\000\048\000\048\000\000\000\000\000\
\000\000\000\000\000\000\048\000\000\000\000\000\048\000\048\000\
\048\000\048\000\048\000\048\000\048\000\048\000\048\000\048\000\
\048\000\000\000\000\000\048\000\048\000\048\000\048\000\048\000\
\048\000\048\000\048\000\048\000\048\000\048\000\000\000\048\000\
\048\000\048\000\000\000\048\000\048\000\048\000\048\000\000\000\
\000\000\048\000\058\000\048\000\000\000\000\000\048\000\048\000\
\048\000\048\000\048\000\048\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\058\000\048\000\000\000\058\000\058\000\000\000\
\000\000\000\000\000\000\000\000\058\000\000\000\000\000\000\000\
\048\000\000\000\048\000\000\000\000\000\048\000\000\000\000\000\
\000\000\000\000\000\000\000\000\058\000\058\000\058\000\058\000\
\058\000\058\000\058\000\058\000\058\000\058\000\058\000\000\000\
\058\000\058\000\058\000\062\000\058\000\058\000\058\000\058\000\
\000\000\000\000\058\000\000\000\058\000\000\000\000\000\058\000\
\058\000\058\000\058\000\058\000\058\000\000\000\000\000\000\000\
\000\000\000\000\000\000\062\000\000\000\000\000\062\000\062\000\
\000\000\000\000\000\000\000\000\058\000\062\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\058\000\000\000\058\000\000\000\062\000\062\000\062\000\
\062\000\062\000\062\000\062\000\062\000\000\000\000\000\000\000\
\000\000\062\000\062\000\062\000\063\000\062\000\062\000\062\000\
\062\000\000\000\000\000\062\000\000\000\062\000\000\000\000\000\
\062\000\062\000\062\000\062\000\062\000\062\000\000\000\000\000\
\000\000\000\000\000\000\000\000\063\000\000\000\000\000\063\000\
\063\000\000\000\000\000\000\000\000\000\062\000\063\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\062\000\000\000\062\000\000\000\063\000\063\000\
\063\000\063\000\063\000\063\000\063\000\063\000\000\000\000\000\
\000\000\000\000\063\000\063\000\063\000\064\000\063\000\063\000\
\063\000\063\000\000\000\000\000\063\000\000\000\063\000\000\000\
\000\000\063\000\063\000\063\000\063\000\063\000\063\000\000\000\
\000\000\000\000\000\000\000\000\000\000\064\000\000\000\000\000\
\064\000\064\000\000\000\000\000\000\000\000\000\063\000\064\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\063\000\000\000\063\000\000\000\064\000\
\064\000\064\000\064\000\064\000\064\000\064\000\064\000\000\000\
\000\000\000\000\000\000\064\000\064\000\064\000\065\000\064\000\
\064\000\064\000\064\000\000\000\000\000\064\000\000\000\064\000\
\000\000\000\000\064\000\064\000\064\000\064\000\064\000\064\000\
\000\000\000\000\000\000\000\000\000\000\000\000\065\000\000\000\
\000\000\065\000\065\000\000\000\000\000\000\000\000\000\064\000\
\065\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\064\000\000\000\064\000\000\000\
\065\000\065\000\065\000\065\000\065\000\065\000\000\000\000\000\
\000\000\000\000\000\000\000\000\065\000\065\000\065\000\066\000\
\065\000\065\000\065\000\065\000\000\000\000\000\065\000\000\000\
\065\000\000\000\000\000\065\000\065\000\065\000\065\000\065\000\
\065\000\000\000\000\000\000\000\000\000\000\000\000\000\066\000\
\000\000\000\000\066\000\066\000\000\000\000\000\000\000\000\000\
\065\000\066\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\065\000\000\000\065\000\
\000\000\066\000\066\000\066\000\066\000\066\000\066\000\000\000\
\000\000\000\000\000\000\000\000\000\000\066\000\066\000\066\000\
\067\000\066\000\066\000\066\000\066\000\000\000\000\000\066\000\
\000\000\066\000\000\000\000\000\066\000\066\000\066\000\066\000\
\066\000\066\000\000\000\000\000\000\000\000\000\000\000\000\000\
\067\000\000\000\000\000\067\000\067\000\000\000\000\000\000\000\
\000\000\066\000\067\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\066\000\000\000\
\066\000\000\000\067\000\067\000\067\000\067\000\067\000\067\000\
\000\000\000\000\000\000\000\000\000\000\000\000\067\000\067\000\
\067\000\068\000\067\000\067\000\067\000\067\000\000\000\000\000\
\067\000\000\000\067\000\000\000\000\000\067\000\067\000\067\000\
\067\000\067\000\067\000\000\000\000\000\000\000\000\000\000\000\
\000\000\068\000\000\000\000\000\068\000\068\000\000\000\000\000\
\000\000\000\000\067\000\068\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\067\000\
\000\000\067\000\000\000\068\000\068\000\068\000\068\000\068\000\
\068\000\000\000\000\000\000\000\000\000\000\000\000\000\068\000\
\068\000\068\000\069\000\068\000\068\000\000\000\000\000\000\000\
\000\000\068\000\000\000\068\000\000\000\000\000\068\000\068\000\
\068\000\068\000\068\000\068\000\000\000\000\000\000\000\000\000\
\000\000\000\000\069\000\000\000\000\000\069\000\069\000\000\000\
\000\000\000\000\000\000\068\000\069\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\068\000\000\000\068\000\000\000\069\000\069\000\069\000\069\000\
\069\000\069\000\000\000\000\000\000\000\000\000\000\000\000\000\
\069\000\069\000\069\000\070\000\069\000\069\000\000\000\000\000\
\000\000\000\000\069\000\000\000\069\000\000\000\000\000\069\000\
\069\000\069\000\069\000\069\000\069\000\000\000\000\000\000\000\
\000\000\000\000\000\000\070\000\000\000\000\000\070\000\070\000\
\000\000\000\000\000\000\000\000\069\000\070\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\069\000\000\000\069\000\000\000\070\000\070\000\070\000\
\070\000\070\000\070\000\000\000\000\000\000\000\000\000\000\000\
\000\000\070\000\070\000\070\000\071\000\070\000\070\000\000\000\
\000\000\000\000\000\000\070\000\000\000\070\000\000\000\000\000\
\070\000\070\000\070\000\070\000\070\000\070\000\000\000\000\000\
\000\000\000\000\000\000\000\000\071\000\000\000\000\000\071\000\
\071\000\000\000\000\000\000\000\000\000\070\000\071\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\070\000\000\000\070\000\000\000\071\000\071\000\
\071\000\071\000\071\000\071\000\000\000\000\000\000\000\000\000\
\000\000\000\000\071\000\071\000\071\000\072\000\071\000\071\000\
\000\000\000\000\000\000\000\000\071\000\000\000\071\000\000\000\
\000\000\071\000\071\000\071\000\071\000\071\000\071\000\000\000\
\000\000\000\000\000\000\000\000\000\000\072\000\000\000\000\000\
\072\000\072\000\000\000\000\000\000\000\000\000\071\000\072\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\071\000\000\000\071\000\000\000\072\000\
\072\000\072\000\072\000\072\000\072\000\000\000\000\000\000\000\
\073\000\000\000\000\000\072\000\072\000\072\000\000\000\072\000\
\072\000\000\000\000\000\000\000\000\000\072\000\000\000\072\000\
\000\000\000\000\072\000\072\000\072\000\072\000\072\000\072\000\
\073\000\000\000\000\000\073\000\073\000\000\000\000\000\000\000\
\000\000\000\000\073\000\000\000\000\000\000\000\000\000\072\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\073\000\073\000\072\000\000\000\072\000\000\000\
\000\000\000\000\000\000\074\000\000\000\000\000\073\000\073\000\
\073\000\000\000\073\000\073\000\000\000\000\000\000\000\000\000\
\073\000\000\000\073\000\000\000\000\000\073\000\073\000\073\000\
\073\000\073\000\073\000\074\000\000\000\000\000\074\000\074\000\
\000\000\000\000\000\000\000\000\000\000\074\000\000\000\000\000\
\000\000\000\000\073\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\074\000\074\000\073\000\
\000\000\073\000\000\000\000\000\000\000\000\000\075\000\000\000\
\000\000\074\000\074\000\074\000\000\000\074\000\074\000\000\000\
\000\000\000\000\000\000\074\000\000\000\074\000\000\000\000\000\
\074\000\074\000\074\000\074\000\074\000\074\000\075\000\000\000\
\000\000\075\000\075\000\000\000\000\000\000\000\000\000\000\000\
\075\000\000\000\000\000\000\000\000\000\074\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\075\000\075\000\074\000\000\000\074\000\000\000\000\000\000\000\
\000\000\076\000\000\000\000\000\075\000\075\000\075\000\000\000\
\075\000\075\000\000\000\000\000\000\000\000\000\075\000\000\000\
\075\000\000\000\000\000\075\000\075\000\075\000\075\000\075\000\
\075\000\076\000\000\000\000\000\076\000\076\000\000\000\000\000\
\000\000\000\000\000\000\076\000\000\000\000\000\000\000\000\000\
\075\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\075\000\000\000\075\000\
\000\000\000\000\000\000\000\000\077\000\000\000\000\000\076\000\
\076\000\076\000\000\000\076\000\076\000\000\000\000\000\000\000\
\000\000\076\000\000\000\076\000\000\000\000\000\076\000\076\000\
\076\000\076\000\076\000\076\000\077\000\000\000\000\000\077\000\
\077\000\000\000\000\000\000\000\000\000\000\000\077\000\000\000\
\000\000\000\000\000\000\076\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\076\000\000\000\076\000\000\000\000\000\000\000\000\000\078\000\
\000\000\000\000\077\000\077\000\077\000\000\000\077\000\077\000\
\000\000\000\000\000\000\000\000\077\000\000\000\077\000\000\000\
\000\000\077\000\077\000\077\000\077\000\077\000\077\000\078\000\
\000\000\000\000\078\000\078\000\000\000\000\000\000\000\000\000\
\000\000\078\000\000\000\000\000\000\000\000\000\077\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\077\000\000\000\077\000\000\000\000\000\
\000\000\000\000\079\000\000\000\000\000\000\000\078\000\078\000\
\000\000\078\000\078\000\000\000\000\000\000\000\000\000\078\000\
\000\000\078\000\000\000\000\000\078\000\078\000\078\000\078\000\
\078\000\078\000\079\000\000\000\000\000\079\000\079\000\118\001\
\118\001\000\000\000\000\000\000\079\000\000\000\000\000\000\000\
\000\000\078\000\000\000\118\001\118\001\118\001\000\000\118\001\
\118\001\000\000\000\000\000\000\000\000\118\001\078\000\000\000\
\078\000\000\000\118\001\118\001\118\001\118\001\000\000\118\001\
\000\000\079\000\079\000\000\000\079\000\079\000\231\000\096\000\
\000\000\000\000\079\000\097\000\079\000\098\000\079\000\079\000\
\079\000\079\000\079\000\079\000\079\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\099\000\118\001\000\000\100\000\079\000\000\000\000\000\000\000\
\000\000\000\000\000\000\101\000\102\000\231\000\096\000\000\000\
\000\000\079\000\097\000\079\000\098\000\079\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\103\000\104\000\105\000\000\000\000\000\106\000\107\000\099\000\
\000\000\108\000\100\000\000\000\000\000\000\000\000\000\000\000\
\153\001\109\000\101\000\102\000\000\000\000\000\000\000\000\000\
\078\001\096\000\000\000\000\000\000\000\097\000\000\000\098\000\
\079\000\110\000\000\000\000\000\000\000\000\000\000\000\103\000\
\104\000\105\000\000\000\000\000\106\000\107\000\080\000\081\000\
\108\000\000\000\099\000\000\000\000\000\100\000\000\000\000\000\
\109\000\000\000\000\000\000\000\000\000\101\000\102\000\037\002\
\096\000\000\000\000\000\000\000\097\000\000\000\098\000\079\000\
\110\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\103\000\104\000\105\000\080\000\081\000\106\000\
\107\000\099\000\000\000\108\000\100\000\000\000\000\000\000\000\
\000\000\000\000\000\000\109\000\101\000\102\000\000\000\000\000\
\000\000\000\000\000\000\096\000\000\000\000\000\000\000\097\000\
\000\000\098\000\079\000\110\000\000\000\000\000\000\000\000\000\
\000\000\103\000\104\000\105\000\000\000\000\000\106\000\107\000\
\080\000\081\000\108\000\000\000\099\000\000\000\000\000\100\000\
\000\000\000\000\109\000\000\000\000\000\000\000\000\000\101\000\
\102\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\110\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\103\000\104\000\105\000\080\000\
\081\000\106\000\107\000\000\000\000\000\108\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\109\000\000\000\000\000\
\000\000\000\000\108\001\108\001\108\001\108\001\108\001\108\001\
\108\001\108\001\000\000\000\000\000\000\110\000\108\001\108\001\
\108\001\000\000\108\001\108\001\108\001\108\001\000\000\000\000\
\108\001\000\000\080\000\081\000\000\000\108\001\108\001\108\001\
\108\001\000\000\108\001\109\001\109\001\109\001\109\001\109\001\
\109\001\000\000\000\000\000\000\000\000\000\000\000\000\109\001\
\109\001\109\001\000\000\109\001\109\001\109\001\109\001\000\000\
\000\000\109\001\000\000\000\000\000\000\000\000\109\001\109\001\
\109\001\109\001\000\000\109\001\108\001\000\000\110\001\110\001\
\110\001\110\001\110\001\110\001\000\000\000\000\000\000\000\000\
\000\000\000\000\110\001\110\001\110\001\000\000\110\001\110\001\
\110\001\110\001\000\000\000\000\110\001\000\000\000\000\000\000\
\000\000\110\001\110\001\110\001\110\001\109\001\110\001\111\001\
\111\001\111\001\111\001\111\001\111\001\000\000\000\000\000\000\
\000\000\000\000\000\000\111\001\111\001\111\001\000\000\111\001\
\111\001\111\001\111\001\000\000\000\000\111\001\000\000\000\000\
\000\000\000\000\111\001\111\001\111\001\111\001\000\000\111\001\
\110\001\000\000\114\001\114\001\114\001\114\001\114\001\114\001\
\000\000\000\000\000\000\000\000\000\000\000\000\114\001\114\001\
\114\001\000\000\114\001\114\001\000\000\000\000\000\000\000\000\
\114\001\000\000\000\000\000\000\000\000\114\001\114\001\114\001\
\114\001\111\001\114\001\115\001\115\001\115\001\115\001\115\001\
\115\001\000\000\000\000\000\000\000\000\000\000\000\000\115\001\
\115\001\115\001\000\000\115\001\115\001\000\000\000\000\000\000\
\000\000\115\001\000\000\000\000\000\000\000\000\115\001\115\001\
\115\001\115\001\000\000\115\001\114\001\000\000\116\001\116\001\
\116\001\116\001\116\001\116\001\000\000\000\000\000\000\000\000\
\000\000\000\000\116\001\116\001\116\001\000\000\116\001\116\001\
\000\000\000\000\000\000\000\000\116\001\119\001\119\001\000\000\
\000\000\116\001\116\001\116\001\116\001\115\001\116\001\000\000\
\000\000\119\001\119\001\119\001\000\000\119\001\119\001\000\000\
\000\000\000\000\000\000\119\001\000\000\000\000\000\000\000\000\
\119\001\119\001\119\001\119\001\000\000\119\001\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\116\001\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\119\001\
\023\000\023\000\023\000\023\000\023\000\023\000\023\000\023\000\
\023\000\023\000\023\000\023\000\023\000\023\000\023\000\023\000\
\023\000\023\000\023\000\023\000\023\000\023\000\023\000\023\000\
\000\000\023\000\023\000\023\000\000\000\023\000\023\000\023\000\
\023\000\023\000\023\000\000\000\023\000\023\000\000\000\023\000\
\000\000\018\000\000\000\023\000\000\000\023\000\023\000\023\000\
\023\000\023\000\023\000\023\000\023\000\023\000\023\000\023\000\
\023\000\023\000\023\000\023\000\023\000\023\000\023\000\023\000\
\023\000\023\000\023\000\023\000\023\000\023\000\000\000\023\000\
\023\000\023\000\000\000\023\000\023\000\023\000\023\000\023\000\
\023\000\000\000\023\000\000\000\000\000\023\000\000\000\000\000\
\023\000\023\000\000\000\023\000"

let yycheck = "\023\000\
\053\000\093\000\001\000\002\000\154\000\031\001\033\000\143\000\
\082\000\004\000\033\001\065\000\018\001\133\000\153\000\049\000\
\000\000\041\000\001\000\002\000\049\000\048\000\198\001\000\000\
\000\000\040\001\056\001\057\001\083\000\000\001\163\000\164\000\
\081\001\016\000\033\000\203\000\076\000\129\000\183\000\000\001\
\023\000\024\000\096\000\041\000\027\000\028\000\000\001\000\001\
\154\000\048\000\033\000\136\002\035\000\001\001\073\002\014\000\
\015\000\076\002\017\000\007\001\079\002\000\001\159\002\213\000\
\075\001\048\000\008\001\050\000\092\000\118\001\094\000\239\000\
\055\000\241\000\057\000\000\001\051\001\060\000\127\002\103\000\
\104\000\105\000\106\000\107\000\108\000\109\000\171\002\028\001\
\001\001\069\001\073\000\032\001\001\001\001\001\050\001\051\001\
\075\001\060\001\007\001\082\000\001\001\060\001\001\001\078\001\
\084\001\076\001\007\001\213\000\007\001\068\000\093\000\109\000\
\060\001\072\000\211\002\075\001\077\001\080\001\081\001\078\000\
\154\000\080\001\078\001\077\001\077\001\154\000\074\001\075\001\
\168\000\128\000\078\001\171\000\172\000\173\000\082\001\060\001\
\176\000\177\000\077\001\188\002\077\002\079\001\001\001\001\001\
\082\001\128\000\180\000\060\001\007\001\007\001\203\000\060\001\
\179\000\076\001\001\001\001\001\253\002\212\000\081\001\183\000\
\007\001\007\001\104\001\105\001\028\001\048\001\075\001\075\001\
\032\001\033\001\153\000\083\001\203\000\085\001\075\001\123\001\
\199\001\097\002\077\001\194\001\179\000\058\001\094\001\075\001\
\213\000\075\001\239\000\210\001\241\000\208\002\100\001\103\001\
\104\001\223\001\213\002\031\001\179\000\103\000\104\000\105\000\
\106\000\107\000\108\000\113\001\076\001\008\001\001\001\001\001\
\239\000\081\001\241\000\235\000\007\001\007\001\123\001\051\001\
\153\002\097\001\077\001\156\002\203\000\077\001\123\001\160\002\
\123\001\061\001\077\001\008\001\009\001\075\001\077\001\255\000\
\000\001\001\001\002\001\003\001\004\001\005\001\006\001\007\001\
\008\001\009\001\010\001\011\001\012\001\013\001\014\001\015\001\
\016\001\017\001\018\001\029\001\075\001\026\001\195\001\079\001\
\239\000\255\000\241\000\083\001\197\002\150\001\151\001\001\001\
\123\001\123\001\102\001\204\002\209\001\007\001\211\001\015\000\
\000\001\017\000\060\001\059\001\123\001\123\001\062\001\000\001\
\000\001\075\001\077\001\000\000\078\001\055\002\083\001\071\001\
\085\001\075\001\001\001\075\001\078\001\043\002\253\000\254\000\
\007\001\094\001\075\001\008\001\002\001\104\001\105\001\001\001\
\001\001\100\001\243\002\076\001\083\001\007\001\085\001\000\001\
\253\001\082\001\251\002\042\001\001\001\113\002\113\001\094\001\
\001\001\048\001\007\001\104\001\105\001\069\000\001\001\000\001\
\123\001\123\001\011\003\195\001\007\001\129\002\036\001\199\001\
\074\001\075\001\001\000\002\000\078\001\116\001\117\001\001\001\
\082\001\209\001\210\001\211\001\076\001\007\001\000\001\001\001\
\002\001\060\001\190\001\001\001\083\001\069\001\085\001\000\001\
\001\001\131\002\075\001\060\001\075\001\074\001\007\001\094\001\
\064\001\000\001\001\001\080\001\084\001\148\001\081\001\060\001\
\103\001\104\001\075\001\077\001\075\001\001\001\150\001\151\001\
\081\001\123\001\204\001\007\001\077\001\253\001\075\001\227\001\
\081\001\078\001\074\001\104\001\105\001\000\001\100\001\074\001\
\075\001\077\001\082\001\078\001\051\001\203\001\077\001\082\001\
\001\001\112\001\113\001\113\001\123\001\115\001\007\001\193\001\
\074\001\075\001\103\002\060\001\078\001\077\001\074\001\000\001\
\082\001\123\001\123\001\074\001\206\001\060\001\082\001\078\001\
\026\001\074\001\075\001\029\001\039\001\078\001\123\001\080\001\
\081\001\082\001\066\002\074\001\075\001\229\001\074\001\078\001\
\123\001\080\001\081\001\082\001\079\001\066\001\082\001\082\001\
\094\002\077\001\023\003\115\002\116\002\204\001\039\001\101\000\
\102\000\123\001\031\003\074\001\048\002\244\001\245\001\198\001\
\211\001\080\001\077\001\055\002\039\001\204\001\081\001\082\001\
\100\001\119\002\123\001\074\001\077\001\000\001\065\001\190\001\
\000\001\080\001\058\001\059\001\123\001\113\001\074\002\103\002\
\083\002\074\001\085\002\080\001\077\001\088\002\083\001\123\001\
\081\001\082\001\000\001\100\001\002\001\080\001\195\002\074\001\
\194\000\195\000\196\000\197\000\198\000\199\000\081\001\082\001\
\113\001\083\002\074\001\085\002\039\001\080\001\088\002\079\001\
\080\001\081\001\123\001\043\002\026\001\113\002\068\001\029\001\
\030\001\145\002\075\001\080\002\059\002\078\001\036\001\060\001\
\061\001\062\001\126\002\001\001\060\002\129\002\082\001\131\002\
\074\001\072\002\192\000\193\000\078\001\070\001\071\001\074\001\
\082\001\002\001\077\001\201\000\202\000\077\001\081\001\082\001\
\106\001\081\001\082\001\081\001\094\002\060\001\061\001\062\001\
\074\001\094\002\081\001\098\002\039\001\079\001\080\001\081\001\
\082\001\026\001\080\001\195\002\029\001\030\001\198\002\054\001\
\055\001\056\001\057\001\036\001\083\002\159\002\085\002\207\002\
\047\002\088\002\119\002\074\001\075\001\082\001\100\001\078\001\
\081\001\189\002\125\002\082\001\083\002\060\001\085\002\082\001\
\016\000\088\002\074\001\113\001\118\001\115\001\052\001\053\001\
\024\000\205\002\097\002\027\000\028\000\074\001\149\002\058\001\
\059\001\152\002\075\001\035\000\039\001\078\001\125\002\080\001\
\159\002\070\001\071\001\082\001\115\002\116\002\052\001\053\001\
\170\002\054\001\055\001\056\001\057\001\001\001\125\002\055\000\
\077\001\057\000\081\001\100\001\076\001\102\001\000\001\001\001\
\077\001\136\002\113\002\052\001\053\001\077\001\117\002\001\001\
\113\001\214\002\115\001\137\001\138\001\139\001\140\001\064\001\
\065\001\066\001\129\002\068\001\069\001\097\001\098\001\076\001\
\159\002\074\001\081\001\082\001\211\002\074\001\079\001\080\001\
\081\001\082\001\022\003\084\001\171\002\050\001\051\001\244\002\
\130\001\131\001\132\001\133\001\134\001\135\001\136\001\137\001\
\138\001\139\001\140\001\141\001\142\001\143\001\144\001\145\001\
\146\001\147\001\074\001\072\001\073\001\075\001\075\001\081\001\
\082\001\078\001\081\001\082\001\075\001\118\001\253\002\075\001\
\000\001\001\001\002\001\007\001\008\001\009\001\010\001\007\001\
\162\002\163\002\010\001\011\001\012\001\013\001\014\001\015\001\
\016\001\009\003\018\001\019\001\020\001\021\001\022\001\023\001\
\024\001\025\001\026\001\027\001\028\001\029\001\030\001\031\001\
\032\001\033\001\034\001\035\001\036\001\050\001\051\001\052\001\
\053\001\054\001\055\001\056\001\057\001\058\001\059\001\060\001\
\061\001\062\001\075\001\064\001\065\001\066\001\074\001\068\001\
\069\001\070\001\071\001\074\001\060\001\074\001\133\001\134\001\
\066\001\078\001\079\001\080\001\081\001\082\001\064\001\084\001\
\135\001\136\001\074\001\075\001\141\001\142\001\078\001\065\001\
\080\001\081\001\082\001\003\001\004\001\247\001\039\001\040\001\
\041\001\042\001\043\001\044\001\045\001\046\001\047\001\048\001\
\049\001\005\001\006\001\068\001\100\001\101\001\082\001\103\001\
\074\001\118\001\011\001\012\001\005\001\005\001\074\001\005\001\
\118\001\113\001\076\001\115\001\076\001\074\001\000\001\001\001\
\002\001\121\001\001\001\123\001\076\001\007\001\001\001\110\001\
\010\001\011\001\012\001\013\001\014\001\015\001\016\001\074\001\
\018\001\019\001\020\001\021\001\022\001\023\001\024\001\025\001\
\026\001\027\001\028\001\029\001\030\001\031\001\032\001\033\001\
\034\001\035\001\036\001\050\001\051\001\052\001\053\001\054\001\
\055\001\056\001\057\001\058\001\059\001\060\001\061\001\062\001\
\074\001\064\001\065\001\066\001\076\001\068\001\069\001\070\001\
\071\001\080\001\060\001\074\001\082\001\074\001\081\001\078\001\
\079\001\076\001\081\001\082\001\076\001\084\001\076\001\076\001\
\074\001\075\001\081\001\076\001\078\001\074\001\080\001\081\001\
\082\001\119\001\120\001\121\001\122\001\123\001\124\001\125\001\
\126\001\127\001\128\001\129\001\082\001\074\001\074\001\074\001\
\001\001\123\002\100\001\101\001\075\001\103\001\074\001\118\001\
\074\001\079\001\001\001\080\001\001\001\075\001\081\001\113\001\
\081\001\115\001\082\001\000\001\001\001\002\001\078\001\121\001\
\076\001\123\001\007\001\076\001\076\001\010\001\011\001\012\001\
\013\001\014\001\015\001\016\001\076\001\018\001\019\001\020\001\
\021\001\022\001\023\001\024\001\025\001\026\001\027\001\028\001\
\029\001\030\001\031\001\032\001\033\001\034\001\035\001\036\001\
\074\001\074\001\052\001\053\001\054\001\055\001\056\001\057\001\
\058\001\059\001\060\001\061\001\062\001\074\001\064\001\065\001\
\066\001\082\001\068\001\069\001\070\001\071\001\082\001\060\001\
\074\001\074\001\082\001\082\001\074\001\079\001\080\001\081\001\
\082\001\039\001\084\001\079\001\076\001\074\001\075\001\080\001\
\082\001\078\001\077\001\080\001\081\001\082\001\077\001\077\001\
\082\001\074\001\074\001\080\001\074\001\080\001\075\001\081\001\
\075\001\075\001\081\001\076\001\080\001\074\001\076\001\100\001\
\101\001\081\001\103\001\082\001\118\001\081\001\079\001\074\001\
\074\001\081\001\081\001\080\001\113\001\074\001\115\001\079\001\
\000\001\001\001\002\001\076\001\121\001\074\001\123\001\007\001\
\092\001\074\001\010\001\011\001\012\001\013\001\014\001\015\001\
\016\001\076\001\018\001\019\001\020\001\021\001\022\001\023\001\
\024\001\025\001\026\001\027\001\028\001\029\001\030\001\031\001\
\032\001\033\001\034\001\035\001\036\001\076\001\081\001\052\001\
\053\001\054\001\055\001\056\001\057\001\058\001\059\001\060\001\
\061\001\062\001\081\001\064\001\065\001\066\001\099\001\068\001\
\069\001\070\001\071\001\008\001\060\001\074\001\001\001\079\001\
\081\001\080\001\079\001\080\001\081\001\082\001\081\001\084\001\
\080\001\078\001\074\001\075\001\074\001\074\001\078\001\001\001\
\080\001\081\001\082\001\082\001\080\001\079\001\081\001\000\001\
\001\001\075\001\003\001\004\001\005\001\006\001\007\001\008\001\
\009\001\080\001\068\001\069\001\100\001\101\001\074\001\103\001\
\074\001\118\001\074\001\082\001\074\001\079\001\080\001\081\001\
\082\001\113\001\084\001\115\001\076\001\000\001\081\001\074\001\
\074\001\121\001\074\001\123\001\037\001\038\001\039\001\068\001\
\069\001\076\001\074\001\076\001\078\001\074\001\076\001\075\001\
\074\001\080\001\079\001\080\001\081\001\082\001\076\001\084\001\
\081\001\058\001\059\001\060\001\118\001\081\001\063\001\064\001\
\076\001\076\001\067\001\068\001\081\001\074\001\079\001\072\001\
\073\001\074\001\075\001\081\001\077\001\078\001\079\001\074\001\
\081\001\082\001\074\001\074\001\074\001\002\000\128\000\199\001\
\182\002\118\001\188\002\052\001\029\001\064\002\228\001\140\000\
\143\001\063\002\144\001\098\002\145\001\123\002\146\001\104\001\
\105\001\198\002\107\001\247\002\147\001\160\000\111\001\112\001\
\214\001\170\002\013\001\015\001\014\001\013\003\031\003\016\001\
\015\003\122\001\123\001\000\001\001\001\002\001\003\001\004\001\
\005\001\006\001\007\001\008\001\009\001\010\001\011\001\012\001\
\013\001\014\001\015\001\016\001\255\255\018\001\019\001\020\001\
\021\001\022\001\023\001\024\001\025\001\026\001\027\001\028\001\
\029\001\030\001\031\001\032\001\033\001\034\001\035\001\036\001\
\037\001\038\001\017\001\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\058\001\059\001\060\001\
\255\255\255\255\063\001\064\001\255\255\255\255\067\001\068\001\
\255\255\255\255\255\255\072\001\073\001\255\255\075\001\076\001\
\077\001\255\255\255\255\255\255\081\001\255\255\255\255\255\255\
\085\001\086\001\087\001\088\001\089\001\090\001\091\001\092\001\
\093\001\094\001\095\001\096\001\255\255\255\255\255\255\100\001\
\101\001\102\001\103\001\104\001\105\001\255\255\107\001\255\255\
\255\255\110\001\111\001\112\001\113\001\114\001\115\001\116\001\
\117\001\255\255\255\255\255\255\121\001\122\001\000\001\001\001\
\002\001\003\001\004\001\005\001\006\001\007\001\008\001\009\001\
\010\001\011\001\012\001\013\001\014\001\015\001\016\001\255\255\
\018\001\019\001\020\001\021\001\022\001\023\001\024\001\025\001\
\026\001\027\001\028\001\029\001\030\001\031\001\032\001\033\001\
\034\001\035\001\036\001\037\001\038\001\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\058\001\059\001\060\001\255\255\255\255\063\001\064\001\255\255\
\255\255\067\001\068\001\255\255\255\255\255\255\072\001\073\001\
\255\255\075\001\076\001\077\001\255\255\255\255\255\255\081\001\
\255\255\255\255\255\255\085\001\086\001\087\001\088\001\089\001\
\090\001\091\001\092\001\093\001\094\001\095\001\096\001\255\255\
\255\255\255\255\100\001\101\001\102\001\103\001\104\001\105\001\
\255\255\107\001\255\255\255\255\255\255\111\001\112\001\113\001\
\114\001\115\001\116\001\117\001\255\255\255\255\255\255\121\001\
\122\001\000\001\001\001\002\001\003\001\004\001\005\001\006\001\
\007\001\008\001\009\001\010\001\011\001\012\001\013\001\014\001\
\015\001\016\001\255\255\018\001\019\001\020\001\021\001\022\001\
\023\001\024\001\025\001\026\001\027\001\028\001\029\001\030\001\
\031\001\032\001\033\001\034\001\035\001\036\001\037\001\038\001\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\058\001\059\001\060\001\255\255\255\255\
\063\001\064\001\255\255\255\255\067\001\068\001\255\255\255\255\
\255\255\072\001\073\001\255\255\075\001\076\001\077\001\255\255\
\255\255\255\255\081\001\255\255\255\255\255\255\085\001\086\001\
\087\001\088\001\089\001\090\001\091\001\092\001\093\001\094\001\
\095\001\096\001\255\255\255\255\255\255\100\001\101\001\102\001\
\103\001\104\001\105\001\255\255\107\001\255\255\255\255\255\255\
\111\001\112\001\113\001\114\001\115\001\116\001\117\001\255\255\
\255\255\255\255\121\001\122\001\000\001\001\001\002\001\003\001\
\004\001\005\001\006\001\007\001\008\001\009\001\010\001\011\001\
\012\001\013\001\014\001\015\001\016\001\255\255\018\001\019\001\
\020\001\021\001\022\001\023\001\024\001\025\001\026\001\027\001\
\028\001\029\001\030\001\031\001\032\001\033\001\034\001\035\001\
\036\001\037\001\038\001\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\058\001\059\001\
\060\001\255\255\255\255\063\001\064\001\255\255\255\255\067\001\
\068\001\255\255\255\255\255\255\072\001\073\001\255\255\075\001\
\255\255\077\001\255\255\255\255\255\255\081\001\255\255\255\255\
\255\255\085\001\086\001\087\001\088\001\089\001\090\001\091\001\
\092\001\093\001\094\001\095\001\096\001\255\255\255\255\255\255\
\100\001\101\001\102\001\103\001\104\001\105\001\255\255\107\001\
\255\255\255\255\255\255\111\001\112\001\113\001\114\001\115\001\
\116\001\117\001\255\255\255\255\255\255\121\001\122\001\000\001\
\001\001\002\001\003\001\004\001\005\001\006\001\007\001\008\001\
\009\001\010\001\011\001\012\001\013\001\014\001\015\001\016\001\
\255\255\018\001\019\001\020\001\021\001\022\001\023\001\024\001\
\025\001\026\001\027\001\028\001\029\001\030\001\031\001\032\001\
\033\001\034\001\035\001\036\001\037\001\038\001\069\001\255\255\
\255\255\255\255\255\255\074\001\255\255\255\255\255\255\255\255\
\079\001\080\001\081\001\082\001\255\255\084\001\255\255\255\255\
\255\255\058\001\059\001\060\001\255\255\255\255\063\001\064\001\
\255\255\255\255\067\001\068\001\255\255\255\255\069\001\072\001\
\073\001\255\255\075\001\074\001\077\001\255\255\255\255\255\255\
\079\001\080\001\081\001\082\001\255\255\084\001\255\255\118\001\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\100\001\101\001\255\255\103\001\104\001\
\105\001\255\255\107\001\255\255\255\255\255\255\111\001\112\001\
\113\001\255\255\115\001\255\255\255\255\255\255\255\255\118\001\
\121\001\122\001\000\001\001\001\002\001\003\001\004\001\005\001\
\006\001\007\001\008\001\009\001\010\001\011\001\012\001\013\001\
\014\001\015\001\016\001\255\255\018\001\019\001\020\001\021\001\
\022\001\023\001\024\001\025\001\026\001\027\001\028\001\029\001\
\030\001\031\001\032\001\033\001\034\001\035\001\036\001\037\001\
\038\001\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\058\001\059\001\060\001\255\255\
\255\255\063\001\064\001\255\255\255\255\067\001\068\001\255\255\
\255\255\255\255\072\001\073\001\255\255\075\001\255\255\255\255\
\255\255\000\001\001\001\255\255\003\001\004\001\005\001\006\001\
\255\255\008\001\009\001\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\100\001\101\001\
\255\255\103\001\104\001\105\001\255\255\107\001\255\255\255\255\
\255\255\111\001\112\001\113\001\255\255\115\001\037\001\038\001\
\255\255\255\255\255\255\121\001\122\001\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\058\001\059\001\060\001\255\255\255\255\
\063\001\064\001\255\255\255\255\067\001\068\001\255\255\255\255\
\255\255\072\001\073\001\255\255\075\001\076\001\077\001\255\255\
\255\255\255\255\081\001\255\255\255\255\255\255\085\001\086\001\
\087\001\088\001\089\001\090\001\091\001\092\001\093\001\094\001\
\095\001\096\001\255\255\255\255\255\255\255\255\255\255\102\001\
\255\255\104\001\105\001\255\255\107\001\255\255\255\255\255\255\
\111\001\112\001\255\255\114\001\000\001\001\001\255\255\003\001\
\004\001\005\001\006\001\122\001\008\001\009\001\255\255\255\255\
\255\255\255\255\255\255\255\255\064\001\065\001\066\001\002\001\
\068\001\069\001\255\255\255\255\255\255\255\255\074\001\255\255\
\002\001\255\255\255\255\079\001\080\001\081\001\082\001\255\255\
\084\001\037\001\038\001\255\255\255\255\255\255\255\255\026\001\
\255\255\255\255\029\001\030\001\255\255\255\255\255\255\255\255\
\026\001\036\001\255\255\029\001\030\001\255\255\058\001\059\001\
\060\001\255\255\036\001\063\001\064\001\255\255\255\255\067\001\
\068\001\255\255\118\001\255\255\072\001\073\001\255\255\075\001\
\255\255\077\001\255\255\255\255\255\255\081\001\255\255\255\255\
\255\255\085\001\086\001\087\001\088\001\089\001\090\001\091\001\
\092\001\093\001\094\001\095\001\096\001\080\001\255\255\255\255\
\255\255\255\255\102\001\255\255\104\001\105\001\080\001\107\001\
\255\255\255\255\255\255\111\001\112\001\255\255\114\001\000\001\
\001\001\100\001\003\001\004\001\005\001\006\001\122\001\008\001\
\009\001\255\255\100\001\255\255\102\001\255\255\113\001\255\255\
\115\001\052\001\053\001\054\001\055\001\056\001\057\001\113\001\
\255\255\115\001\255\255\002\001\255\255\064\001\065\001\066\001\
\255\255\068\001\069\001\255\255\037\001\038\001\255\255\074\001\
\255\255\255\255\255\255\255\255\079\001\080\001\081\001\082\001\
\255\255\084\001\255\255\026\001\255\255\255\255\029\001\030\001\
\255\255\058\001\059\001\060\001\255\255\036\001\063\001\064\001\
\255\255\255\255\067\001\068\001\255\255\255\255\255\255\072\001\
\073\001\255\255\075\001\255\255\077\001\255\255\255\255\255\255\
\081\001\255\255\255\255\118\001\085\001\086\001\087\001\088\001\
\089\001\090\001\091\001\092\001\093\001\094\001\095\001\096\001\
\255\255\255\255\255\255\255\255\075\001\102\001\255\255\104\001\
\105\001\080\001\107\001\255\255\255\255\255\255\111\001\112\001\
\001\001\114\001\003\001\004\001\005\001\006\001\007\001\008\001\
\009\001\122\001\255\255\255\255\255\255\100\001\255\255\255\255\
\255\255\255\255\255\255\002\001\255\255\255\255\255\255\255\255\
\255\255\255\255\113\001\255\255\115\001\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\037\001\038\001\255\255\255\255\
\255\255\255\255\255\255\026\001\255\255\255\255\029\001\030\001\
\255\255\255\255\051\001\255\255\255\255\036\001\255\255\255\255\
\255\255\058\001\059\001\060\001\255\255\255\255\063\001\064\001\
\255\255\255\255\067\001\068\001\255\255\255\255\255\255\072\001\
\073\001\255\255\075\001\255\255\077\001\078\001\000\001\001\001\
\255\255\003\001\004\001\005\001\006\001\255\255\008\001\009\001\
\255\255\255\255\255\255\074\001\255\255\076\001\255\255\255\255\
\079\001\080\001\081\001\082\001\083\001\255\255\255\255\104\001\
\105\001\255\255\107\001\255\255\255\255\255\255\111\001\112\001\
\255\255\255\255\255\255\037\001\038\001\100\001\255\255\255\255\
\255\255\122\001\123\001\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\113\001\255\255\115\001\255\255\255\255\255\255\
\058\001\059\001\060\001\255\255\255\255\063\001\064\001\255\255\
\255\255\067\001\068\001\255\255\255\255\255\255\072\001\073\001\
\255\255\075\001\255\255\255\255\255\255\000\001\001\001\081\001\
\003\001\004\001\005\001\006\001\255\255\008\001\009\001\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\002\001\255\255\255\255\255\255\104\001\105\001\
\255\255\107\001\255\255\255\255\255\255\111\001\112\001\255\255\
\255\255\255\255\037\001\038\001\255\255\255\255\255\255\255\255\
\122\001\255\255\026\001\255\255\255\255\029\001\030\001\255\255\
\255\255\255\255\255\255\255\255\036\001\255\255\255\255\058\001\
\059\001\060\001\255\255\255\255\063\001\064\001\255\255\255\255\
\067\001\068\001\255\255\255\255\255\255\072\001\073\001\255\255\
\075\001\255\255\000\001\001\001\079\001\003\001\004\001\005\001\
\006\001\065\001\008\001\009\001\068\001\069\001\255\255\255\255\
\255\255\255\255\074\001\255\255\076\001\255\255\002\001\079\001\
\080\001\081\001\082\001\083\001\084\001\104\001\105\001\255\255\
\107\001\255\255\255\255\255\255\111\001\112\001\255\255\037\001\
\038\001\255\255\255\255\255\255\100\001\255\255\026\001\122\001\
\255\255\029\001\030\001\255\255\255\255\255\255\255\255\255\255\
\036\001\113\001\255\255\115\001\058\001\059\001\060\001\255\255\
\255\255\063\001\064\001\255\255\255\255\067\001\068\001\255\255\
\255\255\255\255\072\001\073\001\255\255\075\001\000\001\001\001\
\255\255\003\001\004\001\005\001\006\001\065\001\008\001\009\001\
\068\001\069\001\255\255\255\255\255\255\255\255\074\001\255\255\
\076\001\255\255\002\001\079\001\080\001\081\001\082\001\083\001\
\084\001\255\255\104\001\105\001\255\255\107\001\255\255\255\255\
\255\255\111\001\112\001\037\001\038\001\255\255\255\255\255\255\
\100\001\255\255\026\001\255\255\122\001\029\001\030\001\255\255\
\255\255\255\255\255\255\255\255\036\001\113\001\255\255\115\001\
\058\001\059\001\060\001\255\255\255\255\063\001\064\001\255\255\
\255\255\067\001\068\001\255\255\255\255\255\255\072\001\073\001\
\255\255\075\001\000\001\001\001\255\255\003\001\004\001\005\001\
\006\001\255\255\008\001\009\001\068\001\069\001\255\255\255\255\
\255\255\255\255\074\001\255\255\076\001\255\255\002\001\079\001\
\080\001\081\001\082\001\083\001\084\001\255\255\104\001\105\001\
\255\255\107\001\255\255\255\255\255\255\111\001\112\001\037\001\
\038\001\255\255\255\255\255\255\100\001\255\255\026\001\255\255\
\122\001\029\001\030\001\255\255\255\255\255\255\255\255\255\255\
\036\001\113\001\255\255\115\001\058\001\059\001\060\001\255\255\
\255\255\063\001\064\001\255\255\255\255\067\001\068\001\255\255\
\255\255\255\255\072\001\073\001\255\255\075\001\000\001\001\001\
\255\255\003\001\004\001\005\001\006\001\255\255\008\001\009\001\
\068\001\069\001\255\255\255\255\255\255\255\255\074\001\255\255\
\076\001\255\255\002\001\079\001\080\001\081\001\082\001\083\001\
\084\001\255\255\104\001\105\001\255\255\107\001\255\255\255\255\
\255\255\111\001\112\001\037\001\038\001\255\255\255\255\255\255\
\100\001\255\255\026\001\255\255\122\001\029\001\030\001\255\255\
\255\255\255\255\255\255\255\255\036\001\113\001\255\255\115\001\
\058\001\059\001\060\001\255\255\255\255\063\001\064\001\255\255\
\255\255\067\001\068\001\255\255\255\255\255\255\072\001\073\001\
\255\255\075\001\000\001\001\001\255\255\003\001\004\001\005\001\
\006\001\255\255\008\001\009\001\255\255\069\001\255\255\255\255\
\255\255\255\255\074\001\255\255\076\001\255\255\255\255\079\001\
\080\001\081\001\082\001\083\001\084\001\255\255\104\001\105\001\
\255\255\107\001\255\255\255\255\255\255\111\001\112\001\037\001\
\038\001\255\255\255\255\255\255\100\001\255\255\255\255\255\255\
\122\001\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\113\001\255\255\115\001\058\001\059\001\060\001\255\255\
\065\001\063\001\064\001\068\001\069\001\067\001\068\001\255\255\
\255\255\074\001\072\001\073\001\255\255\075\001\079\001\080\001\
\081\001\082\001\255\255\084\001\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\104\001\105\001\255\255\107\001\255\255\255\255\
\255\255\111\001\112\001\255\255\255\255\118\001\255\255\255\255\
\255\255\255\255\255\255\255\255\122\001\001\001\002\001\003\001\
\004\001\005\001\006\001\007\001\008\001\009\001\010\001\011\001\
\012\001\013\001\014\001\015\001\016\001\255\255\018\001\019\001\
\020\001\021\001\022\001\023\001\024\001\025\001\026\001\027\001\
\028\001\029\001\030\001\031\001\032\001\033\001\034\001\035\001\
\036\001\037\001\038\001\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\058\001\059\001\
\060\001\255\255\255\255\063\001\064\001\255\255\255\255\067\001\
\068\001\255\255\255\255\255\255\072\001\073\001\255\255\075\001\
\255\255\255\255\255\255\064\001\065\001\066\001\255\255\068\001\
\069\001\255\255\255\255\255\255\255\255\074\001\255\255\255\255\
\255\255\255\255\079\001\080\001\081\001\082\001\255\255\084\001\
\100\001\101\001\255\255\103\001\104\001\105\001\255\255\107\001\
\255\255\255\255\255\255\111\001\112\001\113\001\255\255\115\001\
\000\001\255\255\002\001\255\255\255\255\121\001\122\001\007\001\
\255\255\255\255\010\001\011\001\012\001\013\001\014\001\015\001\
\016\001\118\001\018\001\019\001\020\001\021\001\022\001\023\001\
\024\001\025\001\026\001\027\001\028\001\029\001\030\001\031\001\
\032\001\033\001\034\001\035\001\036\001\065\001\066\001\255\255\
\068\001\069\001\255\255\255\255\255\255\255\255\074\001\255\255\
\255\255\255\255\255\255\079\001\080\001\081\001\082\001\255\255\
\084\001\255\255\255\255\255\255\255\255\001\001\255\255\003\001\
\004\001\005\001\006\001\255\255\008\001\009\001\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\002\001\081\001\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\118\001\255\255\255\255\255\255\255\255\255\255\
\255\255\037\001\038\001\039\001\100\001\101\001\255\255\103\001\
\026\001\255\255\255\255\029\001\030\001\255\255\255\255\255\255\
\255\255\113\001\036\001\115\001\116\001\117\001\058\001\059\001\
\060\001\121\001\255\255\063\001\064\001\255\255\255\255\067\001\
\068\001\255\255\255\255\255\255\072\001\073\001\255\255\075\001\
\255\255\077\001\001\001\255\255\003\001\004\001\005\001\006\001\
\255\255\008\001\009\001\069\001\255\255\255\255\255\255\255\255\
\074\001\255\255\076\001\255\255\002\001\079\001\080\001\081\001\
\082\001\083\001\084\001\255\255\104\001\105\001\255\255\107\001\
\255\255\255\255\255\255\111\001\112\001\255\255\037\001\038\001\
\255\255\255\255\100\001\255\255\026\001\255\255\122\001\029\001\
\030\001\255\255\255\255\255\255\255\255\255\255\036\001\113\001\
\255\255\115\001\255\255\058\001\059\001\060\001\255\255\255\255\
\063\001\064\001\255\255\255\255\067\001\068\001\255\255\255\255\
\255\255\072\001\073\001\255\255\075\001\255\255\077\001\001\001\
\255\255\003\001\004\001\005\001\006\001\255\255\008\001\009\001\
\255\255\255\255\255\255\255\255\255\255\075\001\255\255\255\255\
\078\001\255\255\080\001\255\255\255\255\255\255\255\255\255\255\
\255\255\104\001\105\001\255\255\107\001\255\255\255\255\255\255\
\111\001\112\001\255\255\037\001\038\001\255\255\100\001\255\255\
\102\001\255\255\255\255\122\001\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\113\001\255\255\115\001\255\255\255\255\
\058\001\059\001\060\001\255\255\255\255\063\001\064\001\255\255\
\255\255\067\001\068\001\255\255\255\255\255\255\072\001\073\001\
\255\255\075\001\255\255\077\001\001\001\255\255\003\001\004\001\
\005\001\006\001\255\255\008\001\009\001\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\104\001\105\001\
\255\255\107\001\255\255\255\255\255\255\111\001\112\001\255\255\
\037\001\038\001\255\255\255\255\255\255\255\255\255\255\255\255\
\122\001\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\058\001\059\001\060\001\
\255\255\255\255\063\001\064\001\255\255\255\255\067\001\068\001\
\255\255\255\255\255\255\072\001\073\001\255\255\075\001\255\255\
\077\001\001\001\255\255\003\001\004\001\005\001\006\001\255\255\
\008\001\009\001\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\104\001\105\001\255\255\107\001\255\255\
\255\255\255\255\111\001\112\001\255\255\037\001\038\001\255\255\
\255\255\255\255\255\255\255\255\255\255\122\001\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\058\001\059\001\060\001\255\255\255\255\063\001\
\064\001\255\255\255\255\067\001\068\001\255\255\255\255\255\255\
\072\001\073\001\255\255\075\001\255\255\001\001\255\255\003\001\
\004\001\005\001\006\001\255\255\008\001\009\001\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\104\001\105\001\255\255\107\001\255\255\255\255\255\255\111\001\
\112\001\037\001\038\001\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\122\001\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\058\001\059\001\
\060\001\255\255\255\255\063\001\064\001\255\255\255\255\067\001\
\068\001\255\255\255\255\255\255\072\001\073\001\255\255\075\001\
\255\255\001\001\255\255\003\001\004\001\005\001\006\001\255\255\
\008\001\009\001\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\104\001\105\001\255\255\107\001\
\255\255\255\255\255\255\111\001\112\001\037\001\038\001\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\122\001\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\058\001\059\001\060\001\255\255\255\255\063\001\
\064\001\255\255\255\255\067\001\068\001\255\255\255\255\255\255\
\072\001\073\001\255\255\075\001\255\255\001\001\255\255\003\001\
\004\001\005\001\006\001\255\255\008\001\009\001\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\104\001\105\001\255\255\107\001\255\255\255\255\255\255\111\001\
\112\001\037\001\038\001\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\122\001\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\058\001\059\001\
\060\001\255\255\255\255\063\001\064\001\255\255\255\255\067\001\
\068\001\255\255\255\255\255\255\072\001\073\001\255\255\075\001\
\255\255\001\001\255\255\003\001\004\001\005\001\006\001\255\255\
\008\001\009\001\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\104\001\105\001\255\255\107\001\
\255\255\255\255\255\255\111\001\112\001\037\001\038\001\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\122\001\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\058\001\059\001\060\001\255\255\255\255\063\001\
\064\001\255\255\255\255\067\001\068\001\255\255\255\255\255\255\
\072\001\073\001\255\255\075\001\255\255\001\001\255\255\003\001\
\004\001\005\001\006\001\255\255\008\001\009\001\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\104\001\105\001\255\255\107\001\255\255\255\255\255\255\111\001\
\112\001\037\001\038\001\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\122\001\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\058\001\059\001\
\060\001\255\255\255\255\063\001\064\001\255\255\255\255\067\001\
\068\001\255\255\255\255\255\255\072\001\073\001\255\255\075\001\
\255\255\065\001\066\001\255\255\068\001\069\001\255\255\255\255\
\255\255\255\255\074\001\255\255\255\255\255\255\255\255\079\001\
\080\001\081\001\082\001\255\255\084\001\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\104\001\105\001\255\255\107\001\
\255\255\255\255\255\255\111\001\112\001\255\255\001\001\002\001\
\255\255\255\255\255\255\255\255\007\001\255\255\122\001\010\001\
\011\001\012\001\013\001\014\001\015\001\016\001\118\001\018\001\
\019\001\020\001\021\001\022\001\023\001\024\001\025\001\026\001\
\027\001\028\001\029\001\030\001\031\001\032\001\033\001\034\001\
\035\001\036\001\001\001\002\001\255\255\255\255\255\255\255\255\
\007\001\255\255\255\255\010\001\011\001\012\001\013\001\014\001\
\015\001\016\001\255\255\018\001\019\001\020\001\021\001\022\001\
\023\001\024\001\025\001\026\001\027\001\028\001\029\001\030\001\
\031\001\032\001\033\001\034\001\035\001\036\001\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\081\001\052\001\
\053\001\054\001\055\001\056\001\057\001\255\255\255\255\255\255\
\255\255\255\255\255\255\064\001\065\001\066\001\255\255\068\001\
\069\001\100\001\101\001\102\001\103\001\074\001\255\255\255\255\
\255\255\255\255\079\001\080\001\081\001\082\001\113\001\084\001\
\115\001\116\001\117\001\255\255\119\001\120\001\121\001\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\100\001\101\001\102\001\
\103\001\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\118\001\113\001\255\255\115\001\116\001\117\001\002\001\
\119\001\120\001\121\001\255\255\007\001\255\255\255\255\010\001\
\011\001\012\001\013\001\014\001\015\001\016\001\255\255\018\001\
\019\001\020\001\021\001\022\001\023\001\024\001\025\001\026\001\
\027\001\028\001\029\001\030\001\031\001\032\001\033\001\034\001\
\035\001\036\001\255\255\255\255\039\001\040\001\041\001\042\001\
\043\001\044\001\045\001\046\001\047\001\048\001\049\001\050\001\
\051\001\052\001\053\001\054\001\055\001\056\001\057\001\058\001\
\059\001\060\001\061\001\062\001\255\255\064\001\065\001\066\001\
\255\255\068\001\069\001\070\001\071\001\072\001\073\001\074\001\
\075\001\076\001\077\001\078\001\079\001\080\001\081\001\082\001\
\083\001\084\001\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\100\001\101\001\255\255\103\001\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\113\001\002\001\
\115\001\255\255\255\255\118\001\007\001\008\001\121\001\010\001\
\011\001\012\001\013\001\014\001\015\001\016\001\255\255\018\001\
\019\001\020\001\021\001\022\001\023\001\024\001\025\001\026\001\
\027\001\028\001\029\001\030\001\031\001\032\001\033\001\034\001\
\035\001\036\001\002\001\255\255\255\255\255\255\255\255\007\001\
\255\255\255\255\010\001\011\001\012\001\013\001\014\001\015\001\
\016\001\255\255\018\001\019\001\020\001\021\001\022\001\023\001\
\024\001\025\001\026\001\027\001\028\001\029\001\030\001\031\001\
\032\001\033\001\034\001\035\001\036\001\065\001\255\255\255\255\
\068\001\069\001\255\255\255\255\255\255\255\255\074\001\255\255\
\255\255\255\255\255\255\079\001\080\001\081\001\082\001\255\255\
\084\001\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\100\001\101\001\255\255\103\001\104\001\105\001\255\255\
\255\255\255\255\255\255\075\001\255\255\255\255\113\001\255\255\
\115\001\255\255\255\255\083\001\255\255\255\255\121\001\255\255\
\255\255\255\255\118\001\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\100\001\101\001\255\255\103\001\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\113\001\002\001\115\001\255\255\255\255\255\255\007\001\
\255\255\121\001\010\001\011\001\012\001\013\001\014\001\015\001\
\016\001\255\255\018\001\019\001\020\001\021\001\022\001\023\001\
\024\001\025\001\026\001\027\001\028\001\029\001\030\001\031\001\
\032\001\033\001\034\001\035\001\036\001\002\001\255\255\255\255\
\255\255\255\255\007\001\255\255\255\255\010\001\011\001\012\001\
\013\001\014\001\015\001\016\001\255\255\018\001\019\001\020\001\
\021\001\022\001\023\001\024\001\025\001\026\001\027\001\028\001\
\029\001\030\001\031\001\032\001\033\001\034\001\035\001\036\001\
\255\255\255\255\074\001\075\001\255\255\052\001\053\001\054\001\
\055\001\056\001\057\001\058\001\059\001\060\001\061\001\062\001\
\255\255\064\001\065\001\066\001\255\255\068\001\069\001\070\001\
\071\001\255\255\255\255\074\001\100\001\101\001\255\255\103\001\
\079\001\080\001\081\001\082\001\255\255\084\001\075\001\255\255\
\255\255\113\001\255\255\115\001\255\255\255\255\255\255\255\255\
\255\255\121\001\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\100\001\
\101\001\255\255\103\001\255\255\255\255\255\255\255\255\118\001\
\255\255\255\255\255\255\255\255\113\001\002\001\115\001\255\255\
\255\255\255\255\007\001\255\255\121\001\010\001\011\001\012\001\
\013\001\014\001\015\001\016\001\255\255\018\001\019\001\020\001\
\021\001\022\001\023\001\024\001\025\001\026\001\027\001\028\001\
\029\001\030\001\031\001\032\001\033\001\034\001\035\001\036\001\
\002\001\255\255\255\255\255\255\255\255\007\001\255\255\255\255\
\010\001\011\001\012\001\013\001\014\001\015\001\016\001\255\255\
\018\001\019\001\020\001\021\001\022\001\023\001\024\001\025\001\
\026\001\027\001\028\001\029\001\030\001\031\001\032\001\033\001\
\034\001\035\001\036\001\255\255\255\255\255\255\255\255\255\255\
\077\001\255\255\255\255\052\001\053\001\054\001\055\001\056\001\
\057\001\058\001\059\001\255\255\255\255\255\255\255\255\064\001\
\065\001\066\001\255\255\068\001\069\001\070\001\071\001\100\001\
\101\001\074\001\103\001\255\255\255\255\255\255\079\001\080\001\
\081\001\082\001\255\255\084\001\113\001\255\255\115\001\255\255\
\255\255\083\001\255\255\255\255\121\001\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\100\001\101\001\255\255\103\001\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\118\001\255\255\113\001\
\002\001\115\001\255\255\255\255\255\255\007\001\255\255\121\001\
\010\001\011\001\012\001\013\001\014\001\015\001\016\001\255\255\
\018\001\019\001\020\001\021\001\022\001\023\001\024\001\025\001\
\026\001\027\001\028\001\029\001\030\001\031\001\032\001\033\001\
\034\001\035\001\036\001\002\001\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\010\001\011\001\012\001\013\001\014\001\
\015\001\016\001\255\255\018\001\019\001\020\001\021\001\022\001\
\023\001\024\001\025\001\026\001\027\001\028\001\029\001\030\001\
\031\001\032\001\033\001\034\001\035\001\036\001\255\255\255\255\
\255\255\255\255\255\255\052\001\053\001\054\001\055\001\056\001\
\057\001\058\001\059\001\255\255\255\255\255\255\255\255\064\001\
\065\001\066\001\255\255\068\001\069\001\070\001\071\001\255\255\
\255\255\074\001\100\001\101\001\255\255\103\001\079\001\080\001\
\081\001\082\001\255\255\084\001\255\255\255\255\255\255\113\001\
\255\255\115\001\255\255\255\255\255\255\255\255\255\255\121\001\
\255\255\255\255\255\255\002\001\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\100\001\101\001\255\255\
\103\001\255\255\255\255\255\255\255\255\118\001\255\255\255\255\
\255\255\255\255\113\001\026\001\115\001\255\255\029\001\030\001\
\255\255\255\255\121\001\255\255\255\255\036\001\255\255\255\255\
\039\001\040\001\041\001\042\001\043\001\044\001\045\001\046\001\
\047\001\048\001\049\001\050\001\051\001\052\001\053\001\054\001\
\055\001\056\001\057\001\058\001\059\001\060\001\061\001\062\001\
\255\255\064\001\065\001\066\001\255\255\068\001\069\001\070\001\
\071\001\072\001\073\001\074\001\075\001\076\001\255\255\078\001\
\079\001\080\001\081\001\082\001\083\001\084\001\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\002\001\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\100\001\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\113\001\255\255\115\001\026\001\255\255\118\001\
\029\001\030\001\255\255\255\255\255\255\255\255\255\255\036\001\
\255\255\255\255\039\001\040\001\041\001\042\001\043\001\044\001\
\045\001\046\001\047\001\048\001\049\001\255\255\255\255\052\001\
\053\001\054\001\055\001\056\001\057\001\058\001\059\001\060\001\
\061\001\062\001\255\255\064\001\065\001\066\001\255\255\068\001\
\069\001\070\001\071\001\255\255\255\255\074\001\255\255\076\001\
\255\255\255\255\079\001\080\001\081\001\082\001\083\001\084\001\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\002\001\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\100\001\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\113\001\255\255\115\001\026\001\
\255\255\118\001\029\001\030\001\255\255\255\255\255\255\255\255\
\255\255\036\001\255\255\255\255\039\001\040\001\041\001\042\001\
\043\001\044\001\045\001\046\001\047\001\048\001\049\001\255\255\
\255\255\052\001\053\001\054\001\055\001\056\001\057\001\058\001\
\059\001\060\001\061\001\062\001\255\255\064\001\065\001\066\001\
\255\255\068\001\069\001\070\001\071\001\255\255\255\255\074\001\
\255\255\076\001\255\255\255\255\079\001\080\001\081\001\082\001\
\083\001\084\001\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\002\001\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\100\001\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\113\001\255\255\
\115\001\026\001\255\255\118\001\029\001\030\001\255\255\255\255\
\255\255\255\255\255\255\036\001\255\255\255\255\039\001\040\001\
\041\001\042\001\043\001\044\001\045\001\046\001\047\001\048\001\
\049\001\255\255\255\255\052\001\053\001\054\001\055\001\056\001\
\057\001\058\001\059\001\060\001\061\001\062\001\255\255\064\001\
\065\001\066\001\255\255\068\001\069\001\070\001\071\001\255\255\
\255\255\074\001\002\001\076\001\255\255\255\255\079\001\080\001\
\081\001\082\001\083\001\084\001\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\026\001\100\001\255\255\029\001\030\001\255\255\
\255\255\255\255\255\255\255\255\036\001\255\255\255\255\255\255\
\113\001\255\255\115\001\255\255\255\255\118\001\255\255\255\255\
\255\255\255\255\255\255\255\255\052\001\053\001\054\001\055\001\
\056\001\057\001\058\001\059\001\060\001\061\001\062\001\255\255\
\064\001\065\001\066\001\002\001\068\001\069\001\070\001\071\001\
\255\255\255\255\074\001\255\255\076\001\255\255\255\255\079\001\
\080\001\081\001\082\001\083\001\084\001\255\255\255\255\255\255\
\255\255\255\255\255\255\026\001\255\255\255\255\029\001\030\001\
\255\255\255\255\255\255\255\255\100\001\036\001\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\113\001\255\255\115\001\255\255\052\001\053\001\054\001\
\055\001\056\001\057\001\058\001\059\001\255\255\255\255\255\255\
\255\255\064\001\065\001\066\001\002\001\068\001\069\001\070\001\
\071\001\255\255\255\255\074\001\255\255\076\001\255\255\255\255\
\079\001\080\001\081\001\082\001\083\001\084\001\255\255\255\255\
\255\255\255\255\255\255\255\255\026\001\255\255\255\255\029\001\
\030\001\255\255\255\255\255\255\255\255\100\001\036\001\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\113\001\255\255\115\001\255\255\052\001\053\001\
\054\001\055\001\056\001\057\001\058\001\059\001\255\255\255\255\
\255\255\255\255\064\001\065\001\066\001\002\001\068\001\069\001\
\070\001\071\001\255\255\255\255\074\001\255\255\076\001\255\255\
\255\255\079\001\080\001\081\001\082\001\083\001\084\001\255\255\
\255\255\255\255\255\255\255\255\255\255\026\001\255\255\255\255\
\029\001\030\001\255\255\255\255\255\255\255\255\100\001\036\001\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\113\001\255\255\115\001\255\255\052\001\
\053\001\054\001\055\001\056\001\057\001\058\001\059\001\255\255\
\255\255\255\255\255\255\064\001\065\001\066\001\002\001\068\001\
\069\001\070\001\071\001\255\255\255\255\074\001\255\255\076\001\
\255\255\255\255\079\001\080\001\081\001\082\001\083\001\084\001\
\255\255\255\255\255\255\255\255\255\255\255\255\026\001\255\255\
\255\255\029\001\030\001\255\255\255\255\255\255\255\255\100\001\
\036\001\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\113\001\255\255\115\001\255\255\
\052\001\053\001\054\001\055\001\056\001\057\001\255\255\255\255\
\255\255\255\255\255\255\255\255\064\001\065\001\066\001\002\001\
\068\001\069\001\070\001\071\001\255\255\255\255\074\001\255\255\
\076\001\255\255\255\255\079\001\080\001\081\001\082\001\083\001\
\084\001\255\255\255\255\255\255\255\255\255\255\255\255\026\001\
\255\255\255\255\029\001\030\001\255\255\255\255\255\255\255\255\
\100\001\036\001\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\113\001\255\255\115\001\
\255\255\052\001\053\001\054\001\055\001\056\001\057\001\255\255\
\255\255\255\255\255\255\255\255\255\255\064\001\065\001\066\001\
\002\001\068\001\069\001\070\001\071\001\255\255\255\255\074\001\
\255\255\076\001\255\255\255\255\079\001\080\001\081\001\082\001\
\083\001\084\001\255\255\255\255\255\255\255\255\255\255\255\255\
\026\001\255\255\255\255\029\001\030\001\255\255\255\255\255\255\
\255\255\100\001\036\001\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\113\001\255\255\
\115\001\255\255\052\001\053\001\054\001\055\001\056\001\057\001\
\255\255\255\255\255\255\255\255\255\255\255\255\064\001\065\001\
\066\001\002\001\068\001\069\001\070\001\071\001\255\255\255\255\
\074\001\255\255\076\001\255\255\255\255\079\001\080\001\081\001\
\082\001\083\001\084\001\255\255\255\255\255\255\255\255\255\255\
\255\255\026\001\255\255\255\255\029\001\030\001\255\255\255\255\
\255\255\255\255\100\001\036\001\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\113\001\
\255\255\115\001\255\255\052\001\053\001\054\001\055\001\056\001\
\057\001\255\255\255\255\255\255\255\255\255\255\255\255\064\001\
\065\001\066\001\002\001\068\001\069\001\255\255\255\255\255\255\
\255\255\074\001\255\255\076\001\255\255\255\255\079\001\080\001\
\081\001\082\001\083\001\084\001\255\255\255\255\255\255\255\255\
\255\255\255\255\026\001\255\255\255\255\029\001\030\001\255\255\
\255\255\255\255\255\255\100\001\036\001\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\113\001\255\255\115\001\255\255\052\001\053\001\054\001\055\001\
\056\001\057\001\255\255\255\255\255\255\255\255\255\255\255\255\
\064\001\065\001\066\001\002\001\068\001\069\001\255\255\255\255\
\255\255\255\255\074\001\255\255\076\001\255\255\255\255\079\001\
\080\001\081\001\082\001\083\001\084\001\255\255\255\255\255\255\
\255\255\255\255\255\255\026\001\255\255\255\255\029\001\030\001\
\255\255\255\255\255\255\255\255\100\001\036\001\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\113\001\255\255\115\001\255\255\052\001\053\001\054\001\
\055\001\056\001\057\001\255\255\255\255\255\255\255\255\255\255\
\255\255\064\001\065\001\066\001\002\001\068\001\069\001\255\255\
\255\255\255\255\255\255\074\001\255\255\076\001\255\255\255\255\
\079\001\080\001\081\001\082\001\083\001\084\001\255\255\255\255\
\255\255\255\255\255\255\255\255\026\001\255\255\255\255\029\001\
\030\001\255\255\255\255\255\255\255\255\100\001\036\001\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\113\001\255\255\115\001\255\255\052\001\053\001\
\054\001\055\001\056\001\057\001\255\255\255\255\255\255\255\255\
\255\255\255\255\064\001\065\001\066\001\002\001\068\001\069\001\
\255\255\255\255\255\255\255\255\074\001\255\255\076\001\255\255\
\255\255\079\001\080\001\081\001\082\001\083\001\084\001\255\255\
\255\255\255\255\255\255\255\255\255\255\026\001\255\255\255\255\
\029\001\030\001\255\255\255\255\255\255\255\255\100\001\036\001\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\113\001\255\255\115\001\255\255\052\001\
\053\001\054\001\055\001\056\001\057\001\255\255\255\255\255\255\
\002\001\255\255\255\255\064\001\065\001\066\001\255\255\068\001\
\069\001\255\255\255\255\255\255\255\255\074\001\255\255\076\001\
\255\255\255\255\079\001\080\001\081\001\082\001\083\001\084\001\
\026\001\255\255\255\255\029\001\030\001\255\255\255\255\255\255\
\255\255\255\255\036\001\255\255\255\255\255\255\255\255\100\001\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\052\001\053\001\113\001\255\255\115\001\255\255\
\255\255\255\255\255\255\002\001\255\255\255\255\064\001\065\001\
\066\001\255\255\068\001\069\001\255\255\255\255\255\255\255\255\
\074\001\255\255\076\001\255\255\255\255\079\001\080\001\081\001\
\082\001\083\001\084\001\026\001\255\255\255\255\029\001\030\001\
\255\255\255\255\255\255\255\255\255\255\036\001\255\255\255\255\
\255\255\255\255\100\001\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\052\001\053\001\113\001\
\255\255\115\001\255\255\255\255\255\255\255\255\002\001\255\255\
\255\255\064\001\065\001\066\001\255\255\068\001\069\001\255\255\
\255\255\255\255\255\255\074\001\255\255\076\001\255\255\255\255\
\079\001\080\001\081\001\082\001\083\001\084\001\026\001\255\255\
\255\255\029\001\030\001\255\255\255\255\255\255\255\255\255\255\
\036\001\255\255\255\255\255\255\255\255\100\001\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\052\001\053\001\113\001\255\255\115\001\255\255\255\255\255\255\
\255\255\002\001\255\255\255\255\064\001\065\001\066\001\255\255\
\068\001\069\001\255\255\255\255\255\255\255\255\074\001\255\255\
\076\001\255\255\255\255\079\001\080\001\081\001\082\001\083\001\
\084\001\026\001\255\255\255\255\029\001\030\001\255\255\255\255\
\255\255\255\255\255\255\036\001\255\255\255\255\255\255\255\255\
\100\001\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\113\001\255\255\115\001\
\255\255\255\255\255\255\255\255\002\001\255\255\255\255\064\001\
\065\001\066\001\255\255\068\001\069\001\255\255\255\255\255\255\
\255\255\074\001\255\255\076\001\255\255\255\255\079\001\080\001\
\081\001\082\001\083\001\084\001\026\001\255\255\255\255\029\001\
\030\001\255\255\255\255\255\255\255\255\255\255\036\001\255\255\
\255\255\255\255\255\255\100\001\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\113\001\255\255\115\001\255\255\255\255\255\255\255\255\002\001\
\255\255\255\255\064\001\065\001\066\001\255\255\068\001\069\001\
\255\255\255\255\255\255\255\255\074\001\255\255\076\001\255\255\
\255\255\079\001\080\001\081\001\082\001\083\001\084\001\026\001\
\255\255\255\255\029\001\030\001\255\255\255\255\255\255\255\255\
\255\255\036\001\255\255\255\255\255\255\255\255\100\001\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\113\001\255\255\115\001\255\255\255\255\
\255\255\255\255\002\001\255\255\255\255\255\255\065\001\066\001\
\255\255\068\001\069\001\255\255\255\255\255\255\255\255\074\001\
\255\255\076\001\255\255\255\255\079\001\080\001\081\001\082\001\
\083\001\084\001\026\001\255\255\255\255\029\001\030\001\052\001\
\053\001\255\255\255\255\255\255\036\001\255\255\255\255\255\255\
\255\255\100\001\255\255\064\001\065\001\066\001\255\255\068\001\
\069\001\255\255\255\255\255\255\255\255\074\001\113\001\255\255\
\115\001\255\255\079\001\080\001\081\001\082\001\255\255\084\001\
\255\255\065\001\066\001\255\255\068\001\069\001\000\001\001\001\
\255\255\255\255\074\001\005\001\076\001\007\001\008\001\079\001\
\080\001\081\001\082\001\083\001\084\001\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\026\001\118\001\255\255\029\001\100\001\255\255\255\255\255\255\
\255\255\255\255\255\255\037\001\038\001\000\001\001\001\255\255\
\255\255\113\001\005\001\115\001\007\001\008\001\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\058\001\059\001\060\001\255\255\255\255\063\001\064\001\026\001\
\255\255\067\001\029\001\255\255\255\255\255\255\255\255\255\255\
\074\001\075\001\037\001\038\001\255\255\255\255\255\255\255\255\
\000\001\001\001\255\255\255\255\255\255\005\001\255\255\007\001\
\008\001\091\001\255\255\255\255\255\255\255\255\255\255\058\001\
\059\001\060\001\255\255\255\255\063\001\064\001\104\001\105\001\
\067\001\255\255\026\001\255\255\255\255\029\001\255\255\255\255\
\075\001\255\255\255\255\255\255\255\255\037\001\038\001\000\001\
\001\001\255\255\255\255\255\255\005\001\255\255\007\001\008\001\
\091\001\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\058\001\059\001\060\001\104\001\105\001\063\001\
\064\001\026\001\255\255\067\001\029\001\255\255\255\255\255\255\
\255\255\255\255\255\255\075\001\037\001\038\001\255\255\255\255\
\255\255\255\255\255\255\001\001\255\255\255\255\255\255\005\001\
\255\255\007\001\008\001\091\001\255\255\255\255\255\255\255\255\
\255\255\058\001\059\001\060\001\255\255\255\255\063\001\064\001\
\104\001\105\001\067\001\255\255\026\001\255\255\255\255\029\001\
\255\255\255\255\075\001\255\255\255\255\255\255\255\255\037\001\
\038\001\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\091\001\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\058\001\059\001\060\001\104\001\
\105\001\063\001\064\001\255\255\255\255\067\001\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\075\001\255\255\255\255\
\255\255\255\255\052\001\053\001\054\001\055\001\056\001\057\001\
\058\001\059\001\255\255\255\255\255\255\091\001\064\001\065\001\
\066\001\255\255\068\001\069\001\070\001\071\001\255\255\255\255\
\074\001\255\255\104\001\105\001\255\255\079\001\080\001\081\001\
\082\001\255\255\084\001\052\001\053\001\054\001\055\001\056\001\
\057\001\255\255\255\255\255\255\255\255\255\255\255\255\064\001\
\065\001\066\001\255\255\068\001\069\001\070\001\071\001\255\255\
\255\255\074\001\255\255\255\255\255\255\255\255\079\001\080\001\
\081\001\082\001\255\255\084\001\118\001\255\255\052\001\053\001\
\054\001\055\001\056\001\057\001\255\255\255\255\255\255\255\255\
\255\255\255\255\064\001\065\001\066\001\255\255\068\001\069\001\
\070\001\071\001\255\255\255\255\074\001\255\255\255\255\255\255\
\255\255\079\001\080\001\081\001\082\001\118\001\084\001\052\001\
\053\001\054\001\055\001\056\001\057\001\255\255\255\255\255\255\
\255\255\255\255\255\255\064\001\065\001\066\001\255\255\068\001\
\069\001\070\001\071\001\255\255\255\255\074\001\255\255\255\255\
\255\255\255\255\079\001\080\001\081\001\082\001\255\255\084\001\
\118\001\255\255\052\001\053\001\054\001\055\001\056\001\057\001\
\255\255\255\255\255\255\255\255\255\255\255\255\064\001\065\001\
\066\001\255\255\068\001\069\001\255\255\255\255\255\255\255\255\
\074\001\255\255\255\255\255\255\255\255\079\001\080\001\081\001\
\082\001\118\001\084\001\052\001\053\001\054\001\055\001\056\001\
\057\001\255\255\255\255\255\255\255\255\255\255\255\255\064\001\
\065\001\066\001\255\255\068\001\069\001\255\255\255\255\255\255\
\255\255\074\001\255\255\255\255\255\255\255\255\079\001\080\001\
\081\001\082\001\255\255\084\001\118\001\255\255\052\001\053\001\
\054\001\055\001\056\001\057\001\255\255\255\255\255\255\255\255\
\255\255\255\255\064\001\065\001\066\001\255\255\068\001\069\001\
\255\255\255\255\255\255\255\255\074\001\052\001\053\001\255\255\
\255\255\079\001\080\001\081\001\082\001\118\001\084\001\255\255\
\255\255\064\001\065\001\066\001\255\255\068\001\069\001\255\255\
\255\255\255\255\255\255\074\001\255\255\255\255\255\255\255\255\
\079\001\080\001\081\001\082\001\255\255\084\001\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\118\001\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\118\001\
\039\001\040\001\041\001\042\001\043\001\044\001\045\001\046\001\
\047\001\048\001\049\001\050\001\051\001\052\001\053\001\054\001\
\055\001\056\001\057\001\058\001\059\001\060\001\061\001\062\001\
\255\255\064\001\065\001\066\001\255\255\068\001\069\001\070\001\
\071\001\072\001\073\001\255\255\075\001\076\001\255\255\078\001\
\255\255\080\001\255\255\082\001\255\255\084\001\039\001\040\001\
\041\001\042\001\043\001\044\001\045\001\046\001\047\001\048\001\
\049\001\050\001\051\001\052\001\053\001\054\001\055\001\056\001\
\057\001\058\001\059\001\060\001\061\001\062\001\255\255\064\001\
\065\001\066\001\255\255\068\001\069\001\070\001\071\001\072\001\
\073\001\255\255\075\001\255\255\255\255\078\001\255\255\255\255\
\081\001\082\001\255\255\084\001"

let yynames_const = "\
  EOF\000\
  EQ\000\
  PLUS_EQ\000\
  MINUS_EQ\000\
  STAR_EQ\000\
  SLASH_EQ\000\
  PERCENT_EQ\000\
  AND_EQ\000\
  PIPE_EQ\000\
  CIRC_EQ\000\
  INF_INF_EQ\000\
  SUP_SUP_EQ\000\
  ARROW\000\
  DOT\000\
  EQ_EQ\000\
  EXCLAM_EQ\000\
  INF\000\
  SUP\000\
  INF_EQ\000\
  SUP_EQ\000\
  SLASH\000\
  PERCENT\000\
  PIPE\000\
  CIRC\000\
  PIPE_PIPE\000\
  INF_INF\000\
  SUP_SUP\000\
  RPAREN\000\
  LBRACKET\000\
  RBRACKET\000\
  COLON\000\
  COMMA\000\
  ELLIPSIS\000\
  QUEST\000\
  ELSE\000\
  LABEL__\000\
  BUILTIN_VA_LIST\000\
  BLOCKATTRIBUTE\000\
  PRAGMA_EOL\000\
  AT_NAME\000\
  "

let yynames_block = "\
  IDENT\000\
  QUALIFIER\000\
  CST_CHAR\000\
  CST_WCHAR\000\
  CST_INT\000\
  CST_FLOAT\000\
  NAMED_TYPE\000\
  CST_STRING\000\
  CST_WSTRING\000\
  CHAR\000\
  INT\000\
  BOOL\000\
  DOUBLE\000\
  FLOAT\000\
  VOID\000\
  INT64\000\
  INT32\000\
  ENUM\000\
  STRUCT\000\
  TYPEDEF\000\
  UNION\000\
  SIGNED\000\
  UNSIGNED\000\
  LONG\000\
  SHORT\000\
  VOLATILE\000\
  EXTERN\000\
  STATIC\000\
  CONST\000\
  RESTRICT\000\
  AUTO\000\
  REGISTER\000\
  UNIFORM\000\
  IN\000\
  OUT\000\
  THREAD\000\
  SIZEOF\000\
  ALIGNOF\000\
  PLUS\000\
  MINUS\000\
  STAR\000\
  TILDE\000\
  AND\000\
  EXCLAM\000\
  AND_AND\000\
  PLUS_PLUS\000\
  MINUS_MINUS\000\
  LPAREN\000\
  RBRACE\000\
  LBRACE\000\
  SEMICOLON\000\
  BREAK\000\
  CONTINUE\000\
  GOTO\000\
  RETURN\000\
  SWITCH\000\
  CASE\000\
  DEFAULT\000\
  WHILE\000\
  DO\000\
  FOR\000\
  IF\000\
  TRY\000\
  EXCEPT\000\
  FINALLY\000\
  ATTRIBUTE\000\
  INLINE\000\
  ASM\000\
  TYPEOF\000\
  FUNCTION__\000\
  PRETTY_FUNCTION__\000\
  BUILTIN_VA_ARG\000\
  ATTRIBUTE_USED\000\
  BUILTIN_TYPES_COMPAT\000\
  BUILTIN_OFFSETOF\000\
  DECLSPEC\000\
  MSASM\000\
  MSATTR\000\
  PRAGMA_LINE\000\
  PRAGMA\000\
  AT_TRANSFORM\000\
  AT_TRANSFORMEXPR\000\
  AT_SPECIFIER\000\
  AT_EXPR\000\
  "

let yyact = [|
  (fun _ -> failwith "parser")
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 1 : Cabs.definition list) in
    Obj.repr(
# 397 "src/frontc/cparser.mly"
              (_1)
# 2797 "src/frontc/cparser.ml"
               : Cabs.definition list))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : Cabs.definition list) in
    Obj.repr(
# 399 "src/frontc/cparser.mly"
                 (_1)
# 2804 "src/frontc/cparser.ml"
               : Cabs.definition list))
; (fun __caml_parser_env ->
    Obj.repr(
# 402 "src/frontc/cparser.mly"
                                        ( [] )
# 2810 "src/frontc/cparser.ml"
               : Cabs.definition list))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 1 : Cabs.definition) in
    let _2 = (Parsing.peek_val __caml_parser_env 0 : Cabs.definition list) in
    Obj.repr(
# 403 "src/frontc/cparser.mly"
                                        ( _1 :: _2 )
# 2818 "src/frontc/cparser.ml"
               : Cabs.definition list))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 1 : Cabs.cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 0 : Cabs.definition list) in
    Obj.repr(
# 404 "src/frontc/cparser.mly"
                                        ( _2 )
# 2826 "src/frontc/cparser.ml"
               : Cabs.definition list))
; (fun __caml_parser_env ->
    Obj.repr(
# 408 "src/frontc/cparser.mly"
                               ( currentLoc () )
# 2832 "src/frontc/cparser.ml"
               : Cabs.cabsloc))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : Cabs.definition) in
    Obj.repr(
# 413 "src/frontc/cparser.mly"
                                        ( _1 )
# 2839 "src/frontc/cparser.ml"
               : Cabs.definition))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : Cabs.definition) in
    Obj.repr(
# 414 "src/frontc/cparser.mly"
                                        ( _1 )
# 2846 "src/frontc/cparser.ml"
               : Cabs.definition))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : Cabs.cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 1 : string * cabsloc) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : Cabs.definition) in
    Obj.repr(
# 417 "src/frontc/cparser.mly"
                                        ( LINKAGE (fst _2, (*handleLoc*) (snd _2), [ _3 ]) )
# 2855 "src/frontc/cparser.ml"
               : Cabs.definition))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 4 : Cabs.cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 3 : string * cabsloc) in
    let _3 = (Parsing.peek_val __caml_parser_env 2 : Cabs.cabsloc) in
    let _4 = (Parsing.peek_val __caml_parser_env 1 : Cabs.definition list) in
    let _5 = (Parsing.peek_val __caml_parser_env 0 : Cabs.cabsloc) in
    Obj.repr(
# 419 "src/frontc/cparser.mly"
                                        ( LINKAGE (fst _2, (*handleLoc*) (snd _2), _4)  )
# 2866 "src/frontc/cparser.ml"
               : Cabs.definition))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 4 : Cabs.cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 3 : Cabs.cabsloc) in
    let _3 = (Parsing.peek_val __caml_parser_env 2 : string * cabsloc) in
    let _5 = (Parsing.peek_val __caml_parser_env 0 : Cabs.cabsloc) in
    Obj.repr(
# 421 "src/frontc/cparser.mly"
                                        ( GLOBASM (fst _3, (*handleLoc*) _1) )
# 2876 "src/frontc/cparser.ml"
               : Cabs.definition))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'pragma) in
    Obj.repr(
# 422 "src/frontc/cparser.mly"
                                        ( _1 )
# 2883 "src/frontc/cparser.ml"
               : Cabs.definition))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 5 : string * Cabs.cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 4 : Cabs.cabsloc) in
    let _3 = (Parsing.peek_val __caml_parser_env 3 : string list) in
    let _5 = (Parsing.peek_val __caml_parser_env 1 : 'old_pardef_list) in
    let _6 = (Parsing.peek_val __caml_parser_env 0 : Cabs.cabsloc) in
    Obj.repr(
# 427 "src/frontc/cparser.mly"
                           ( (* Convert pardecl to new style *)
                             let pardecl, isva = doOldParDecl _3 _5 in 
                             (* Make the function declarator *)
                             doDeclaration ((*handleLoc*) (snd _1)) []
                               [((fst _1, PROTO(JUSTBASE, pardecl,isva), [], cabslu),
                                 NO_INIT)]
                            )
# 2900 "src/frontc/cparser.ml"
               : Cabs.definition))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 3 : string * Cabs.cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 2 : Cabs.cabsloc) in
    let _4 = (Parsing.peek_val __caml_parser_env 0 : Cabs.cabsloc) in
    Obj.repr(
# 436 "src/frontc/cparser.mly"
                           ( (* Make the function declarator *)
                             doDeclaration ((*handleLoc*)(snd _1)) []
                               [((fst _1, PROTO(JUSTBASE,[],false), [], cabslu),
                                 NO_INIT)]
                            )
# 2913 "src/frontc/cparser.ml"
               : Cabs.definition))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 7 : Cabs.cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 6 : Cabs.cabsloc) in
    let _3 = (Parsing.peek_val __caml_parser_env 5 : Cabs.definition) in
    let _4 = (Parsing.peek_val __caml_parser_env 4 : Cabs.cabsloc) in
    let _5 = (Parsing.peek_val __caml_parser_env 3 : string * Cabs.cabsloc) in
    let _6 = (Parsing.peek_val __caml_parser_env 2 : Cabs.cabsloc) in
    let _7 = (Parsing.peek_val __caml_parser_env 1 : Cabs.definition list) in
    let _8 = (Parsing.peek_val __caml_parser_env 0 : Cabs.cabsloc) in
    Obj.repr(
# 442 "src/frontc/cparser.mly"
                                                                        (
    checkConnective(fst _5);
    TRANSFORMER(_3, _7, _1)
  )
# 2930 "src/frontc/cparser.ml"
               : Cabs.definition))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 7 : Cabs.cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 6 : Cabs.cabsloc) in
    let _3 = (Parsing.peek_val __caml_parser_env 5 : Cabs.expression * cabsloc) in
    let _4 = (Parsing.peek_val __caml_parser_env 4 : Cabs.cabsloc) in
    let _5 = (Parsing.peek_val __caml_parser_env 3 : string * Cabs.cabsloc) in
    let _6 = (Parsing.peek_val __caml_parser_env 2 : Cabs.cabsloc) in
    let _7 = (Parsing.peek_val __caml_parser_env 1 : Cabs.expression * cabsloc) in
    let _8 = (Parsing.peek_val __caml_parser_env 0 : Cabs.cabsloc) in
    Obj.repr(
# 447 "src/frontc/cparser.mly"
                                                                                   (
    checkConnective(fst _5);
    EXPRTRANSFORMER(fst _3, fst _7, _1)
  )
# 2947 "src/frontc/cparser.ml"
               : Cabs.definition))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : Cabs.cabsloc) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : Cabs.cabsloc) in
    Obj.repr(
# 451 "src/frontc/cparser.mly"
                           ( PRAGMA (VARIABLE "parse_error", _1) )
# 2955 "src/frontc/cparser.ml"
               : Cabs.definition))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : string * Cabs.cabsloc) in
    Obj.repr(
# 455 "src/frontc/cparser.mly"
             (fst _1)
# 2962 "src/frontc/cparser.ml"
               : 'id_or_typename))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : string * Cabs.cabsloc) in
    Obj.repr(
# 456 "src/frontc/cparser.mly"
                  (fst _1)
# 2969 "src/frontc/cparser.ml"
               : 'id_or_typename))
; (fun __caml_parser_env ->
    let _2 = (Parsing.peek_val __caml_parser_env 2 : Cabs.cabsloc) in
    let _3 = (Parsing.peek_val __caml_parser_env 1 : string * Cabs.cabsloc) in
    Obj.repr(
# 457 "src/frontc/cparser.mly"
                                        ( "@name(" ^ fst _3 ^ ")" )
# 2977 "src/frontc/cparser.ml"
               : 'id_or_typename))
; (fun __caml_parser_env ->
    Obj.repr(
# 461 "src/frontc/cparser.mly"
                                        ( () )
# 2983 "src/frontc/cparser.ml"
               : 'maybecomma))
; (fun __caml_parser_env ->
    Obj.repr(
# 462 "src/frontc/cparser.mly"
                                        ( () )
# 2989 "src/frontc/cparser.ml"
               : 'maybecomma))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : string * Cabs.cabsloc) in
    Obj.repr(
# 469 "src/frontc/cparser.mly"
          (VARIABLE (fst _1), snd _1)
# 2996 "src/frontc/cparser.ml"
               : 'primary_expression))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : Cabs.constant * cabsloc) in
    Obj.repr(
# 471 "src/frontc/cparser.mly"
          (CONSTANT (fst _1), snd _1)
# 3003 "src/frontc/cparser.ml"
               : 'primary_expression))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : Cabs.expression list * cabsloc) in
    Obj.repr(
# 473 "src/frontc/cparser.mly"
          (PAREN (smooth_expression (fst _1)), snd _1)
# 3010 "src/frontc/cparser.ml"
               : 'primary_expression))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : Cabs.cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 1 : Cabs.block * cabsloc * cabsloc) in
    Obj.repr(
# 475 "src/frontc/cparser.mly"
          ( GNU_BODY (fst3 _2), _1 )
# 3018 "src/frontc/cparser.ml"
               : 'primary_expression))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 3 : Cabs.cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 2 : Cabs.cabsloc) in
    let _3 = (Parsing.peek_val __caml_parser_env 1 : string * Cabs.cabsloc) in
    Obj.repr(
# 479 "src/frontc/cparser.mly"
                         ( EXPR_PATTERN(fst _3), _1 )
# 3027 "src/frontc/cparser.ml"
               : 'primary_expression))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'primary_expression) in
    Obj.repr(
# 484 "src/frontc/cparser.mly"
                        ( _1 )
# 3034 "src/frontc/cparser.ml"
               : 'postfix_expression))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 1 : 'postfix_expression) in
    let _2 = (Parsing.peek_val __caml_parser_env 0 : Cabs.expression list) in
    Obj.repr(
# 486 "src/frontc/cparser.mly"
   (INDEX (fst _1, smooth_expression _2), snd _1)
# 3042 "src/frontc/cparser.ml"
               : 'postfix_expression))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 3 : 'postfix_expression) in
    let _2 = (Parsing.peek_val __caml_parser_env 2 : Cabs.cabsloc) in
    let _3 = (Parsing.peek_val __caml_parser_env 1 : Cabs.expression list) in
    Obj.repr(
# 488 "src/frontc/cparser.mly"
   (CALL (fst _1, _3), snd _1)
# 3051 "src/frontc/cparser.ml"
               : 'postfix_expression))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 5 : Cabs.cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 4 : Cabs.cabsloc) in
    let _3 = (Parsing.peek_val __caml_parser_env 3 : Cabs.expression * cabsloc) in
    let _5 = (Parsing.peek_val __caml_parser_env 1 : Cabs.spec_elem list * Cabs.decl_type) in
    Obj.repr(
# 490 "src/frontc/cparser.mly"
                        ( let b, d = _5 in
                          CALL (VARIABLE "__builtin_va_arg", 
                                [fst _3; TYPE_SIZEOF (b, d)]), _1 )
# 3063 "src/frontc/cparser.ml"
               : 'postfix_expression))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 5 : Cabs.cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 4 : Cabs.cabsloc) in
    let _3 = (Parsing.peek_val __caml_parser_env 3 : Cabs.spec_elem list * Cabs.decl_type) in
    let _5 = (Parsing.peek_val __caml_parser_env 1 : Cabs.spec_elem list * Cabs.decl_type) in
    Obj.repr(
# 494 "src/frontc/cparser.mly"
                        ( let b1,d1 = _3 in
                          let b2,d2 = _5 in
                          CALL (VARIABLE "__builtin_types_compatible_p", 
                                [TYPE_SIZEOF(b1,d1); TYPE_SIZEOF(b2,d2)]), _1 )
# 3076 "src/frontc/cparser.ml"
               : 'postfix_expression))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 5 : Cabs.cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 4 : Cabs.cabsloc) in
    let _3 = (Parsing.peek_val __caml_parser_env 3 : Cabs.spec_elem list * Cabs.decl_type) in
    let _5 = (Parsing.peek_val __caml_parser_env 1 : 'offsetof_member_designator) in
    Obj.repr(
# 499 "src/frontc/cparser.mly"
                        ( transformOffsetOf _3 _5, _1 )
# 3086 "src/frontc/cparser.ml"
               : 'postfix_expression))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : 'postfix_expression) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : 'id_or_typename) in
    Obj.repr(
# 501 "src/frontc/cparser.mly"
          (MEMBEROF (fst _1, _3), snd _1)
# 3094 "src/frontc/cparser.ml"
               : 'postfix_expression))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : 'postfix_expression) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : 'id_or_typename) in
    Obj.repr(
# 503 "src/frontc/cparser.mly"
          (MEMBEROFPTR (fst _1, _3), snd _1)
# 3102 "src/frontc/cparser.ml"
               : 'postfix_expression))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 1 : 'postfix_expression) in
    let _2 = (Parsing.peek_val __caml_parser_env 0 : Cabs.cabsloc) in
    Obj.repr(
# 505 "src/frontc/cparser.mly"
          (UNARY (POSINCR, fst _1), snd _1)
# 3110 "src/frontc/cparser.ml"
               : 'postfix_expression))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 1 : 'postfix_expression) in
    let _2 = (Parsing.peek_val __caml_parser_env 0 : Cabs.cabsloc) in
    Obj.repr(
# 507 "src/frontc/cparser.mly"
          (UNARY (POSDECR, fst _1), snd _1)
# 3118 "src/frontc/cparser.ml"
               : 'postfix_expression))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 5 : Cabs.cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 4 : Cabs.spec_elem list * Cabs.decl_type) in
    let _4 = (Parsing.peek_val __caml_parser_env 2 : Cabs.cabsloc) in
    let _5 = (Parsing.peek_val __caml_parser_env 1 : 'initializer_list_opt) in
    let _6 = (Parsing.peek_val __caml_parser_env 0 : Cabs.cabsloc) in
    Obj.repr(
# 510 "src/frontc/cparser.mly"
          ( CAST(_2, COMPOUND_INIT _5), _1 )
# 3129 "src/frontc/cparser.ml"
               : 'postfix_expression))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'id_or_typename) in
    Obj.repr(
# 515 "src/frontc/cparser.mly"
          ( VARIABLE (_1) )
# 3136 "src/frontc/cparser.ml"
               : 'offsetof_member_designator))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : 'offsetof_member_designator) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : string * Cabs.cabsloc) in
    Obj.repr(
# 517 "src/frontc/cparser.mly"
   ( MEMBEROF (_1, fst _3) )
# 3144 "src/frontc/cparser.ml"
               : 'offsetof_member_designator))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 1 : 'offsetof_member_designator) in
    let _2 = (Parsing.peek_val __caml_parser_env 0 : Cabs.expression list) in
    Obj.repr(
# 519 "src/frontc/cparser.mly"
   ( INDEX (_1, smooth_expression _2) )
# 3152 "src/frontc/cparser.ml"
               : 'offsetof_member_designator))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'postfix_expression) in
    Obj.repr(
# 524 "src/frontc/cparser.mly"
                        ( _1 )
# 3159 "src/frontc/cparser.ml"
               : 'unary_expression))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 1 : Cabs.cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 0 : 'unary_expression) in
    Obj.repr(
# 526 "src/frontc/cparser.mly"
          (UNARY (PREINCR, fst _2), _1)
# 3167 "src/frontc/cparser.ml"
               : 'unary_expression))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 1 : Cabs.cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 0 : 'unary_expression) in
    Obj.repr(
# 528 "src/frontc/cparser.mly"
          (UNARY (PREDECR, fst _2), _1)
# 3175 "src/frontc/cparser.ml"
               : 'unary_expression))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 1 : Cabs.cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 0 : 'unary_expression) in
    Obj.repr(
# 530 "src/frontc/cparser.mly"
          (EXPR_SIZEOF (fst _2), _1)
# 3183 "src/frontc/cparser.ml"
               : 'unary_expression))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 3 : Cabs.cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 2 : Cabs.cabsloc) in
    let _3 = (Parsing.peek_val __caml_parser_env 1 : Cabs.spec_elem list * Cabs.decl_type) in
    Obj.repr(
# 532 "src/frontc/cparser.mly"
          (let b, d = _3 in TYPE_SIZEOF (b, d), _1)
# 3192 "src/frontc/cparser.ml"
               : 'unary_expression))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 1 : Cabs.cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 0 : 'unary_expression) in
    Obj.repr(
# 534 "src/frontc/cparser.mly"
          (EXPR_ALIGNOF (fst _2), _1)
# 3200 "src/frontc/cparser.ml"
               : 'unary_expression))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 3 : Cabs.cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 2 : Cabs.cabsloc) in
    let _3 = (Parsing.peek_val __caml_parser_env 1 : Cabs.spec_elem list * Cabs.decl_type) in
    Obj.repr(
# 536 "src/frontc/cparser.mly"
          (let b, d = _3 in TYPE_ALIGNOF (b, d), _1)
# 3209 "src/frontc/cparser.ml"
               : 'unary_expression))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 1 : Cabs.cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 0 : 'cast_expression) in
    Obj.repr(
# 538 "src/frontc/cparser.mly"
          (UNARY (PLUS, fst _2), _1)
# 3217 "src/frontc/cparser.ml"
               : 'unary_expression))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 1 : Cabs.cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 0 : 'cast_expression) in
    Obj.repr(
# 540 "src/frontc/cparser.mly"
          (UNARY (MINUS, fst _2), _1)
# 3225 "src/frontc/cparser.ml"
               : 'unary_expression))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 1 : Cabs.cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 0 : 'cast_expression) in
    Obj.repr(
# 542 "src/frontc/cparser.mly"
          (UNARY (MEMOF, fst _2), _1)
# 3233 "src/frontc/cparser.ml"
               : 'unary_expression))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 1 : Cabs.cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 0 : 'cast_expression) in
    Obj.repr(
# 544 "src/frontc/cparser.mly"
          (UNARY (ADDROF, fst _2), _1)
# 3241 "src/frontc/cparser.ml"
               : 'unary_expression))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 1 : Cabs.cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 0 : 'cast_expression) in
    Obj.repr(
# 546 "src/frontc/cparser.mly"
          (UNARY (NOT, fst _2), _1)
# 3249 "src/frontc/cparser.ml"
               : 'unary_expression))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 1 : Cabs.cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 0 : 'cast_expression) in
    Obj.repr(
# 548 "src/frontc/cparser.mly"
          (UNARY (BNOT, fst _2), _1)
# 3257 "src/frontc/cparser.ml"
               : 'unary_expression))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 1 : Cabs.cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 0 : string * Cabs.cabsloc) in
    Obj.repr(
# 549 "src/frontc/cparser.mly"
                               ( LABELADDR (fst _2), _1 )
# 3265 "src/frontc/cparser.ml"
               : 'unary_expression))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'unary_expression) in
    Obj.repr(
# 554 "src/frontc/cparser.mly"
                         ( _1 )
# 3272 "src/frontc/cparser.ml"
               : 'cast_expression))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 3 : Cabs.cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 2 : Cabs.spec_elem list * Cabs.decl_type) in
    let _4 = (Parsing.peek_val __caml_parser_env 0 : 'cast_expression) in
    Obj.repr(
# 556 "src/frontc/cparser.mly"
           ( CAST(_2, SINGLE_INIT (fst _4)), _1 )
# 3281 "src/frontc/cparser.ml"
               : 'cast_expression))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'cast_expression) in
    Obj.repr(
# 561 "src/frontc/cparser.mly"
                         ( _1 )
# 3288 "src/frontc/cparser.ml"
               : 'multiplicative_expression))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : 'multiplicative_expression) in
    let _2 = (Parsing.peek_val __caml_parser_env 1 : Cabs.cabsloc) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : 'cast_expression) in
    Obj.repr(
# 563 "src/frontc/cparser.mly"
   (BINARY(MUL, fst _1, fst _3), snd _1)
# 3297 "src/frontc/cparser.ml"
               : 'multiplicative_expression))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : 'multiplicative_expression) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : 'cast_expression) in
    Obj.repr(
# 565 "src/frontc/cparser.mly"
   (BINARY(DIV, fst _1, fst _3), snd _1)
# 3305 "src/frontc/cparser.ml"
               : 'multiplicative_expression))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : 'multiplicative_expression) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : 'cast_expression) in
    Obj.repr(
# 567 "src/frontc/cparser.mly"
   (BINARY(MOD, fst _1, fst _3), snd _1)
# 3313 "src/frontc/cparser.ml"
               : 'multiplicative_expression))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'multiplicative_expression) in
    Obj.repr(
# 572 "src/frontc/cparser.mly"
                        ( _1 )
# 3320 "src/frontc/cparser.ml"
               : 'additive_expression))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : 'additive_expression) in
    let _2 = (Parsing.peek_val __caml_parser_env 1 : Cabs.cabsloc) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : 'multiplicative_expression) in
    Obj.repr(
# 574 "src/frontc/cparser.mly"
   (BINARY(ADD, fst _1, fst _3), snd _1)
# 3329 "src/frontc/cparser.ml"
               : 'additive_expression))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : 'additive_expression) in
    let _2 = (Parsing.peek_val __caml_parser_env 1 : Cabs.cabsloc) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : 'multiplicative_expression) in
    Obj.repr(
# 576 "src/frontc/cparser.mly"
   (BINARY(SUB, fst _1, fst _3), snd _1)
# 3338 "src/frontc/cparser.ml"
               : 'additive_expression))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'additive_expression) in
    Obj.repr(
# 581 "src/frontc/cparser.mly"
                         ( _1 )
# 3345 "src/frontc/cparser.ml"
               : 'shift_expression))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : 'shift_expression) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : 'additive_expression) in
    Obj.repr(
# 583 "src/frontc/cparser.mly"
   (BINARY(SHL, fst _1, fst _3), snd _1)
# 3353 "src/frontc/cparser.ml"
               : 'shift_expression))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : 'shift_expression) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : 'additive_expression) in
    Obj.repr(
# 585 "src/frontc/cparser.mly"
   (BINARY(SHR, fst _1, fst _3), snd _1)
# 3361 "src/frontc/cparser.ml"
               : 'shift_expression))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'shift_expression) in
    Obj.repr(
# 591 "src/frontc/cparser.mly"
                        ( _1 )
# 3368 "src/frontc/cparser.ml"
               : 'relational_expression))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : 'relational_expression) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : 'shift_expression) in
    Obj.repr(
# 593 "src/frontc/cparser.mly"
   (BINARY(LT, fst _1, fst _3), snd _1)
# 3376 "src/frontc/cparser.ml"
               : 'relational_expression))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : 'relational_expression) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : 'shift_expression) in
    Obj.repr(
# 595 "src/frontc/cparser.mly"
   (BINARY(GT, fst _1, fst _3), snd _1)
# 3384 "src/frontc/cparser.ml"
               : 'relational_expression))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : 'relational_expression) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : 'shift_expression) in
    Obj.repr(
# 597 "src/frontc/cparser.mly"
   (BINARY(LE, fst _1, fst _3), snd _1)
# 3392 "src/frontc/cparser.ml"
               : 'relational_expression))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : 'relational_expression) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : 'shift_expression) in
    Obj.repr(
# 599 "src/frontc/cparser.mly"
   (BINARY(GE, fst _1, fst _3), snd _1)
# 3400 "src/frontc/cparser.ml"
               : 'relational_expression))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'relational_expression) in
    Obj.repr(
# 604 "src/frontc/cparser.mly"
                        ( _1 )
# 3407 "src/frontc/cparser.ml"
               : 'equality_expression))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : 'equality_expression) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : 'relational_expression) in
    Obj.repr(
# 606 "src/frontc/cparser.mly"
   (BINARY(EQ, fst _1, fst _3), snd _1)
# 3415 "src/frontc/cparser.ml"
               : 'equality_expression))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : 'equality_expression) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : 'relational_expression) in
    Obj.repr(
# 608 "src/frontc/cparser.mly"
   (BINARY(NE, fst _1, fst _3), snd _1)
# 3423 "src/frontc/cparser.ml"
               : 'equality_expression))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'equality_expression) in
    Obj.repr(
# 614 "src/frontc/cparser.mly"
                       ( _1 )
# 3430 "src/frontc/cparser.ml"
               : 'bitwise_and_expression))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : 'bitwise_and_expression) in
    let _2 = (Parsing.peek_val __caml_parser_env 1 : Cabs.cabsloc) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : 'equality_expression) in
    Obj.repr(
# 616 "src/frontc/cparser.mly"
   (BINARY(BAND, fst _1, fst _3), snd _1)
# 3439 "src/frontc/cparser.ml"
               : 'bitwise_and_expression))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'bitwise_and_expression) in
    Obj.repr(
# 621 "src/frontc/cparser.mly"
                       ( _1 )
# 3446 "src/frontc/cparser.ml"
               : 'bitwise_xor_expression))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : 'bitwise_xor_expression) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : 'bitwise_and_expression) in
    Obj.repr(
# 623 "src/frontc/cparser.mly"
   (BINARY(XOR, fst _1, fst _3), snd _1)
# 3454 "src/frontc/cparser.ml"
               : 'bitwise_xor_expression))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'bitwise_xor_expression) in
    Obj.repr(
# 628 "src/frontc/cparser.mly"
                        ( _1 )
# 3461 "src/frontc/cparser.ml"
               : 'bitwise_or_expression))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : 'bitwise_or_expression) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : 'bitwise_xor_expression) in
    Obj.repr(
# 630 "src/frontc/cparser.mly"
   (BINARY(BOR, fst _1, fst _3), snd _1)
# 3469 "src/frontc/cparser.ml"
               : 'bitwise_or_expression))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'bitwise_or_expression) in
    Obj.repr(
# 635 "src/frontc/cparser.mly"
                        ( _1 )
# 3476 "src/frontc/cparser.ml"
               : 'logical_and_expression))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : 'logical_and_expression) in
    let _2 = (Parsing.peek_val __caml_parser_env 1 : Cabs.cabsloc) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : 'bitwise_or_expression) in
    Obj.repr(
# 637 "src/frontc/cparser.mly"
   (BINARY(AND, fst _1, fst _3), snd _1)
# 3485 "src/frontc/cparser.ml"
               : 'logical_and_expression))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'logical_and_expression) in
    Obj.repr(
# 642 "src/frontc/cparser.mly"
                        ( _1 )
# 3492 "src/frontc/cparser.ml"
               : 'logical_or_expression))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : 'logical_or_expression) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : 'logical_and_expression) in
    Obj.repr(
# 644 "src/frontc/cparser.mly"
   (BINARY(OR, fst _1, fst _3), snd _1)
# 3500 "src/frontc/cparser.ml"
               : 'logical_or_expression))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'logical_or_expression) in
    Obj.repr(
# 649 "src/frontc/cparser.mly"
                         ( _1 )
# 3507 "src/frontc/cparser.ml"
               : 'conditional_expression))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 4 : 'logical_or_expression) in
    let _3 = (Parsing.peek_val __caml_parser_env 2 : Cabs.expression) in
    let _5 = (Parsing.peek_val __caml_parser_env 0 : 'conditional_expression) in
    Obj.repr(
# 651 "src/frontc/cparser.mly"
   (QUESTION (fst _1, _3, fst _5), snd _1)
# 3516 "src/frontc/cparser.ml"
               : 'conditional_expression))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'conditional_expression) in
    Obj.repr(
# 659 "src/frontc/cparser.mly"
                         ( _1 )
# 3523 "src/frontc/cparser.ml"
               : 'assignment_expression))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : 'cast_expression) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : 'assignment_expression) in
    Obj.repr(
# 661 "src/frontc/cparser.mly"
   (BINARY(ASSIGN, fst _1, fst _3), snd _1)
# 3531 "src/frontc/cparser.ml"
               : 'assignment_expression))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : 'cast_expression) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : 'assignment_expression) in
    Obj.repr(
# 663 "src/frontc/cparser.mly"
   (BINARY(ADD_ASSIGN, fst _1, fst _3), snd _1)
# 3539 "src/frontc/cparser.ml"
               : 'assignment_expression))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : 'cast_expression) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : 'assignment_expression) in
    Obj.repr(
# 665 "src/frontc/cparser.mly"
   (BINARY(SUB_ASSIGN, fst _1, fst _3), snd _1)
# 3547 "src/frontc/cparser.ml"
               : 'assignment_expression))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : 'cast_expression) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : 'assignment_expression) in
    Obj.repr(
# 667 "src/frontc/cparser.mly"
   (BINARY(MUL_ASSIGN, fst _1, fst _3), snd _1)
# 3555 "src/frontc/cparser.ml"
               : 'assignment_expression))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : 'cast_expression) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : 'assignment_expression) in
    Obj.repr(
# 669 "src/frontc/cparser.mly"
   (BINARY(DIV_ASSIGN, fst _1, fst _3), snd _1)
# 3563 "src/frontc/cparser.ml"
               : 'assignment_expression))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : 'cast_expression) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : 'assignment_expression) in
    Obj.repr(
# 671 "src/frontc/cparser.mly"
   (BINARY(MOD_ASSIGN, fst _1, fst _3), snd _1)
# 3571 "src/frontc/cparser.ml"
               : 'assignment_expression))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : 'cast_expression) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : 'assignment_expression) in
    Obj.repr(
# 673 "src/frontc/cparser.mly"
   (BINARY(BAND_ASSIGN, fst _1, fst _3), snd _1)
# 3579 "src/frontc/cparser.ml"
               : 'assignment_expression))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : 'cast_expression) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : 'assignment_expression) in
    Obj.repr(
# 675 "src/frontc/cparser.mly"
   (BINARY(BOR_ASSIGN, fst _1, fst _3), snd _1)
# 3587 "src/frontc/cparser.ml"
               : 'assignment_expression))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : 'cast_expression) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : 'assignment_expression) in
    Obj.repr(
# 677 "src/frontc/cparser.mly"
   (BINARY(XOR_ASSIGN, fst _1, fst _3), snd _1)
# 3595 "src/frontc/cparser.ml"
               : 'assignment_expression))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : 'cast_expression) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : 'assignment_expression) in
    Obj.repr(
# 679 "src/frontc/cparser.mly"
   (BINARY(SHL_ASSIGN, fst _1, fst _3), snd _1)
# 3603 "src/frontc/cparser.ml"
               : 'assignment_expression))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : 'cast_expression) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : 'assignment_expression) in
    Obj.repr(
# 681 "src/frontc/cparser.mly"
   (BINARY(SHR_ASSIGN, fst _1, fst _3), snd _1)
# 3611 "src/frontc/cparser.ml"
               : 'assignment_expression))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'assignment_expression) in
    Obj.repr(
# 686 "src/frontc/cparser.mly"
                        ( _1 )
# 3618 "src/frontc/cparser.ml"
               : Cabs.expression * cabsloc))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : string * Cabs.cabsloc) in
    Obj.repr(
# 691 "src/frontc/cparser.mly"
               (CONST_INT (fst _1), snd _1)
# 3625 "src/frontc/cparser.ml"
               : Cabs.constant * cabsloc))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : string * Cabs.cabsloc) in
    Obj.repr(
# 692 "src/frontc/cparser.mly"
                 (CONST_FLOAT (fst _1), snd _1)
# 3632 "src/frontc/cparser.ml"
               : Cabs.constant * cabsloc))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : int64 list * Cabs.cabsloc) in
    Obj.repr(
# 693 "src/frontc/cparser.mly"
                (CONST_CHAR (fst _1), snd _1)
# 3639 "src/frontc/cparser.ml"
               : Cabs.constant * cabsloc))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : int64 list * Cabs.cabsloc) in
    Obj.repr(
# 694 "src/frontc/cparser.mly"
                 (CONST_WCHAR (fst _1), snd _1)
# 3646 "src/frontc/cparser.ml"
               : Cabs.constant * cabsloc))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : string * cabsloc) in
    Obj.repr(
# 695 "src/frontc/cparser.mly"
                             (CONST_STRING (fst _1), snd _1)
# 3653 "src/frontc/cparser.ml"
               : Cabs.constant * cabsloc))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : int64 list * cabsloc) in
    Obj.repr(
# 696 "src/frontc/cparser.mly"
                   (CONST_WSTRING (fst _1), snd _1)
# 3660 "src/frontc/cparser.ml"
               : Cabs.constant * cabsloc))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : int64 list Queue.t * cabsloc) in
    Obj.repr(
# 702 "src/frontc/cparser.mly"
                                        (
     let queue, location = _1 in
     let buffer = Buffer.create (Queue.length queue) in
     Queue.iter
       (List.iter
	  (fun value ->
	    let char = int64_to_char value in
	    Buffer.add_char buffer char))
       queue;
     Buffer.contents buffer, location
   )
# 3677 "src/frontc/cparser.ml"
               : string * cabsloc))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : int64 list * Cabs.cabsloc) in
    Obj.repr(
# 716 "src/frontc/cparser.mly"
                                        (intlist_to_string (fst _1) )
# 3684 "src/frontc/cparser.ml"
               : 'one_string_constant))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'one_string) in
    Obj.repr(
# 719 "src/frontc/cparser.mly"
                                        (
      let queue = Queue.create () in
      Queue.add (fst _1) queue;
      queue, snd _1
    )
# 3695 "src/frontc/cparser.ml"
               : int64 list Queue.t * cabsloc))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 1 : int64 list Queue.t * cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 0 : 'one_string) in
    Obj.repr(
# 724 "src/frontc/cparser.mly"
                                        (
      Queue.add (fst _2) (fst _1);
      _1
    )
# 3706 "src/frontc/cparser.ml"
               : int64 list Queue.t * cabsloc))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : int64 list * Cabs.cabsloc) in
    Obj.repr(
# 731 "src/frontc/cparser.mly"
                                        ( _1 )
# 3713 "src/frontc/cparser.ml"
               : int64 list * cabsloc))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 1 : int64 list * cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 0 : 'one_string) in
    Obj.repr(
# 732 "src/frontc/cparser.mly"
                                        ( (fst _1) @ (fst _2), snd _1 )
# 3721 "src/frontc/cparser.ml"
               : int64 list * cabsloc))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 1 : int64 list * cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 0 : int64 list * Cabs.cabsloc) in
    Obj.repr(
# 733 "src/frontc/cparser.mly"
                                        ( (fst _1) @ (fst _2), snd _1 )
# 3729 "src/frontc/cparser.ml"
               : int64 list * cabsloc))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : int64 list * Cabs.cabsloc) in
    Obj.repr(
# 738 "src/frontc/cparser.mly"
                  (_1)
# 3736 "src/frontc/cparser.ml"
               : 'one_string))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : Cabs.cabsloc) in
    Obj.repr(
# 739 "src/frontc/cparser.mly"
                                        ((Cabshelper.explodeStringToInts 
					    !currentFunctionName), _1)
# 3744 "src/frontc/cparser.ml"
               : 'one_string))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : Cabs.cabsloc) in
    Obj.repr(
# 741 "src/frontc/cparser.mly"
                                        ((Cabshelper.explodeStringToInts 
					    !currentFunctionName), _1)
# 3752 "src/frontc/cparser.ml"
               : 'one_string))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : Cabs.expression * cabsloc) in
    Obj.repr(
# 746 "src/frontc/cparser.mly"
                        ( SINGLE_INIT (fst _1) )
# 3759 "src/frontc/cparser.ml"
               : Cabs.init_expression))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : Cabs.cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 1 : 'initializer_list_opt) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : Cabs.cabsloc) in
    Obj.repr(
# 748 "src/frontc/cparser.mly"
   ( COMPOUND_INIT _2)
# 3768 "src/frontc/cparser.ml"
               : Cabs.init_expression))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : Cabs.initwhat * Cabs.init_expression) in
    Obj.repr(
# 751 "src/frontc/cparser.mly"
                                            ( [_1] )
# 3775 "src/frontc/cparser.ml"
               : (Cabs.initwhat * Cabs.init_expression) list))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : Cabs.initwhat * Cabs.init_expression) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : 'initializer_list_opt) in
    Obj.repr(
# 752 "src/frontc/cparser.mly"
                                            ( _1 :: _3 )
# 3783 "src/frontc/cparser.ml"
               : (Cabs.initwhat * Cabs.init_expression) list))
; (fun __caml_parser_env ->
    Obj.repr(
# 755 "src/frontc/cparser.mly"
                                            ( [] )
# 3789 "src/frontc/cparser.ml"
               : 'initializer_list_opt))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : (Cabs.initwhat * Cabs.init_expression) list) in
    Obj.repr(
# 756 "src/frontc/cparser.mly"
                                            ( _1 )
# 3796 "src/frontc/cparser.ml"
               : 'initializer_list_opt))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : Cabs.initwhat) in
    let _2 = (Parsing.peek_val __caml_parser_env 1 : 'eq_opt) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : Cabs.init_expression) in
    Obj.repr(
# 759 "src/frontc/cparser.mly"
                                            ( (_1, _3) )
# 3805 "src/frontc/cparser.ml"
               : Cabs.initwhat * Cabs.init_expression))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 1 : 'gcc_init_designators) in
    let _2 = (Parsing.peek_val __caml_parser_env 0 : Cabs.init_expression) in
    Obj.repr(
# 760 "src/frontc/cparser.mly"
                                         ( (_1, _2) )
# 3813 "src/frontc/cparser.ml"
               : Cabs.initwhat * Cabs.init_expression))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : Cabs.init_expression) in
    Obj.repr(
# 761 "src/frontc/cparser.mly"
                                        ( (NEXT_INIT, _1) )
# 3820 "src/frontc/cparser.ml"
               : Cabs.initwhat * Cabs.init_expression))
; (fun __caml_parser_env ->
    Obj.repr(
# 764 "src/frontc/cparser.mly"
                             ( () )
# 3826 "src/frontc/cparser.ml"
               : 'eq_opt))
; (fun __caml_parser_env ->
    Obj.repr(
# 766 "src/frontc/cparser.mly"
                                 ( () )
# 3832 "src/frontc/cparser.ml"
               : 'eq_opt))
; (fun __caml_parser_env ->
    let _2 = (Parsing.peek_val __caml_parser_env 1 : 'id_or_typename) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : Cabs.initwhat) in
    Obj.repr(
# 769 "src/frontc/cparser.mly"
                                                 ( INFIELD_INIT(_2, _3) )
# 3840 "src/frontc/cparser.ml"
               : Cabs.initwhat))
; (fun __caml_parser_env ->
    let _2 = (Parsing.peek_val __caml_parser_env 2 : Cabs.expression * cabsloc) in
    let _4 = (Parsing.peek_val __caml_parser_env 0 : Cabs.initwhat) in
    Obj.repr(
# 771 "src/frontc/cparser.mly"
                                        ( ATINDEX_INIT(fst _2, _4) )
# 3848 "src/frontc/cparser.ml"
               : Cabs.initwhat))
; (fun __caml_parser_env ->
    let _2 = (Parsing.peek_val __caml_parser_env 3 : Cabs.expression * cabsloc) in
    let _4 = (Parsing.peek_val __caml_parser_env 1 : Cabs.expression * cabsloc) in
    Obj.repr(
# 773 "src/frontc/cparser.mly"
                                        ( ATINDEXRANGE_INIT(fst _2, fst _4) )
# 3856 "src/frontc/cparser.ml"
               : Cabs.initwhat))
; (fun __caml_parser_env ->
    Obj.repr(
# 776 "src/frontc/cparser.mly"
                                        ( NEXT_INIT )
# 3862 "src/frontc/cparser.ml"
               : Cabs.initwhat))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : Cabs.initwhat) in
    Obj.repr(
# 777 "src/frontc/cparser.mly"
                                        ( _1 )
# 3869 "src/frontc/cparser.ml"
               : Cabs.initwhat))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 1 : 'id_or_typename) in
    Obj.repr(
# 781 "src/frontc/cparser.mly"
                                        ( INFIELD_INIT(_1, NEXT_INIT) )
# 3876 "src/frontc/cparser.ml"
               : 'gcc_init_designators))
; (fun __caml_parser_env ->
    Obj.repr(
# 785 "src/frontc/cparser.mly"
                                    ( [] )
# 3882 "src/frontc/cparser.ml"
               : Cabs.expression list))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : Cabs.expression list * cabsloc) in
    Obj.repr(
# 786 "src/frontc/cparser.mly"
                                    ( fst _1 )
# 3889 "src/frontc/cparser.ml"
               : Cabs.expression list))
; (fun __caml_parser_env ->
    Obj.repr(
# 791 "src/frontc/cparser.mly"
          (NOTHING)
# 3895 "src/frontc/cparser.ml"
               : Cabs.expression))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : Cabs.expression list * cabsloc) in
    Obj.repr(
# 793 "src/frontc/cparser.mly"
          (smooth_expression (fst _1))
# 3902 "src/frontc/cparser.ml"
               : Cabs.expression))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : Cabs.expression * cabsloc) in
    Obj.repr(
# 797 "src/frontc/cparser.mly"
                                           ([fst _1], snd _1)
# 3909 "src/frontc/cparser.ml"
               : Cabs.expression list * cabsloc))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : Cabs.expression * cabsloc) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : Cabs.expression list * cabsloc) in
    Obj.repr(
# 798 "src/frontc/cparser.mly"
                                                  ( fst _1 :: fst _3, snd _1 )
# 3917 "src/frontc/cparser.ml"
               : Cabs.expression list * cabsloc))
; (fun __caml_parser_env ->
    let _3 = (Parsing.peek_val __caml_parser_env 0 : Cabs.expression list * cabsloc) in
    Obj.repr(
# 799 "src/frontc/cparser.mly"
                                                  ( _3 )
# 3924 "src/frontc/cparser.ml"
               : Cabs.expression list * cabsloc))
; (fun __caml_parser_env ->
    Obj.repr(
# 803 "src/frontc/cparser.mly"
                                    ( NOTHING )
# 3930 "src/frontc/cparser.ml"
               : 'comma_expression_opt))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : Cabs.expression list * cabsloc) in
    Obj.repr(
# 804 "src/frontc/cparser.mly"
                                    ( smooth_expression (fst _1) )
# 3937 "src/frontc/cparser.ml"
               : 'comma_expression_opt))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : Cabs.cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 1 : Cabs.expression list * cabsloc) in
    Obj.repr(
# 808 "src/frontc/cparser.mly"
                                                   ( _2 )
# 3945 "src/frontc/cparser.ml"
               : Cabs.expression list * cabsloc))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : Cabs.cabsloc) in
    Obj.repr(
# 809 "src/frontc/cparser.mly"
                                                   ( [], _1 )
# 3952 "src/frontc/cparser.ml"
               : Cabs.expression list * cabsloc))
; (fun __caml_parser_env ->
    let _2 = (Parsing.peek_val __caml_parser_env 1 : Cabs.expression list * cabsloc) in
    Obj.repr(
# 813 "src/frontc/cparser.mly"
                                                       ( fst _2 )
# 3959 "src/frontc/cparser.ml"
               : Cabs.expression list))
; (fun __caml_parser_env ->
    Obj.repr(
# 814 "src/frontc/cparser.mly"
                                                       ( [] )
# 3965 "src/frontc/cparser.ml"
               : Cabs.expression list))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 4 : 'block_begin) in
    let _2 = (Parsing.peek_val __caml_parser_env 3 : string list) in
    let _3 = (Parsing.peek_val __caml_parser_env 2 : 'block_attrs) in
    let _4 = (Parsing.peek_val __caml_parser_env 1 : Cabs.statement list) in
    let _5 = (Parsing.peek_val __caml_parser_env 0 : Cabs.cabsloc) in
    Obj.repr(
# 821 "src/frontc/cparser.mly"
                                         (!Lexerhack.pop_context();
                                          { blabels = _2;
                                            battrs = _3;
                                            bstmts = _4 },
					    _1, _5
                                         )
# 3981 "src/frontc/cparser.ml"
               : Cabs.block * cabsloc * cabsloc))
; (fun __caml_parser_env ->
    let _2 = (Parsing.peek_val __caml_parser_env 1 : Cabs.cabsloc) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : Cabs.cabsloc) in
    Obj.repr(
# 827 "src/frontc/cparser.mly"
                                         ( { blabels = [];
                                             battrs  = [];
                                             bstmts  = [] },
					     _2, _3
                                         )
# 3993 "src/frontc/cparser.ml"
               : Cabs.block * cabsloc * cabsloc))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : Cabs.cabsloc) in
    Obj.repr(
# 834 "src/frontc/cparser.mly"
                           (!Lexerhack.push_context (); _1)
# 4000 "src/frontc/cparser.ml"
               : 'block_begin))
; (fun __caml_parser_env ->
    Obj.repr(
# 838 "src/frontc/cparser.mly"
                                                            ( [] )
# 4006 "src/frontc/cparser.ml"
               : 'block_attrs))
; (fun __caml_parser_env ->
    let _2 = (Parsing.peek_val __caml_parser_env 0 : 'paren_attr_list_ne) in
    Obj.repr(
# 840 "src/frontc/cparser.mly"
                                        ( [("__blockattribute__", _2)] )
# 4013 "src/frontc/cparser.ml"
               : 'block_attrs))
; (fun __caml_parser_env ->
    Obj.repr(
# 845 "src/frontc/cparser.mly"
                                         ( [] )
# 4019 "src/frontc/cparser.ml"
               : Cabs.statement list))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 1 : Cabs.definition) in
    let _2 = (Parsing.peek_val __caml_parser_env 0 : Cabs.statement list) in
    Obj.repr(
# 846 "src/frontc/cparser.mly"
                                         ( DEFINITION(_1) :: _2 )
# 4027 "src/frontc/cparser.ml"
               : Cabs.statement list))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 1 : Cabs.statement) in
    let _2 = (Parsing.peek_val __caml_parser_env 0 : Cabs.statement list) in
    Obj.repr(
# 847 "src/frontc/cparser.mly"
                                         ( _1 :: _2 )
# 4035 "src/frontc/cparser.ml"
               : Cabs.statement list))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 1 : string * Cabs.cabsloc) in
    Obj.repr(
# 849 "src/frontc/cparser.mly"
                                         ( [ LABEL (fst _1, NOP (snd _1), 
                                                    snd _1)] )
# 4043 "src/frontc/cparser.ml"
               : Cabs.statement list))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 1 : 'pragma) in
    let _2 = (Parsing.peek_val __caml_parser_env 0 : Cabs.statement list) in
    Obj.repr(
# 851 "src/frontc/cparser.mly"
                                         ( _2 )
# 4051 "src/frontc/cparser.ml"
               : Cabs.statement list))
; (fun __caml_parser_env ->
    Obj.repr(
# 855 "src/frontc/cparser.mly"
                                                     ( [] )
# 4057 "src/frontc/cparser.ml"
               : string list))
; (fun __caml_parser_env ->
    let _2 = (Parsing.peek_val __caml_parser_env 2 : string list) in
    let _3 = (Parsing.peek_val __caml_parser_env 1 : Cabs.cabsloc) in
    let _4 = (Parsing.peek_val __caml_parser_env 0 : string list) in
    Obj.repr(
# 856 "src/frontc/cparser.mly"
                                                     ( _2 @ _4 )
# 4066 "src/frontc/cparser.ml"
               : string list))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : string * Cabs.cabsloc) in
    Obj.repr(
# 859 "src/frontc/cparser.mly"
                                         ( [ fst _1 ] )
# 4073 "src/frontc/cparser.ml"
               : string list))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : string * Cabs.cabsloc) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : string list) in
    Obj.repr(
# 860 "src/frontc/cparser.mly"
                                         ( fst _1 :: _3 )
# 4081 "src/frontc/cparser.ml"
               : string list))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : Cabs.cabsloc) in
    Obj.repr(
# 866 "src/frontc/cparser.mly"
               (NOP ((*handleLoc*) _1) )
# 4088 "src/frontc/cparser.ml"
               : Cabs.statement))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 1 : Cabs.expression list * cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 0 : Cabs.cabsloc) in
    Obj.repr(
# 868 "src/frontc/cparser.mly"
          (COMPUTATION (smooth_expression (fst _1), (*handleLoc*)(snd _1)))
# 4096 "src/frontc/cparser.ml"
               : Cabs.statement))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : Cabs.block * cabsloc * cabsloc) in
    Obj.repr(
# 869 "src/frontc/cparser.mly"
                        (BLOCK (fst3 _1, (*handleLoc*)(snd3 _1)))
# 4103 "src/frontc/cparser.ml"
               : Cabs.statement))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : Cabs.cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 1 : Cabs.expression list * cabsloc) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : Cabs.statement) in
    Obj.repr(
# 871 "src/frontc/cparser.mly"
                 (IF (smooth_expression (fst _2), _3, NOP _1, _1))
# 4112 "src/frontc/cparser.ml"
               : Cabs.statement))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 4 : Cabs.cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 3 : Cabs.expression list * cabsloc) in
    let _3 = (Parsing.peek_val __caml_parser_env 2 : Cabs.statement) in
    let _5 = (Parsing.peek_val __caml_parser_env 0 : Cabs.statement) in
    Obj.repr(
# 873 "src/frontc/cparser.mly"
                 (IF (smooth_expression (fst _2), _3, _5, (*handleLoc*) _1))
# 4122 "src/frontc/cparser.ml"
               : Cabs.statement))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : Cabs.cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 1 : Cabs.expression list * cabsloc) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : Cabs.statement) in
    Obj.repr(
# 875 "src/frontc/cparser.mly"
                        (SWITCH (smooth_expression (fst _2), _3, (*handleLoc*) _1))
# 4131 "src/frontc/cparser.ml"
               : Cabs.statement))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : Cabs.cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 1 : Cabs.expression list * cabsloc) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : Cabs.statement) in
    Obj.repr(
# 877 "src/frontc/cparser.mly"
          (WHILE (smooth_expression (fst _2), _3, (*handleLoc*) _1))
# 4140 "src/frontc/cparser.ml"
               : Cabs.statement))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 4 : Cabs.cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 3 : Cabs.statement) in
    let _3 = (Parsing.peek_val __caml_parser_env 2 : Cabs.cabsloc) in
    let _4 = (Parsing.peek_val __caml_parser_env 1 : Cabs.expression list * cabsloc) in
    let _5 = (Parsing.peek_val __caml_parser_env 0 : Cabs.cabsloc) in
    Obj.repr(
# 879 "src/frontc/cparser.mly"
                   (DOWHILE (smooth_expression (fst _4), _2, (*handleLoc*) _1))
# 4151 "src/frontc/cparser.ml"
               : Cabs.statement))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 7 : Cabs.cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 6 : Cabs.cabsloc) in
    let _3 = (Parsing.peek_val __caml_parser_env 5 : 'for_clause) in
    let _4 = (Parsing.peek_val __caml_parser_env 4 : Cabs.expression) in
    let _5 = (Parsing.peek_val __caml_parser_env 3 : Cabs.cabsloc) in
    let _6 = (Parsing.peek_val __caml_parser_env 2 : Cabs.expression) in
    let _8 = (Parsing.peek_val __caml_parser_env 0 : Cabs.statement) in
    Obj.repr(
# 882 "src/frontc/cparser.mly"
                          (FOR (_3, _4, _6, _8, (*handleLoc*) _1))
# 4164 "src/frontc/cparser.ml"
               : Cabs.statement))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 3 : string * Cabs.cabsloc) in
    let _3 = (Parsing.peek_val __caml_parser_env 1 : 'attribute_nocv_list) in
    let _4 = (Parsing.peek_val __caml_parser_env 0 : Cabs.statement) in
    Obj.repr(
# 884 "src/frontc/cparser.mly"
                   ((* The only attribute that should appear here
                                     is "unused". For now, we drop this on the
                                     floor, since unused labels are usually
                                     removed anyways by Rmtmps. *)
                                  LABEL (fst _1, _4, (snd _1)))
# 4177 "src/frontc/cparser.ml"
               : Cabs.statement))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 3 : Cabs.cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 2 : Cabs.expression * cabsloc) in
    let _4 = (Parsing.peek_val __caml_parser_env 0 : Cabs.statement) in
    Obj.repr(
# 890 "src/frontc/cparser.mly"
                          (CASE (fst _2, _4, (*handleLoc*) _1))
# 4186 "src/frontc/cparser.ml"
               : Cabs.statement))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 5 : Cabs.cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 4 : Cabs.expression * cabsloc) in
    let _4 = (Parsing.peek_val __caml_parser_env 2 : Cabs.expression * cabsloc) in
    let _6 = (Parsing.peek_val __caml_parser_env 0 : Cabs.statement) in
    Obj.repr(
# 892 "src/frontc/cparser.mly"
                          (CASERANGE (fst _2, fst _4, _6, (*handleLoc*) _1))
# 4196 "src/frontc/cparser.ml"
               : Cabs.statement))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 1 : Cabs.cabsloc) in
    Obj.repr(
# 894 "src/frontc/cparser.mly"
                          (DEFAULT (NOP _1, (*handleLoc*) _1))
# 4203 "src/frontc/cparser.ml"
               : Cabs.statement))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 1 : Cabs.cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 0 : Cabs.cabsloc) in
    Obj.repr(
# 895 "src/frontc/cparser.mly"
                       (RETURN (NOTHING, (*handleLoc*) _1))
# 4211 "src/frontc/cparser.ml"
               : Cabs.statement))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : Cabs.cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 1 : Cabs.expression list * cabsloc) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : Cabs.cabsloc) in
    Obj.repr(
# 897 "src/frontc/cparser.mly"
                          (RETURN (smooth_expression (fst _2), (*handleLoc*) _1))
# 4220 "src/frontc/cparser.ml"
               : Cabs.statement))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 1 : Cabs.cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 0 : Cabs.cabsloc) in
    Obj.repr(
# 898 "src/frontc/cparser.mly"
                        (BREAK ((*handleLoc*) _1))
# 4228 "src/frontc/cparser.ml"
               : Cabs.statement))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 1 : Cabs.cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 0 : Cabs.cabsloc) in
    Obj.repr(
# 899 "src/frontc/cparser.mly"
                        (CONTINUE ((*handleLoc*) _1))
# 4236 "src/frontc/cparser.ml"
               : Cabs.statement))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : Cabs.cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 1 : string * Cabs.cabsloc) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : Cabs.cabsloc) in
    Obj.repr(
# 901 "src/frontc/cparser.mly"
                   (GOTO (fst _2, (*handleLoc*) _1))
# 4245 "src/frontc/cparser.ml"
               : Cabs.statement))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 3 : Cabs.cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 2 : Cabs.cabsloc) in
    let _3 = (Parsing.peek_val __caml_parser_env 1 : Cabs.expression list * cabsloc) in
    let _4 = (Parsing.peek_val __caml_parser_env 0 : Cabs.cabsloc) in
    Obj.repr(
# 903 "src/frontc/cparser.mly"
                                 ( COMPGOTO (smooth_expression (fst _3), (*handleLoc*) _1) )
# 4255 "src/frontc/cparser.ml"
               : Cabs.statement))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 6 : Cabs.cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 5 : Cabs.attribute list) in
    let _3 = (Parsing.peek_val __caml_parser_env 4 : Cabs.cabsloc) in
    let _4 = (Parsing.peek_val __caml_parser_env 3 : 'asmtemplate) in
    let _5 = (Parsing.peek_val __caml_parser_env 2 : 'asmoutputs) in
    let _7 = (Parsing.peek_val __caml_parser_env 0 : Cabs.cabsloc) in
    Obj.repr(
# 905 "src/frontc/cparser.mly"
                        ( ASM (_2, _4, _5, (*handleLoc*) _1) )
# 4267 "src/frontc/cparser.ml"
               : Cabs.statement))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : string * Cabs.cabsloc) in
    Obj.repr(
# 906 "src/frontc/cparser.mly"
                        ( ASM ([], [fst _1], None, (*handleLoc*)(snd _1)))
# 4274 "src/frontc/cparser.ml"
               : Cabs.statement))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 4 : Cabs.cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 3 : Cabs.block * cabsloc * cabsloc) in
    let _3 = (Parsing.peek_val __caml_parser_env 2 : Cabs.cabsloc) in
    let _4 = (Parsing.peek_val __caml_parser_env 1 : Cabs.expression list * cabsloc) in
    let _5 = (Parsing.peek_val __caml_parser_env 0 : Cabs.block * cabsloc * cabsloc) in
    Obj.repr(
# 908 "src/frontc/cparser.mly"
                        ( let b, _, _ = _2 in
                          let h, _, _ = _5 in
                          if not !Cprint.msvcMode then 
                            parse_error "try/except in GCC code";
                          TRY_EXCEPT (b, COMMA (fst _4), h, (*handleLoc*) _1) )
# 4289 "src/frontc/cparser.ml"
               : Cabs.statement))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 3 : Cabs.cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 2 : Cabs.block * cabsloc * cabsloc) in
    let _3 = (Parsing.peek_val __caml_parser_env 1 : Cabs.cabsloc) in
    let _4 = (Parsing.peek_val __caml_parser_env 0 : Cabs.block * cabsloc * cabsloc) in
    Obj.repr(
# 914 "src/frontc/cparser.mly"
                        ( let b, _, _ = _2 in
                          let h, _, _ = _4 in
                          if not !Cprint.msvcMode then 
                            parse_error "try/finally in GCC code";
                          TRY_FINALLY (b, h, (*handleLoc*) _1) )
# 4303 "src/frontc/cparser.ml"
               : Cabs.statement))
; (fun __caml_parser_env ->
    let _2 = (Parsing.peek_val __caml_parser_env 1 : Cabs.cabsloc) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : Cabs.cabsloc) in
    Obj.repr(
# 920 "src/frontc/cparser.mly"
                                 ( (NOP _2))
# 4311 "src/frontc/cparser.ml"
               : Cabs.statement))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 1 : Cabs.expression) in
    let _2 = (Parsing.peek_val __caml_parser_env 0 : Cabs.cabsloc) in
    Obj.repr(
# 925 "src/frontc/cparser.mly"
                                 ( FC_EXP _1 )
# 4319 "src/frontc/cparser.ml"
               : 'for_clause))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : Cabs.definition) in
    Obj.repr(
# 926 "src/frontc/cparser.mly"
                                 ( FC_DECL _1 )
# 4326 "src/frontc/cparser.ml"
               : 'for_clause))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : spec_elem list * cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 1 : Cabs.init_name list) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : Cabs.cabsloc) in
    Obj.repr(
# 931 "src/frontc/cparser.mly"
                                       ( doDeclaration ((*handleLoc*)(snd _1)) (fst _1) _2 )
# 4335 "src/frontc/cparser.ml"
               : Cabs.definition))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 1 : spec_elem list * cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 0 : Cabs.cabsloc) in
    Obj.repr(
# 933 "src/frontc/cparser.mly"
                                       ( doDeclaration ((*handleLoc*)(snd _1)) (fst _1) [] )
# 4343 "src/frontc/cparser.ml"
               : Cabs.definition))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : Cabs.init_name) in
    Obj.repr(
# 936 "src/frontc/cparser.mly"
                                                 ( [_1] )
# 4350 "src/frontc/cparser.ml"
               : Cabs.init_name list))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : Cabs.init_name) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : Cabs.init_name list) in
    Obj.repr(
# 937 "src/frontc/cparser.mly"
                                                 ( _1 :: _3 )
# 4358 "src/frontc/cparser.ml"
               : Cabs.init_name list))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : Cabs.name) in
    Obj.repr(
# 941 "src/frontc/cparser.mly"
                                        ( (_1, NO_INIT) )
# 4365 "src/frontc/cparser.ml"
               : Cabs.init_name))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : Cabs.name) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : Cabs.init_expression) in
    Obj.repr(
# 943 "src/frontc/cparser.mly"
                                        ( (_1, _3) )
# 4373 "src/frontc/cparser.ml"
               : Cabs.init_name))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 1 : Cabs.cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 0 : 'decl_spec_list_opt) in
    Obj.repr(
# 948 "src/frontc/cparser.mly"
                                        ( SpecTypedef :: _2, _1  )
# 4381 "src/frontc/cparser.ml"
               : spec_elem list * cabsloc))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 1 : Cabs.cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 0 : 'decl_spec_list_opt) in
    Obj.repr(
# 949 "src/frontc/cparser.mly"
                                        ( SpecStorage EXTERN :: _2, _1 )
# 4389 "src/frontc/cparser.ml"
               : spec_elem list * cabsloc))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 1 : Cabs.cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 0 : 'decl_spec_list_opt) in
    Obj.repr(
# 950 "src/frontc/cparser.mly"
                                        ( SpecStorage STATIC :: _2, _1 )
# 4397 "src/frontc/cparser.ml"
               : spec_elem list * cabsloc))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 1 : Cabs.cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 0 : 'decl_spec_list_opt) in
    Obj.repr(
# 951 "src/frontc/cparser.mly"
                                        ( SpecStorage AUTO :: _2, _1 )
# 4405 "src/frontc/cparser.ml"
               : spec_elem list * cabsloc))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 1 : Cabs.cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 0 : 'decl_spec_list_opt) in
    Obj.repr(
# 952 "src/frontc/cparser.mly"
                                        ( SpecStorage REGISTER :: _2, _1)
# 4413 "src/frontc/cparser.ml"
               : spec_elem list * cabsloc))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 1 : typeSpecifier * cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 0 : 'decl_spec_list_opt_no_named) in
    Obj.repr(
# 954 "src/frontc/cparser.mly"
                                          ( SpecType (fst _1) :: _2, snd _1 )
# 4421 "src/frontc/cparser.ml"
               : spec_elem list * cabsloc))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 1 : Cabs.cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 0 : 'decl_spec_list_opt) in
    Obj.repr(
# 956 "src/frontc/cparser.mly"
                                        ( SpecInline :: _2, _1 )
# 4429 "src/frontc/cparser.ml"
               : spec_elem list * cabsloc))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 1 : Cabs.spec_elem * cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 0 : 'decl_spec_list_opt) in
    Obj.repr(
# 957 "src/frontc/cparser.mly"
                                        ( (fst _1) :: _2, snd _1 )
# 4437 "src/frontc/cparser.ml"
               : spec_elem list * cabsloc))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 1 : 'attribute_nocv) in
    let _2 = (Parsing.peek_val __caml_parser_env 0 : 'decl_spec_list_opt) in
    Obj.repr(
# 958 "src/frontc/cparser.mly"
                                        ( SpecAttr (fst _1) :: _2, snd _1 )
# 4445 "src/frontc/cparser.ml"
               : spec_elem list * cabsloc))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 3 : Cabs.cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 2 : Cabs.cabsloc) in
    let _3 = (Parsing.peek_val __caml_parser_env 1 : string * Cabs.cabsloc) in
    Obj.repr(
# 960 "src/frontc/cparser.mly"
                                        ( [ SpecPattern(fst _3) ], _1 )
# 4454 "src/frontc/cparser.ml"
               : spec_elem list * cabsloc))
; (fun __caml_parser_env ->
    Obj.repr(
# 965 "src/frontc/cparser.mly"
                                        ( [] )
# 4460 "src/frontc/cparser.ml"
               : 'decl_spec_list_opt))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : spec_elem list * cabsloc) in
    Obj.repr(
# 966 "src/frontc/cparser.mly"
                                        ( fst _1 )
# 4467 "src/frontc/cparser.ml"
               : 'decl_spec_list_opt))
; (fun __caml_parser_env ->
    Obj.repr(
# 973 "src/frontc/cparser.mly"
                                        ( [] )
# 4473 "src/frontc/cparser.ml"
               : 'decl_spec_list_opt_no_named))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : spec_elem list * cabsloc) in
    Obj.repr(
# 974 "src/frontc/cparser.mly"
                                        ( fst _1 )
# 4480 "src/frontc/cparser.ml"
               : 'decl_spec_list_opt_no_named))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : Cabs.cabsloc) in
    Obj.repr(
# 977 "src/frontc/cparser.mly"
                    ( Tvoid, _1)
# 4487 "src/frontc/cparser.ml"
               : typeSpecifier * cabsloc))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : Cabs.cabsloc) in
    Obj.repr(
# 978 "src/frontc/cparser.mly"
                    ( Tchar, _1 )
# 4494 "src/frontc/cparser.ml"
               : typeSpecifier * cabsloc))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : Cabs.cabsloc) in
    Obj.repr(
# 979 "src/frontc/cparser.mly"
                    ( Tbool, _1 )
# 4501 "src/frontc/cparser.ml"
               : typeSpecifier * cabsloc))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : Cabs.cabsloc) in
    Obj.repr(
# 980 "src/frontc/cparser.mly"
                    ( Tshort, _1 )
# 4508 "src/frontc/cparser.ml"
               : typeSpecifier * cabsloc))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : Cabs.cabsloc) in
    Obj.repr(
# 981 "src/frontc/cparser.mly"
                    ( Tint, _1 )
# 4515 "src/frontc/cparser.ml"
               : typeSpecifier * cabsloc))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : Cabs.cabsloc) in
    Obj.repr(
# 982 "src/frontc/cparser.mly"
                    ( Tlong, _1 )
# 4522 "src/frontc/cparser.ml"
               : typeSpecifier * cabsloc))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : Cabs.cabsloc) in
    Obj.repr(
# 983 "src/frontc/cparser.mly"
                    ( Tint64, _1 )
# 4529 "src/frontc/cparser.ml"
               : typeSpecifier * cabsloc))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : Cabs.cabsloc) in
    Obj.repr(
# 984 "src/frontc/cparser.mly"
                    ( Tfloat, _1 )
# 4536 "src/frontc/cparser.ml"
               : typeSpecifier * cabsloc))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : Cabs.cabsloc) in
    Obj.repr(
# 985 "src/frontc/cparser.mly"
                    ( Tdouble, _1 )
# 4543 "src/frontc/cparser.ml"
               : typeSpecifier * cabsloc))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : Cabs.cabsloc) in
    Obj.repr(
# 986 "src/frontc/cparser.mly"
                    ( Tsigned, _1 )
# 4550 "src/frontc/cparser.ml"
               : typeSpecifier * cabsloc))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : Cabs.cabsloc) in
    Obj.repr(
# 987 "src/frontc/cparser.mly"
                    ( Tunsigned, _1 )
# 4557 "src/frontc/cparser.ml"
               : typeSpecifier * cabsloc))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 1 : Cabs.cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 0 : 'id_or_typename) in
    Obj.repr(
# 989 "src/frontc/cparser.mly"
                                                   ( Tstruct (_2, None,    []), _1 )
# 4565 "src/frontc/cparser.ml"
               : typeSpecifier * cabsloc))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : Cabs.cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 1 : 'just_attributes) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : 'id_or_typename) in
    Obj.repr(
# 991 "src/frontc/cparser.mly"
                                                   ( Tstruct (_3, None,    _2), _1 )
# 4574 "src/frontc/cparser.ml"
               : typeSpecifier * cabsloc))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 4 : Cabs.cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 3 : 'id_or_typename) in
    let _3 = (Parsing.peek_val __caml_parser_env 2 : Cabs.cabsloc) in
    let _4 = (Parsing.peek_val __caml_parser_env 1 : Cabs.field_group list) in
    let _5 = (Parsing.peek_val __caml_parser_env 0 : Cabs.cabsloc) in
    Obj.repr(
# 993 "src/frontc/cparser.mly"
                                                   ( Tstruct (_2, Some _4, []), _1 )
# 4585 "src/frontc/cparser.ml"
               : typeSpecifier * cabsloc))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 3 : Cabs.cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 2 : Cabs.cabsloc) in
    let _3 = (Parsing.peek_val __caml_parser_env 1 : Cabs.field_group list) in
    let _4 = (Parsing.peek_val __caml_parser_env 0 : Cabs.cabsloc) in
    Obj.repr(
# 995 "src/frontc/cparser.mly"
                                                   ( Tstruct ("", Some _3, []), _1 )
# 4595 "src/frontc/cparser.ml"
               : typeSpecifier * cabsloc))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 5 : Cabs.cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 4 : 'just_attributes) in
    let _3 = (Parsing.peek_val __caml_parser_env 3 : 'id_or_typename) in
    let _4 = (Parsing.peek_val __caml_parser_env 2 : Cabs.cabsloc) in
    let _5 = (Parsing.peek_val __caml_parser_env 1 : Cabs.field_group list) in
    let _6 = (Parsing.peek_val __caml_parser_env 0 : Cabs.cabsloc) in
    Obj.repr(
# 997 "src/frontc/cparser.mly"
                                                   ( Tstruct (_3, Some _5, _2), _1 )
# 4607 "src/frontc/cparser.ml"
               : typeSpecifier * cabsloc))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 4 : Cabs.cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 3 : 'just_attributes) in
    let _3 = (Parsing.peek_val __caml_parser_env 2 : Cabs.cabsloc) in
    let _4 = (Parsing.peek_val __caml_parser_env 1 : Cabs.field_group list) in
    let _5 = (Parsing.peek_val __caml_parser_env 0 : Cabs.cabsloc) in
    Obj.repr(
# 999 "src/frontc/cparser.mly"
                                                   ( Tstruct ("", Some _4, _2), _1 )
# 4618 "src/frontc/cparser.ml"
               : typeSpecifier * cabsloc))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 1 : Cabs.cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 0 : 'id_or_typename) in
    Obj.repr(
# 1001 "src/frontc/cparser.mly"
                                                   ( Tunion  (_2, None,    []), _1 )
# 4626 "src/frontc/cparser.ml"
               : typeSpecifier * cabsloc))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 4 : Cabs.cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 3 : 'id_or_typename) in
    let _3 = (Parsing.peek_val __caml_parser_env 2 : Cabs.cabsloc) in
    let _4 = (Parsing.peek_val __caml_parser_env 1 : Cabs.field_group list) in
    let _5 = (Parsing.peek_val __caml_parser_env 0 : Cabs.cabsloc) in
    Obj.repr(
# 1003 "src/frontc/cparser.mly"
                                                   ( Tunion  (_2, Some _4, []), _1 )
# 4637 "src/frontc/cparser.ml"
               : typeSpecifier * cabsloc))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 3 : Cabs.cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 2 : Cabs.cabsloc) in
    let _3 = (Parsing.peek_val __caml_parser_env 1 : Cabs.field_group list) in
    let _4 = (Parsing.peek_val __caml_parser_env 0 : Cabs.cabsloc) in
    Obj.repr(
# 1005 "src/frontc/cparser.mly"
                                                   ( Tunion  ("", Some _3, []), _1 )
# 4647 "src/frontc/cparser.ml"
               : typeSpecifier * cabsloc))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 5 : Cabs.cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 4 : 'just_attributes) in
    let _3 = (Parsing.peek_val __caml_parser_env 3 : 'id_or_typename) in
    let _4 = (Parsing.peek_val __caml_parser_env 2 : Cabs.cabsloc) in
    let _5 = (Parsing.peek_val __caml_parser_env 1 : Cabs.field_group list) in
    let _6 = (Parsing.peek_val __caml_parser_env 0 : Cabs.cabsloc) in
    Obj.repr(
# 1007 "src/frontc/cparser.mly"
                                                   ( Tunion  (_3, Some _5, _2), _1 )
# 4659 "src/frontc/cparser.ml"
               : typeSpecifier * cabsloc))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 4 : Cabs.cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 3 : 'just_attributes) in
    let _3 = (Parsing.peek_val __caml_parser_env 2 : Cabs.cabsloc) in
    let _4 = (Parsing.peek_val __caml_parser_env 1 : Cabs.field_group list) in
    let _5 = (Parsing.peek_val __caml_parser_env 0 : Cabs.cabsloc) in
    Obj.repr(
# 1009 "src/frontc/cparser.mly"
                                                   ( Tunion  ("", Some _4, _2), _1 )
# 4670 "src/frontc/cparser.ml"
               : typeSpecifier * cabsloc))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 1 : Cabs.cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 0 : 'id_or_typename) in
    Obj.repr(
# 1011 "src/frontc/cparser.mly"
                                                   ( Tenum   (_2, None,    []), _1 )
# 4678 "src/frontc/cparser.ml"
               : typeSpecifier * cabsloc))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 5 : Cabs.cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 4 : 'id_or_typename) in
    let _3 = (Parsing.peek_val __caml_parser_env 3 : Cabs.cabsloc) in
    let _4 = (Parsing.peek_val __caml_parser_env 2 : Cabs.enum_item list) in
    let _5 = (Parsing.peek_val __caml_parser_env 1 : 'maybecomma) in
    let _6 = (Parsing.peek_val __caml_parser_env 0 : Cabs.cabsloc) in
    Obj.repr(
# 1013 "src/frontc/cparser.mly"
                                                   ( Tenum   (_2, Some _4, []), _1 )
# 4690 "src/frontc/cparser.ml"
               : typeSpecifier * cabsloc))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 4 : Cabs.cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 3 : Cabs.cabsloc) in
    let _3 = (Parsing.peek_val __caml_parser_env 2 : Cabs.enum_item list) in
    let _4 = (Parsing.peek_val __caml_parser_env 1 : 'maybecomma) in
    let _5 = (Parsing.peek_val __caml_parser_env 0 : Cabs.cabsloc) in
    Obj.repr(
# 1015 "src/frontc/cparser.mly"
                                                   ( Tenum   ("", Some _3, []), _1 )
# 4701 "src/frontc/cparser.ml"
               : typeSpecifier * cabsloc))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 6 : Cabs.cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 5 : 'just_attributes) in
    let _3 = (Parsing.peek_val __caml_parser_env 4 : 'id_or_typename) in
    let _4 = (Parsing.peek_val __caml_parser_env 3 : Cabs.cabsloc) in
    let _5 = (Parsing.peek_val __caml_parser_env 2 : Cabs.enum_item list) in
    let _6 = (Parsing.peek_val __caml_parser_env 1 : 'maybecomma) in
    let _7 = (Parsing.peek_val __caml_parser_env 0 : Cabs.cabsloc) in
    Obj.repr(
# 1017 "src/frontc/cparser.mly"
                                                   ( Tenum   (_3, Some _5, _2), _1 )
# 4714 "src/frontc/cparser.ml"
               : typeSpecifier * cabsloc))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 5 : Cabs.cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 4 : 'just_attributes) in
    let _3 = (Parsing.peek_val __caml_parser_env 3 : Cabs.cabsloc) in
    let _4 = (Parsing.peek_val __caml_parser_env 2 : Cabs.enum_item list) in
    let _5 = (Parsing.peek_val __caml_parser_env 1 : 'maybecomma) in
    let _6 = (Parsing.peek_val __caml_parser_env 0 : Cabs.cabsloc) in
    Obj.repr(
# 1019 "src/frontc/cparser.mly"
                                                   ( Tenum   ("", Some _4, _2), _1 )
# 4726 "src/frontc/cparser.ml"
               : typeSpecifier * cabsloc))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : string * Cabs.cabsloc) in
    Obj.repr(
# 1020 "src/frontc/cparser.mly"
                    ( Tnamed (fst _1), snd _1 )
# 4733 "src/frontc/cparser.ml"
               : typeSpecifier * cabsloc))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 3 : Cabs.cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 2 : Cabs.cabsloc) in
    let _3 = (Parsing.peek_val __caml_parser_env 1 : Cabs.expression * cabsloc) in
    Obj.repr(
# 1021 "src/frontc/cparser.mly"
                                        ( TtypeofE (fst _3), _1 )
# 4742 "src/frontc/cparser.ml"
               : typeSpecifier * cabsloc))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 3 : Cabs.cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 2 : Cabs.cabsloc) in
    let _3 = (Parsing.peek_val __caml_parser_env 1 : Cabs.spec_elem list * Cabs.decl_type) in
    Obj.repr(
# 1022 "src/frontc/cparser.mly"
                                        ( let s, d = _3 in
                                          TtypeofT (s, d), _1 )
# 4752 "src/frontc/cparser.ml"
               : typeSpecifier * cabsloc))
; (fun __caml_parser_env ->
    Obj.repr(
# 1028 "src/frontc/cparser.mly"
                                         ( [] )
# 4758 "src/frontc/cparser.ml"
               : Cabs.field_group list))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : spec_elem list * cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 1 : Cabs.cabsloc) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : Cabs.field_group list) in
    Obj.repr(
# 1030 "src/frontc/cparser.mly"
                                         ( (fst _1, 
                                            [(missingFieldDecl, None)]) :: _3 )
# 4768 "src/frontc/cparser.ml"
               : Cabs.field_group list))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 1 : Cabs.cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 0 : Cabs.field_group list) in
    Obj.repr(
# 1034 "src/frontc/cparser.mly"
                                         ( _2 )
# 4776 "src/frontc/cparser.ml"
               : Cabs.field_group list))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 3 : spec_elem list * cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 2 : (Cabs.name * expression option) list) in
    let _3 = (Parsing.peek_val __caml_parser_env 1 : Cabs.cabsloc) in
    let _4 = (Parsing.peek_val __caml_parser_env 0 : Cabs.field_group list) in
    Obj.repr(
# 1036 "src/frontc/cparser.mly"
                                          ( (fst _1, _2) 
                                            :: _4 )
# 4787 "src/frontc/cparser.ml"
               : Cabs.field_group list))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 1 : 'pragma) in
    let _2 = (Parsing.peek_val __caml_parser_env 0 : Cabs.field_group list) in
    Obj.repr(
# 1039 "src/frontc/cparser.mly"
                                          ( _2 )
# 4795 "src/frontc/cparser.ml"
               : Cabs.field_group list))
; (fun __caml_parser_env ->
    let _2 = (Parsing.peek_val __caml_parser_env 1 : Cabs.cabsloc) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : Cabs.field_group list) in
    Obj.repr(
# 1042 "src/frontc/cparser.mly"
                                          ( _3 )
# 4803 "src/frontc/cparser.ml"
               : Cabs.field_group list))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : Cabs.name * expression option) in
    Obj.repr(
# 1045 "src/frontc/cparser.mly"
                                         ( [_1] )
# 4810 "src/frontc/cparser.ml"
               : (Cabs.name * expression option) list))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : Cabs.name * expression option) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : (Cabs.name * expression option) list) in
    Obj.repr(
# 1046 "src/frontc/cparser.mly"
                                         ( _1 :: _3 )
# 4818 "src/frontc/cparser.ml"
               : (Cabs.name * expression option) list))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : Cabs.name) in
    Obj.repr(
# 1049 "src/frontc/cparser.mly"
                                    ( (_1, None) )
# 4825 "src/frontc/cparser.ml"
               : Cabs.name * expression option))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 3 : Cabs.name) in
    let _3 = (Parsing.peek_val __caml_parser_env 1 : Cabs.expression * cabsloc) in
    let _4 = (Parsing.peek_val __caml_parser_env 0 : Cabs.attribute list) in
    Obj.repr(
# 1051 "src/frontc/cparser.mly"
                                    ( let (n,decl,al,loc) = _1 in
                                      let al' = al @ _4 in
                                     ((n,decl,al',loc), Some (fst _3)) )
# 4836 "src/frontc/cparser.ml"
               : Cabs.name * expression option))
; (fun __caml_parser_env ->
    let _2 = (Parsing.peek_val __caml_parser_env 0 : Cabs.expression * cabsloc) in
    Obj.repr(
# 1054 "src/frontc/cparser.mly"
                                    ( (missingFieldDecl, Some (fst _2)) )
# 4843 "src/frontc/cparser.ml"
               : Cabs.name * expression option))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : Cabs.enum_item) in
    Obj.repr(
# 1058 "src/frontc/cparser.mly"
                  ([_1])
# 4850 "src/frontc/cparser.ml"
               : Cabs.enum_item list))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : Cabs.enum_item list) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : Cabs.enum_item) in
    Obj.repr(
# 1059 "src/frontc/cparser.mly"
                                       (_1 @ [_3])
# 4858 "src/frontc/cparser.ml"
               : Cabs.enum_item list))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : Cabs.enum_item list) in
    Obj.repr(
# 1060 "src/frontc/cparser.mly"
                                        ( _1 )
# 4865 "src/frontc/cparser.ml"
               : Cabs.enum_item list))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : string * Cabs.cabsloc) in
    Obj.repr(
# 1063 "src/frontc/cparser.mly"
            ((fst _1, NOTHING, snd _1))
# 4872 "src/frontc/cparser.ml"
               : Cabs.enum_item))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : string * Cabs.cabsloc) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : Cabs.expression * cabsloc) in
    Obj.repr(
# 1064 "src/frontc/cparser.mly"
                         ((fst _1, fst _3, snd _1))
# 4880 "src/frontc/cparser.ml"
               : Cabs.enum_item))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : attribute list list * cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 1 : string * Cabs.decl_type) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : Cabs.attribute list) in
    Obj.repr(
# 1070 "src/frontc/cparser.mly"
                               ( let (n, decl) = _2 in
                                (n, applyPointer (fst _1) decl, _3, (snd _1)) )
# 4890 "src/frontc/cparser.ml"
               : Cabs.name))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'id_or_typename) in
    Obj.repr(
# 1078 "src/frontc/cparser.mly"
                                   ( (_1, JUSTBASE) )
# 4897 "src/frontc/cparser.ml"
               : string * Cabs.decl_type))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 3 : Cabs.cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 2 : Cabs.attribute list) in
    let _3 = (Parsing.peek_val __caml_parser_env 1 : Cabs.name) in
    Obj.repr(
# 1081 "src/frontc/cparser.mly"
                                   ( let (n,decl,al,loc) = _3 in
                                     (n, PARENTYPE(_2,decl,al)) )
# 4907 "src/frontc/cparser.ml"
               : string * Cabs.decl_type))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 4 : string * Cabs.decl_type) in
    let _3 = (Parsing.peek_val __caml_parser_env 2 : Cabs.attribute list) in
    let _4 = (Parsing.peek_val __caml_parser_env 1 : 'comma_expression_opt) in
    Obj.repr(
# 1085 "src/frontc/cparser.mly"
                                   ( let (n, decl) = _1 in
                                     (n, ARRAY(decl, _3, _4)) )
# 4917 "src/frontc/cparser.ml"
               : string * Cabs.decl_type))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 4 : string * Cabs.decl_type) in
    let _3 = (Parsing.peek_val __caml_parser_env 2 : Cabs.attribute list) in
    Obj.repr(
# 1088 "src/frontc/cparser.mly"
                                   ( let (n, decl) = _1 in
                                     (n, ARRAY(decl, _3, NOTHING)) )
# 4926 "src/frontc/cparser.ml"
               : string * Cabs.decl_type))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 3 : string * Cabs.decl_type) in
    let _2 = (Parsing.peek_val __caml_parser_env 2 : 'parameter_list_startscope) in
    let _3 = (Parsing.peek_val __caml_parser_env 1 : 'rest_par_list) in
    Obj.repr(
# 1091 "src/frontc/cparser.mly"
                                   ( let (n, decl) = _1 in
                                     let (params, isva) = _3 in
                                     !Lexerhack.pop_context ();
                                     (n, PROTO(decl, params, isva))
                                   )
# 4939 "src/frontc/cparser.ml"
               : string * Cabs.decl_type))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : Cabs.cabsloc) in
    Obj.repr(
# 1098 "src/frontc/cparser.mly"
                                   ( !Lexerhack.push_context () )
# 4946 "src/frontc/cparser.ml"
               : 'parameter_list_startscope))
; (fun __caml_parser_env ->
    Obj.repr(
# 1101 "src/frontc/cparser.mly"
                                   ( ([], false) )
# 4952 "src/frontc/cparser.ml"
               : 'rest_par_list))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 1 : Cabs.single_name) in
    let _2 = (Parsing.peek_val __caml_parser_env 0 : 'rest_par_list1) in
    Obj.repr(
# 1102 "src/frontc/cparser.mly"
                                   ( let (params, isva) = _2 in 
                                     (_1 :: params, isva) 
                                   )
# 4962 "src/frontc/cparser.ml"
               : 'rest_par_list))
; (fun __caml_parser_env ->
    Obj.repr(
# 1107 "src/frontc/cparser.mly"
                                        ( ([], false) )
# 4968 "src/frontc/cparser.ml"
               : 'rest_par_list1))
; (fun __caml_parser_env ->
    Obj.repr(
# 1108 "src/frontc/cparser.mly"
                                        ( ([], true) )
# 4974 "src/frontc/cparser.ml"
               : 'rest_par_list1))
; (fun __caml_parser_env ->
    let _2 = (Parsing.peek_val __caml_parser_env 1 : Cabs.single_name) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : 'rest_par_list1) in
    Obj.repr(
# 1109 "src/frontc/cparser.mly"
                                        ( let (params, isva) = _3 in 
                                          (_2 :: params, isva)
                                        )
# 4984 "src/frontc/cparser.ml"
               : 'rest_par_list1))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 1 : spec_elem list * cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 0 : Cabs.name) in
    Obj.repr(
# 1116 "src/frontc/cparser.mly"
                                          ( (fst _1, _2) )
# 4992 "src/frontc/cparser.ml"
               : Cabs.single_name))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 1 : spec_elem list * cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 0 : Cabs.decl_type * Cabs.attribute list) in
    Obj.repr(
# 1117 "src/frontc/cparser.mly"
                                          ( let d, a = _2 in
                                            (fst _1, ("", d, a, cabslu)) )
# 5001 "src/frontc/cparser.ml"
               : Cabs.single_name))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : spec_elem list * cabsloc) in
    Obj.repr(
# 1119 "src/frontc/cparser.mly"
                                          ( (fst _1, ("", JUSTBASE, [], cabslu)) )
# 5008 "src/frontc/cparser.ml"
               : Cabs.single_name))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : Cabs.cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 1 : Cabs.single_name) in
    Obj.repr(
# 1120 "src/frontc/cparser.mly"
                                          ( _2 )
# 5016 "src/frontc/cparser.ml"
               : Cabs.single_name))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 1 : attribute list list * cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 0 : 'direct_old_proto_decl) in
    Obj.repr(
# 1125 "src/frontc/cparser.mly"
                                      ( let (n, decl, a) = _2 in
					  (n, applyPointer (fst _1) decl, 
                                           a, snd _1) 
                                      )
# 5027 "src/frontc/cparser.ml"
               : Cabs.name))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 4 : string * Cabs.decl_type) in
    let _2 = (Parsing.peek_val __caml_parser_env 3 : Cabs.cabsloc) in
    let _3 = (Parsing.peek_val __caml_parser_env 2 : string list) in
    let _5 = (Parsing.peek_val __caml_parser_env 0 : 'old_pardef_list) in
    Obj.repr(
# 1134 "src/frontc/cparser.mly"
                                   ( let par_decl, isva = doOldParDecl _3 _5 in
                                     let n, decl = _1 in
                                     (n, PROTO(decl, par_decl, isva), [])
                                   )
# 5040 "src/frontc/cparser.ml"
               : 'direct_old_proto_decl))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : string * Cabs.decl_type) in
    let _2 = (Parsing.peek_val __caml_parser_env 1 : Cabs.cabsloc) in
    Obj.repr(
# 1139 "src/frontc/cparser.mly"
                                   ( let n, decl = _1 in
                                     (n, PROTO(decl, [], false), [])
                                   )
# 5050 "src/frontc/cparser.ml"
               : 'direct_old_proto_decl))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : string * Cabs.cabsloc) in
    Obj.repr(
# 1154 "src/frontc/cparser.mly"
                                               ( [fst _1] )
# 5057 "src/frontc/cparser.ml"
               : string list))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : string * Cabs.cabsloc) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : string list) in
    Obj.repr(
# 1155 "src/frontc/cparser.mly"
                                               ( let rest = _3 in
                                                 (fst _1 :: rest) )
# 5066 "src/frontc/cparser.ml"
               : string list))
; (fun __caml_parser_env ->
    Obj.repr(
# 1160 "src/frontc/cparser.mly"
                                          ( ([], false) )
# 5072 "src/frontc/cparser.ml"
               : 'old_pardef_list))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 3 : spec_elem list * cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 2 : 'old_pardef) in
    let _3 = (Parsing.peek_val __caml_parser_env 1 : Cabs.cabsloc) in
    Obj.repr(
# 1162 "src/frontc/cparser.mly"
                                          ( ([(fst _1, _2)], true) )
# 5081 "src/frontc/cparser.ml"
               : 'old_pardef_list))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 3 : spec_elem list * cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 2 : 'old_pardef) in
    let _3 = (Parsing.peek_val __caml_parser_env 1 : Cabs.cabsloc) in
    let _4 = (Parsing.peek_val __caml_parser_env 0 : 'old_pardef_list) in
    Obj.repr(
# 1164 "src/frontc/cparser.mly"
                                          ( let rest, isva = _4 in
                                            ((fst _1, _2) :: rest, isva) 
                                          )
# 5093 "src/frontc/cparser.ml"
               : 'old_pardef_list))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : Cabs.name) in
    Obj.repr(
# 1170 "src/frontc/cparser.mly"
                                          ( [_1] )
# 5100 "src/frontc/cparser.ml"
               : 'old_pardef))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : Cabs.name) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : 'old_pardef) in
    Obj.repr(
# 1171 "src/frontc/cparser.mly"
                                          ( _1 :: _3 )
# 5108 "src/frontc/cparser.ml"
               : 'old_pardef))
; (fun __caml_parser_env ->
    Obj.repr(
# 1172 "src/frontc/cparser.mly"
                                          ( [] )
# 5114 "src/frontc/cparser.ml"
               : 'old_pardef))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : Cabs.cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 1 : Cabs.attribute list) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : attribute list list * cabsloc) in
    Obj.repr(
# 1177 "src/frontc/cparser.mly"
                                ( _2 :: fst _3, _1 )
# 5123 "src/frontc/cparser.ml"
               : attribute list list * cabsloc))
; (fun __caml_parser_env ->
    Obj.repr(
# 1180 "src/frontc/cparser.mly"
                                 ( let l = currentLoc () in
                                   ([], l) )
# 5130 "src/frontc/cparser.ml"
               : attribute list list * cabsloc))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : attribute list list * cabsloc) in
    Obj.repr(
# 1182 "src/frontc/cparser.mly"
                                 ( _1 )
# 5137 "src/frontc/cparser.ml"
               : attribute list list * cabsloc))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 1 : spec_elem list * cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 0 : Cabs.decl_type * Cabs.attribute list) in
    Obj.repr(
# 1186 "src/frontc/cparser.mly"
                               ( let d, a = _2 in
                                 if a <> [] then begin
                                   parse_error "attributes in type name";
                                   raise Parsing.Parse_error
                                 end;
                                 (fst _1, d) 
                               )
# 5151 "src/frontc/cparser.ml"
               : Cabs.spec_elem list * Cabs.decl_type))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : spec_elem list * cabsloc) in
    Obj.repr(
# 1193 "src/frontc/cparser.mly"
                               ( (fst _1, JUSTBASE) )
# 5158 "src/frontc/cparser.ml"
               : Cabs.spec_elem list * Cabs.decl_type))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : attribute list list * cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 1 : Cabs.decl_type) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : Cabs.attribute list) in
    Obj.repr(
# 1196 "src/frontc/cparser.mly"
                                          ( applyPointer (fst _1) _2, _3 )
# 5167 "src/frontc/cparser.ml"
               : Cabs.decl_type * Cabs.attribute list))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : attribute list list * cabsloc) in
    Obj.repr(
# 1197 "src/frontc/cparser.mly"
                                          ( applyPointer (fst _1) JUSTBASE, [] )
# 5174 "src/frontc/cparser.ml"
               : Cabs.decl_type * Cabs.attribute list))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 3 : Cabs.cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 2 : Cabs.attribute list) in
    let _3 = (Parsing.peek_val __caml_parser_env 1 : Cabs.decl_type * Cabs.attribute list) in
    Obj.repr(
# 1204 "src/frontc/cparser.mly"
                                   ( let d, a = _3 in
                                     PARENTYPE (_2, d, a)
                                   )
# 5185 "src/frontc/cparser.ml"
               : Cabs.decl_type))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : Cabs.cabsloc) in
    Obj.repr(
# 1209 "src/frontc/cparser.mly"
                                   ( JUSTBASE )
# 5192 "src/frontc/cparser.ml"
               : Cabs.decl_type))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 3 : Cabs.decl_type) in
    let _3 = (Parsing.peek_val __caml_parser_env 1 : 'comma_expression_opt) in
    Obj.repr(
# 1212 "src/frontc/cparser.mly"
                                   ( ARRAY(_1, [], _3) )
# 5200 "src/frontc/cparser.ml"
               : Cabs.decl_type))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 3 : Cabs.decl_type) in
    let _2 = (Parsing.peek_val __caml_parser_env 2 : 'parameter_list_startscope) in
    let _3 = (Parsing.peek_val __caml_parser_env 1 : 'rest_par_list) in
    Obj.repr(
# 1215 "src/frontc/cparser.mly"
                                   ( let (params, isva) = _3 in
                                     !Lexerhack.pop_context ();
                                     PROTO (_1, params, isva)
                                   )
# 5212 "src/frontc/cparser.ml"
               : Cabs.decl_type))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : Cabs.decl_type) in
    Obj.repr(
# 1221 "src/frontc/cparser.mly"
                                    ( _1 )
# 5219 "src/frontc/cparser.ml"
               : Cabs.decl_type))
; (fun __caml_parser_env ->
    Obj.repr(
# 1222 "src/frontc/cparser.mly"
                                    ( JUSTBASE )
# 5225 "src/frontc/cparser.ml"
               : Cabs.decl_type))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 1 : cabsloc * spec_elem list * name) in
    let _2 = (Parsing.peek_val __caml_parser_env 0 : Cabs.block * cabsloc * cabsloc) in
    Obj.repr(
# 1226 "src/frontc/cparser.mly"
          ( let (loc, specs, decl) = _1 in
            currentFunctionName := "<__FUNCTION__ used outside any functions>";
            !Lexerhack.pop_context (); (* The context pushed by 
                                    * announceFunctionName *)
            doFunctionDef ((*handleLoc*) loc) (trd3 _2) specs decl (fst3 _2)
          )
# 5238 "src/frontc/cparser.ml"
               : Cabs.definition))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 1 : spec_elem list * cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 0 : Cabs.name) in
    Obj.repr(
# 1236 "src/frontc/cparser.mly"
                            ( announceFunctionName _2;
                              (snd _1, fst _1, _2)
                            )
# 5248 "src/frontc/cparser.ml"
               : cabsloc * spec_elem list * name))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 1 : spec_elem list * cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 0 : Cabs.name) in
    Obj.repr(
# 1242 "src/frontc/cparser.mly"
                            ( announceFunctionName _2;
                              (snd _1, fst _1, _2)
                            )
# 5258 "src/frontc/cparser.ml"
               : cabsloc * spec_elem list * name))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 3 : string * Cabs.cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 2 : 'parameter_list_startscope) in
    let _3 = (Parsing.peek_val __caml_parser_env 1 : 'rest_par_list) in
    Obj.repr(
# 1247 "src/frontc/cparser.mly"
                           ( let (params, isva) = _3 in
                             let fdec = 
                               (fst _1, PROTO(JUSTBASE, params, isva), [], snd _1) in
                             announceFunctionName fdec;
                             (* Default is int type *)
                             let defSpec = [SpecType Tint] in
                             (snd _1, defSpec, fdec)
                           )
# 5274 "src/frontc/cparser.ml"
               : cabsloc * spec_elem list * name))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 4 : string * Cabs.cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 3 : Cabs.cabsloc) in
    let _3 = (Parsing.peek_val __caml_parser_env 2 : string list) in
    let _5 = (Parsing.peek_val __caml_parser_env 0 : 'old_pardef_list) in
    Obj.repr(
# 1258 "src/frontc/cparser.mly"
                           ( (* Convert pardecl to new style *)
                             let pardecl, isva = doOldParDecl _3 _5 in
                             (* Make the function declarator *)
                             let fdec = (fst _1,
                                         PROTO(JUSTBASE, pardecl,isva), 
                                         [], snd _1) in
                             announceFunctionName fdec;
                             (* Default is int type *)
                             let defSpec = [SpecType Tint] in
                             (snd _1, defSpec, fdec) 
                            )
# 5294 "src/frontc/cparser.ml"
               : cabsloc * spec_elem list * name))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : string * Cabs.cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 1 : Cabs.cabsloc) in
    Obj.repr(
# 1271 "src/frontc/cparser.mly"
                           ( (* Make the function declarator *)
                             let fdec = (fst _1,
                                         PROTO(JUSTBASE, [], false), 
                                         [], snd _1) in
                             announceFunctionName fdec;
                             (* Default is int type *)
                             let defSpec = [SpecType Tint] in
                             (snd _1, defSpec, fdec)
                            )
# 5310 "src/frontc/cparser.ml"
               : cabsloc * spec_elem list * name))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : Cabs.cabsloc) in
    Obj.repr(
# 1284 "src/frontc/cparser.mly"
                                        ( SpecCV(CV_CONST), _1 )
# 5317 "src/frontc/cparser.ml"
               : Cabs.spec_elem * cabsloc))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : Cabs.cabsloc) in
    Obj.repr(
# 1285 "src/frontc/cparser.mly"
                                        ( SpecCV(CV_UNIFORM), _1 )
# 5324 "src/frontc/cparser.ml"
               : Cabs.spec_elem * cabsloc))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : Cabs.cabsloc) in
    Obj.repr(
# 1286 "src/frontc/cparser.mly"
                                   ( SpecCV(CV_IN), _1 )
# 5331 "src/frontc/cparser.ml"
               : Cabs.spec_elem * cabsloc))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : Cabs.cabsloc) in
    Obj.repr(
# 1287 "src/frontc/cparser.mly"
                                    ( SpecCV(CV_OUT), _1 )
# 5338 "src/frontc/cparser.ml"
               : Cabs.spec_elem * cabsloc))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : Cabs.cabsloc) in
    Obj.repr(
# 1288 "src/frontc/cparser.mly"
                                        ( SpecCV(CV_VOLATILE), _1 )
# 5345 "src/frontc/cparser.ml"
               : Cabs.spec_elem * cabsloc))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : Cabs.cabsloc) in
    Obj.repr(
# 1289 "src/frontc/cparser.mly"
                                        ( SpecCV(CV_RESTRICT), _1 )
# 5352 "src/frontc/cparser.ml"
               : Cabs.spec_elem * cabsloc))
; (fun __caml_parser_env ->
    Obj.repr(
# 1294 "src/frontc/cparser.mly"
                   ( [])
# 5358 "src/frontc/cparser.ml"
               : Cabs.attribute list))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 1 : 'attribute) in
    let _2 = (Parsing.peek_val __caml_parser_env 0 : Cabs.attribute list) in
    Obj.repr(
# 1295 "src/frontc/cparser.mly"
                                 ( fst _1 :: _2 )
# 5366 "src/frontc/cparser.ml"
               : Cabs.attribute list))
; (fun __caml_parser_env ->
    Obj.repr(
# 1301 "src/frontc/cparser.mly"
                                        ( [] )
# 5372 "src/frontc/cparser.ml"
               : Cabs.attribute list))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 1 : 'attribute) in
    let _2 = (Parsing.peek_val __caml_parser_env 0 : Cabs.attribute list) in
    Obj.repr(
# 1302 "src/frontc/cparser.mly"
                                        ( fst _1 :: _2 )
# 5380 "src/frontc/cparser.ml"
               : Cabs.attribute list))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 4 : Cabs.cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 3 : Cabs.cabsloc) in
    let _3 = (Parsing.peek_val __caml_parser_env 2 : string * cabsloc) in
    let _5 = (Parsing.peek_val __caml_parser_env 0 : Cabs.attribute list) in
    Obj.repr(
# 1304 "src/frontc/cparser.mly"
                                        ( ("__asm__", 
					   [CONSTANT(CONST_STRING (fst _3))]) :: _5 )
# 5391 "src/frontc/cparser.ml"
               : Cabs.attribute list))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 3 : Cabs.cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 2 : Cabs.cabsloc) in
    let _3 = (Parsing.peek_val __caml_parser_env 1 : 'paren_attr_list) in
    Obj.repr(
# 1311 "src/frontc/cparser.mly"
                                        ( ("__attribute__", _3), _1 )
# 5400 "src/frontc/cparser.ml"
               : 'attribute_nocv))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 1 : Cabs.cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 0 : 'paren_attr_list_ne) in
    Obj.repr(
# 1316 "src/frontc/cparser.mly"
                                        ( ("__declspec", _2), _1 )
# 5408 "src/frontc/cparser.ml"
               : 'attribute_nocv))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : string * Cabs.cabsloc) in
    Obj.repr(
# 1317 "src/frontc/cparser.mly"
                                        ( (fst _1, []), snd _1 )
# 5415 "src/frontc/cparser.ml"
               : 'attribute_nocv))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : Cabs.cabsloc) in
    Obj.repr(
# 1319 "src/frontc/cparser.mly"
                                        ( ("__thread",[]), _1 )
# 5422 "src/frontc/cparser.ml"
               : 'attribute_nocv))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : string * Cabs.cabsloc) in
    Obj.repr(
# 1320 "src/frontc/cparser.mly"
                                  (("__attribute__",[VARIABLE(fst _1)]),snd _1)
# 5429 "src/frontc/cparser.ml"
               : 'attribute_nocv))
; (fun __caml_parser_env ->
    Obj.repr(
# 1324 "src/frontc/cparser.mly"
                   ( [])
# 5435 "src/frontc/cparser.ml"
               : 'attribute_nocv_list))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 1 : 'attribute_nocv) in
    let _2 = (Parsing.peek_val __caml_parser_env 0 : 'attribute_nocv_list) in
    Obj.repr(
# 1325 "src/frontc/cparser.mly"
                                        ( fst _1 :: _2 )
# 5443 "src/frontc/cparser.ml"
               : 'attribute_nocv_list))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'attribute_nocv) in
    Obj.repr(
# 1330 "src/frontc/cparser.mly"
                                        ( _1 )
# 5450 "src/frontc/cparser.ml"
               : 'attribute))
; (fun __caml_parser_env ->
    let _2 = (Parsing.peek_val __caml_parser_env 0 : string * Cabs.cabsloc) in
    Obj.repr(
# 1331 "src/frontc/cparser.mly"
                                        ( (":" ^ fst _2, []), (snd _2) (* CGCG *) )
# 5457 "src/frontc/cparser.ml"
               : 'attribute))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : Cabs.cabsloc) in
    Obj.repr(
# 1332 "src/frontc/cparser.mly"
                                        ( ("const", []), _1 )
# 5464 "src/frontc/cparser.ml"
               : 'attribute))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : Cabs.cabsloc) in
    Obj.repr(
# 1333 "src/frontc/cparser.mly"
                                        ( ("restrict",[]), _1 )
# 5471 "src/frontc/cparser.ml"
               : 'attribute))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : Cabs.cabsloc) in
    Obj.repr(
# 1334 "src/frontc/cparser.mly"
                                        ( ("volatile",[]), _1 )
# 5478 "src/frontc/cparser.ml"
               : 'attribute))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 3 : Cabs.cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 2 : Cabs.cabsloc) in
    let _3 = (Parsing.peek_val __caml_parser_env 1 : 'paren_attr_list) in
    Obj.repr(
# 1342 "src/frontc/cparser.mly"
                                        ( ("__attribute__", _3) )
# 5487 "src/frontc/cparser.ml"
               : 'just_attribute))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 1 : Cabs.cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 0 : 'paren_attr_list_ne) in
    Obj.repr(
# 1343 "src/frontc/cparser.mly"
                                        ( ("__declspec", _2) )
# 5495 "src/frontc/cparser.ml"
               : 'just_attribute))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'just_attribute) in
    Obj.repr(
# 1349 "src/frontc/cparser.mly"
                                        ( [_1] )
# 5502 "src/frontc/cparser.ml"
               : 'just_attributes))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 1 : 'just_attribute) in
    let _2 = (Parsing.peek_val __caml_parser_env 0 : 'just_attributes) in
    Obj.repr(
# 1350 "src/frontc/cparser.mly"
                                        ( _1 :: _2 )
# 5510 "src/frontc/cparser.ml"
               : 'just_attributes))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : Cabs.cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 1 : 'attr) in
    Obj.repr(
# 1355 "src/frontc/cparser.mly"
                          ( PRAGMA (_2, _1) )
# 5518 "src/frontc/cparser.ml"
               : 'pragma))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 3 : Cabs.cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 2 : 'attr) in
    let _3 = (Parsing.peek_val __caml_parser_env 1 : Cabs.cabsloc) in
    Obj.repr(
# 1356 "src/frontc/cparser.mly"
                                   ( PRAGMA (_2, _1) )
# 5527 "src/frontc/cparser.ml"
               : 'pragma))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : string * Cabs.cabsloc) in
    Obj.repr(
# 1357 "src/frontc/cparser.mly"
                                        ( PRAGMA (VARIABLE (fst _1), 
                                                  snd _1) )
# 5535 "src/frontc/cparser.ml"
               : 'pragma))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : string * Cabs.cabsloc) in
    Obj.repr(
# 1364 "src/frontc/cparser.mly"
             ( VARIABLE (fst _1) )
# 5542 "src/frontc/cparser.ml"
               : 'primary_attr))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : string * Cabs.cabsloc) in
    Obj.repr(
# 1366 "src/frontc/cparser.mly"
                  ( VARIABLE (fst _1) )
# 5549 "src/frontc/cparser.ml"
               : 'primary_attr))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : Cabs.cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 1 : 'attr) in
    Obj.repr(
# 1367 "src/frontc/cparser.mly"
                                        ( _2 )
# 5557 "src/frontc/cparser.ml"
               : 'primary_attr))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 1 : string * Cabs.cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 0 : string * Cabs.cabsloc) in
    Obj.repr(
# 1368 "src/frontc/cparser.mly"
                                         ( CALL(VARIABLE (fst _1), [VARIABLE (fst _2)]) )
# 5565 "src/frontc/cparser.ml"
               : 'primary_attr))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : string * Cabs.cabsloc) in
    Obj.repr(
# 1369 "src/frontc/cparser.mly"
                                         ( CONSTANT(CONST_INT (fst _1)) )
# 5572 "src/frontc/cparser.ml"
               : 'primary_attr))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : string * cabsloc) in
    Obj.repr(
# 1370 "src/frontc/cparser.mly"
                                         ( CONSTANT(CONST_STRING (fst _1)) )
# 5579 "src/frontc/cparser.ml"
               : 'primary_attr))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : Cabs.cabsloc) in
    Obj.repr(
# 1374 "src/frontc/cparser.mly"
                                         ( VARIABLE "aconst" )
# 5586 "src/frontc/cparser.ml"
               : 'primary_attr))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : string * Cabs.cabsloc) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : string * Cabs.cabsloc) in
    Obj.repr(
# 1376 "src/frontc/cparser.mly"
                                         ( VARIABLE (fst _1 ^ ":" ^ fst _3) )
# 5594 "src/frontc/cparser.ml"
               : 'primary_attr))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : string * Cabs.cabsloc) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : string * Cabs.cabsloc) in
    Obj.repr(
# 1380 "src/frontc/cparser.mly"
                                         ( VARIABLE (fst _1 ^ ":" ^ fst _3) )
# 5602 "src/frontc/cparser.ml"
               : 'primary_attr))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : Cabs.cabsloc) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : string * Cabs.cabsloc) in
    Obj.repr(
# 1382 "src/frontc/cparser.mly"
                                         ( VARIABLE ("default:" ^ fst _3) )
# 5610 "src/frontc/cparser.ml"
               : 'primary_attr))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : Cabs.cabsloc) in
    Obj.repr(
# 1387 "src/frontc/cparser.mly"
                                         ( VARIABLE ("__noreturn__") )
# 5617 "src/frontc/cparser.ml"
               : 'primary_attr))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'primary_attr) in
    Obj.repr(
# 1391 "src/frontc/cparser.mly"
                                         ( _1 )
# 5624 "src/frontc/cparser.ml"
               : 'postfix_attr))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : string * Cabs.cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 1 : Cabs.cabsloc) in
    Obj.repr(
# 1394 "src/frontc/cparser.mly"
                                     ( CALL(VARIABLE (fst _1), [VARIABLE ""]) )
# 5632 "src/frontc/cparser.ml"
               : 'postfix_attr))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 1 : string * Cabs.cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 0 : 'paren_attr_list_ne) in
    Obj.repr(
# 1395 "src/frontc/cparser.mly"
                                     ( CALL(VARIABLE (fst _1), _2) )
# 5640 "src/frontc/cparser.ml"
               : 'postfix_attr))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : 'postfix_attr) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : 'id_or_typename) in
    Obj.repr(
# 1397 "src/frontc/cparser.mly"
                                         (MEMBEROFPTR (_1, _3))
# 5648 "src/frontc/cparser.ml"
               : 'postfix_attr))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : 'postfix_attr) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : 'id_or_typename) in
    Obj.repr(
# 1398 "src/frontc/cparser.mly"
                                         (MEMBEROF (_1, _3))
# 5656 "src/frontc/cparser.ml"
               : 'postfix_attr))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 3 : 'postfix_attr) in
    let _3 = (Parsing.peek_val __caml_parser_env 1 : 'attr) in
    Obj.repr(
# 1399 "src/frontc/cparser.mly"
                                         (INDEX (_1, _3) )
# 5664 "src/frontc/cparser.ml"
               : 'postfix_attr))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'postfix_attr) in
    Obj.repr(
# 1406 "src/frontc/cparser.mly"
                                         ( _1 )
# 5671 "src/frontc/cparser.ml"
               : 'unary_attr))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 1 : Cabs.cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 0 : 'unary_expression) in
    Obj.repr(
# 1407 "src/frontc/cparser.mly"
                                         (EXPR_SIZEOF (fst _2) )
# 5679 "src/frontc/cparser.ml"
               : 'unary_attr))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 3 : Cabs.cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 2 : Cabs.cabsloc) in
    let _3 = (Parsing.peek_val __caml_parser_env 1 : Cabs.spec_elem list * Cabs.decl_type) in
    Obj.repr(
# 1409 "src/frontc/cparser.mly"
                           (let b, d = _3 in TYPE_SIZEOF (b, d))
# 5688 "src/frontc/cparser.ml"
               : 'unary_attr))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 1 : Cabs.cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 0 : 'unary_expression) in
    Obj.repr(
# 1411 "src/frontc/cparser.mly"
                                         (EXPR_ALIGNOF (fst _2) )
# 5696 "src/frontc/cparser.ml"
               : 'unary_attr))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 3 : Cabs.cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 2 : Cabs.cabsloc) in
    let _3 = (Parsing.peek_val __caml_parser_env 1 : Cabs.spec_elem list * Cabs.decl_type) in
    Obj.repr(
# 1412 "src/frontc/cparser.mly"
                                         (let b, d = _3 in TYPE_ALIGNOF (b, d))
# 5705 "src/frontc/cparser.ml"
               : 'unary_attr))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 1 : Cabs.cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 0 : 'cast_attr) in
    Obj.repr(
# 1413 "src/frontc/cparser.mly"
                                        (UNARY (PLUS, _2))
# 5713 "src/frontc/cparser.ml"
               : 'unary_attr))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 1 : Cabs.cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 0 : 'cast_attr) in
    Obj.repr(
# 1414 "src/frontc/cparser.mly"
                                        (UNARY (MINUS, _2))
# 5721 "src/frontc/cparser.ml"
               : 'unary_attr))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 1 : Cabs.cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 0 : 'cast_attr) in
    Obj.repr(
# 1415 "src/frontc/cparser.mly"
                            (UNARY (MEMOF, _2))
# 5729 "src/frontc/cparser.ml"
               : 'unary_attr))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 1 : Cabs.cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 0 : 'cast_attr) in
    Obj.repr(
# 1417 "src/frontc/cparser.mly"
                                 (UNARY (ADDROF, _2))
# 5737 "src/frontc/cparser.ml"
               : 'unary_attr))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 1 : Cabs.cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 0 : 'cast_attr) in
    Obj.repr(
# 1418 "src/frontc/cparser.mly"
                                 (UNARY (NOT, _2))
# 5745 "src/frontc/cparser.ml"
               : 'unary_attr))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 1 : Cabs.cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 0 : 'cast_attr) in
    Obj.repr(
# 1419 "src/frontc/cparser.mly"
                                        (UNARY (BNOT, _2))
# 5753 "src/frontc/cparser.ml"
               : 'unary_attr))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'unary_attr) in
    Obj.repr(
# 1423 "src/frontc/cparser.mly"
                                         ( _1 )
# 5760 "src/frontc/cparser.ml"
               : 'cast_attr))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'cast_attr) in
    Obj.repr(
# 1427 "src/frontc/cparser.mly"
                                        ( _1 )
# 5767 "src/frontc/cparser.ml"
               : 'multiplicative_attr))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : 'multiplicative_attr) in
    let _2 = (Parsing.peek_val __caml_parser_env 1 : Cabs.cabsloc) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : 'cast_attr) in
    Obj.repr(
# 1428 "src/frontc/cparser.mly"
                                        (BINARY(MUL ,_1 , _3))
# 5776 "src/frontc/cparser.ml"
               : 'multiplicative_attr))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : 'multiplicative_attr) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : 'cast_attr) in
    Obj.repr(
# 1429 "src/frontc/cparser.mly"
                                          (BINARY(DIV ,_1 , _3))
# 5784 "src/frontc/cparser.ml"
               : 'multiplicative_attr))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : 'multiplicative_attr) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : 'cast_attr) in
    Obj.repr(
# 1430 "src/frontc/cparser.mly"
                                          (BINARY(MOD ,_1 , _3))
# 5792 "src/frontc/cparser.ml"
               : 'multiplicative_attr))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'multiplicative_attr) in
    Obj.repr(
# 1435 "src/frontc/cparser.mly"
                                        ( _1 )
# 5799 "src/frontc/cparser.ml"
               : 'additive_attr))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : 'additive_attr) in
    let _2 = (Parsing.peek_val __caml_parser_env 1 : Cabs.cabsloc) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : 'multiplicative_attr) in
    Obj.repr(
# 1436 "src/frontc/cparser.mly"
                                            (BINARY(ADD ,_1 , _3))
# 5808 "src/frontc/cparser.ml"
               : 'additive_attr))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : 'additive_attr) in
    let _2 = (Parsing.peek_val __caml_parser_env 1 : Cabs.cabsloc) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : 'multiplicative_attr) in
    Obj.repr(
# 1437 "src/frontc/cparser.mly"
                                            (BINARY(SUB ,_1 , _3))
# 5817 "src/frontc/cparser.ml"
               : 'additive_attr))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'additive_attr) in
    Obj.repr(
# 1441 "src/frontc/cparser.mly"
                                        ( _1 )
# 5824 "src/frontc/cparser.ml"
               : 'shift_attr))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : 'shift_attr) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : 'additive_attr) in
    Obj.repr(
# 1442 "src/frontc/cparser.mly"
                                     (BINARY(SHL ,_1 , _3))
# 5832 "src/frontc/cparser.ml"
               : 'shift_attr))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : 'shift_attr) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : 'additive_attr) in
    Obj.repr(
# 1443 "src/frontc/cparser.mly"
                                     (BINARY(SHR ,_1 , _3))
# 5840 "src/frontc/cparser.ml"
               : 'shift_attr))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'shift_attr) in
    Obj.repr(
# 1447 "src/frontc/cparser.mly"
                                        ( _1 )
# 5847 "src/frontc/cparser.ml"
               : 'relational_attr))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : 'relational_attr) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : 'shift_attr) in
    Obj.repr(
# 1448 "src/frontc/cparser.mly"
                                   (BINARY(LT ,_1 , _3))
# 5855 "src/frontc/cparser.ml"
               : 'relational_attr))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : 'relational_attr) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : 'shift_attr) in
    Obj.repr(
# 1449 "src/frontc/cparser.mly"
                                   (BINARY(GT ,_1 , _3))
# 5863 "src/frontc/cparser.ml"
               : 'relational_attr))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : 'relational_attr) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : 'shift_attr) in
    Obj.repr(
# 1450 "src/frontc/cparser.mly"
                                      (BINARY(LE ,_1 , _3))
# 5871 "src/frontc/cparser.ml"
               : 'relational_attr))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : 'relational_attr) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : 'shift_attr) in
    Obj.repr(
# 1451 "src/frontc/cparser.mly"
                                      (BINARY(GE ,_1 , _3))
# 5879 "src/frontc/cparser.ml"
               : 'relational_attr))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'relational_attr) in
    Obj.repr(
# 1455 "src/frontc/cparser.mly"
                                        ( _1 )
# 5886 "src/frontc/cparser.ml"
               : 'equality_attr))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : 'equality_attr) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : 'relational_attr) in
    Obj.repr(
# 1456 "src/frontc/cparser.mly"
                                            (BINARY(EQ ,_1 , _3))
# 5894 "src/frontc/cparser.ml"
               : 'equality_attr))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : 'equality_attr) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : 'relational_attr) in
    Obj.repr(
# 1457 "src/frontc/cparser.mly"
                                            (BINARY(NE ,_1 , _3))
# 5902 "src/frontc/cparser.ml"
               : 'equality_attr))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'equality_attr) in
    Obj.repr(
# 1462 "src/frontc/cparser.mly"
                                        ( _1 )
# 5909 "src/frontc/cparser.ml"
               : 'bitwise_and_attr))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : 'bitwise_and_attr) in
    let _2 = (Parsing.peek_val __caml_parser_env 1 : Cabs.cabsloc) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : 'equality_attr) in
    Obj.repr(
# 1463 "src/frontc/cparser.mly"
                                       (BINARY(BAND ,_1 , _3))
# 5918 "src/frontc/cparser.ml"
               : 'bitwise_and_attr))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'bitwise_and_attr) in
    Obj.repr(
# 1467 "src/frontc/cparser.mly"
                                           ( _1 )
# 5925 "src/frontc/cparser.ml"
               : 'bitwise_xor_attr))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : 'bitwise_xor_attr) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : 'bitwise_and_attr) in
    Obj.repr(
# 1468 "src/frontc/cparser.mly"
                                           (BINARY(XOR ,_1 , _3))
# 5933 "src/frontc/cparser.ml"
               : 'bitwise_xor_attr))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'bitwise_xor_attr) in
    Obj.repr(
# 1472 "src/frontc/cparser.mly"
                                          ( _1 )
# 5940 "src/frontc/cparser.ml"
               : 'bitwise_or_attr))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : 'bitwise_or_attr) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : 'bitwise_xor_attr) in
    Obj.repr(
# 1473 "src/frontc/cparser.mly"
                                          (BINARY(BOR ,_1 , _3))
# 5948 "src/frontc/cparser.ml"
               : 'bitwise_or_attr))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'bitwise_or_attr) in
    Obj.repr(
# 1477 "src/frontc/cparser.mly"
                                                ( _1 )
# 5955 "src/frontc/cparser.ml"
               : 'logical_and_attr))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : 'logical_and_attr) in
    let _2 = (Parsing.peek_val __caml_parser_env 1 : Cabs.cabsloc) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : 'bitwise_or_attr) in
    Obj.repr(
# 1478 "src/frontc/cparser.mly"
                                             (BINARY(AND ,_1 , _3))
# 5964 "src/frontc/cparser.ml"
               : 'logical_and_attr))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'logical_and_attr) in
    Obj.repr(
# 1482 "src/frontc/cparser.mly"
                                               ( _1 )
# 5971 "src/frontc/cparser.ml"
               : 'logical_or_attr))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : 'logical_or_attr) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : 'logical_and_attr) in
    Obj.repr(
# 1483 "src/frontc/cparser.mly"
                                               (BINARY(OR ,_1 , _3))
# 5979 "src/frontc/cparser.ml"
               : 'logical_or_attr))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'logical_or_attr) in
    Obj.repr(
# 1487 "src/frontc/cparser.mly"
                                           ( _1 )
# 5986 "src/frontc/cparser.ml"
               : 'conditional_attr))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 4 : 'logical_or_attr) in
    let _3 = (Parsing.peek_val __caml_parser_env 2 : 'conditional_attr) in
    let _5 = (Parsing.peek_val __caml_parser_env 0 : 'conditional_attr) in
    Obj.repr(
# 1490 "src/frontc/cparser.mly"
                                          ( QUESTION(_1, _3, _5) )
# 5995 "src/frontc/cparser.ml"
               : 'conditional_attr))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'conditional_attr) in
    Obj.repr(
# 1493 "src/frontc/cparser.mly"
                                          ( _1 )
# 6002 "src/frontc/cparser.ml"
               : 'attr))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'attr) in
    Obj.repr(
# 1497 "src/frontc/cparser.mly"
                                         ( [_1] )
# 6009 "src/frontc/cparser.ml"
               : 'attr_list_ne))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : 'attr) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : 'attr_list_ne) in
    Obj.repr(
# 1498 "src/frontc/cparser.mly"
                                         ( _1 :: _3 )
# 6017 "src/frontc/cparser.ml"
               : 'attr_list_ne))
; (fun __caml_parser_env ->
    let _3 = (Parsing.peek_val __caml_parser_env 0 : 'attr_list_ne) in
    Obj.repr(
# 1499 "src/frontc/cparser.mly"
                                         ( _3 )
# 6024 "src/frontc/cparser.ml"
               : 'attr_list_ne))
; (fun __caml_parser_env ->
    Obj.repr(
# 1502 "src/frontc/cparser.mly"
                                         ( [] )
# 6030 "src/frontc/cparser.ml"
               : 'attr_list))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'attr_list_ne) in
    Obj.repr(
# 1503 "src/frontc/cparser.mly"
                                         ( _1 )
# 6037 "src/frontc/cparser.ml"
               : 'attr_list))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : Cabs.cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 1 : 'attr_list_ne) in
    Obj.repr(
# 1506 "src/frontc/cparser.mly"
                                         ( _2 )
# 6045 "src/frontc/cparser.ml"
               : 'paren_attr_list_ne))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : Cabs.cabsloc) in
    Obj.repr(
# 1507 "src/frontc/cparser.mly"
                                         ( [] )
# 6052 "src/frontc/cparser.ml"
               : 'paren_attr_list_ne))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : Cabs.cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 1 : 'attr_list) in
    Obj.repr(
# 1510 "src/frontc/cparser.mly"
                                         ( _2 )
# 6060 "src/frontc/cparser.ml"
               : 'paren_attr_list))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : Cabs.cabsloc) in
    Obj.repr(
# 1511 "src/frontc/cparser.mly"
                                         ( [] )
# 6067 "src/frontc/cparser.ml"
               : 'paren_attr_list))
; (fun __caml_parser_env ->
    Obj.repr(
# 1515 "src/frontc/cparser.mly"
                                        ( [] )
# 6073 "src/frontc/cparser.ml"
               : Cabs.attribute list))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 1 : Cabs.cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 0 : Cabs.attribute list) in
    Obj.repr(
# 1516 "src/frontc/cparser.mly"
                                        ( ("volatile", []) :: _2 )
# 6081 "src/frontc/cparser.ml"
               : Cabs.attribute list))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 1 : Cabs.cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 0 : Cabs.attribute list) in
    Obj.repr(
# 1517 "src/frontc/cparser.mly"
                                        ( ("const", []) :: _2 )
# 6089 "src/frontc/cparser.ml"
               : Cabs.attribute list))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'one_string_constant) in
    Obj.repr(
# 1520 "src/frontc/cparser.mly"
                                                 ( [_1] )
# 6096 "src/frontc/cparser.ml"
               : 'asmtemplate))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 1 : 'one_string_constant) in
    let _2 = (Parsing.peek_val __caml_parser_env 0 : 'asmtemplate) in
    Obj.repr(
# 1521 "src/frontc/cparser.mly"
                                                 ( _1 :: _2 )
# 6104 "src/frontc/cparser.ml"
               : 'asmtemplate))
; (fun __caml_parser_env ->
    Obj.repr(
# 1524 "src/frontc/cparser.mly"
                        ( None )
# 6110 "src/frontc/cparser.ml"
               : 'asmoutputs))
; (fun __caml_parser_env ->
    let _2 = (Parsing.peek_val __caml_parser_env 1 : 'asmoperands) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : 'asminputs) in
    Obj.repr(
# 1526 "src/frontc/cparser.mly"
                        ( let (ins, clobs) = _3 in
                          Some {aoutputs = _2; ainputs = ins; aclobbers = clobs} )
# 6119 "src/frontc/cparser.ml"
               : 'asmoutputs))
; (fun __caml_parser_env ->
    Obj.repr(
# 1530 "src/frontc/cparser.mly"
                                        ( [] )
# 6125 "src/frontc/cparser.ml"
               : 'asmoperands))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'asmoperandsne) in
    Obj.repr(
# 1531 "src/frontc/cparser.mly"
                                        ( List.rev _1 )
# 6132 "src/frontc/cparser.ml"
               : 'asmoperands))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'asmoperand) in
    Obj.repr(
# 1534 "src/frontc/cparser.mly"
                                        ( [_1] )
# 6139 "src/frontc/cparser.ml"
               : 'asmoperandsne))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : 'asmoperandsne) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : 'asmoperand) in
    Obj.repr(
# 1535 "src/frontc/cparser.mly"
                                        ( _3 :: _1 )
# 6147 "src/frontc/cparser.ml"
               : 'asmoperandsne))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 4 : 'asmopname) in
    let _2 = (Parsing.peek_val __caml_parser_env 3 : string * cabsloc) in
    let _3 = (Parsing.peek_val __caml_parser_env 2 : Cabs.cabsloc) in
    let _4 = (Parsing.peek_val __caml_parser_env 1 : Cabs.expression * cabsloc) in
    Obj.repr(
# 1538 "src/frontc/cparser.mly"
                                                           ( (_1, fst _2, fst _4) )
# 6157 "src/frontc/cparser.ml"
               : 'asmoperand))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 4 : 'asmopname) in
    let _2 = (Parsing.peek_val __caml_parser_env 3 : string * cabsloc) in
    let _3 = (Parsing.peek_val __caml_parser_env 2 : Cabs.cabsloc) in
    Obj.repr(
# 1539 "src/frontc/cparser.mly"
                                                           ( (_1, fst _2, NOTHING ) )
# 6166 "src/frontc/cparser.ml"
               : 'asmoperand))
; (fun __caml_parser_env ->
    Obj.repr(
# 1542 "src/frontc/cparser.mly"
                             ( ([], []) )
# 6172 "src/frontc/cparser.ml"
               : 'asminputs))
; (fun __caml_parser_env ->
    let _2 = (Parsing.peek_val __caml_parser_env 1 : 'asmoperands) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : 'asmclobber) in
    Obj.repr(
# 1544 "src/frontc/cparser.mly"
                        ( (_2, _3) )
# 6180 "src/frontc/cparser.ml"
               : 'asminputs))
; (fun __caml_parser_env ->
    Obj.repr(
# 1547 "src/frontc/cparser.mly"
                                        ( None )
# 6186 "src/frontc/cparser.ml"
               : 'asmopname))
; (fun __caml_parser_env ->
    let _2 = (Parsing.peek_val __caml_parser_env 1 : string * Cabs.cabsloc) in
    Obj.repr(
# 1548 "src/frontc/cparser.mly"
                                        ( Some (fst _2) )
# 6193 "src/frontc/cparser.ml"
               : 'asmopname))
; (fun __caml_parser_env ->
    Obj.repr(
# 1552 "src/frontc/cparser.mly"
                                        ( [] )
# 6199 "src/frontc/cparser.ml"
               : 'asmclobber))
; (fun __caml_parser_env ->
    let _2 = (Parsing.peek_val __caml_parser_env 0 : 'asmcloberlst_ne) in
    Obj.repr(
# 1553 "src/frontc/cparser.mly"
                                        ( _2 )
# 6206 "src/frontc/cparser.ml"
               : 'asmclobber))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'one_string_constant) in
    Obj.repr(
# 1556 "src/frontc/cparser.mly"
                                                 ( [_1] )
# 6213 "src/frontc/cparser.ml"
               : 'asmcloberlst_ne))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : 'one_string_constant) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : 'asmcloberlst_ne) in
    Obj.repr(
# 1557 "src/frontc/cparser.mly"
                                                 ( _1 :: _3 )
# 6221 "src/frontc/cparser.ml"
               : 'asmcloberlst_ne))
(* Entry interpret *)
; (fun __caml_parser_env -> raise (Parsing.YYexit (Parsing.peek_val __caml_parser_env 0)))
(* Entry file *)
; (fun __caml_parser_env -> raise (Parsing.YYexit (Parsing.peek_val __caml_parser_env 0)))
|]
let yytables =
  { Parsing.actions=yyact;
    Parsing.transl_const=yytransl_const;
    Parsing.transl_block=yytransl_block;
    Parsing.lhs=yylhs;
    Parsing.len=yylen;
    Parsing.defred=yydefred;
    Parsing.dgoto=yydgoto;
    Parsing.sindex=yysindex;
    Parsing.rindex=yyrindex;
    Parsing.gindex=yygindex;
    Parsing.tablesize=yytablesize;
    Parsing.table=yytable;
    Parsing.check=yycheck;
    Parsing.error_function=parse_error;
    Parsing.names_const=yynames_const;
    Parsing.names_block=yynames_block }
let interpret (lexfun : Lexing.lexbuf -> token) (lexbuf : Lexing.lexbuf) =
   (Parsing.yyparse yytables 1 lexfun lexbuf : Cabs.definition list)
let file (lexfun : Lexing.lexbuf -> token) (lexbuf : Lexing.lexbuf) =
   (Parsing.yyparse yytables 2 lexfun lexbuf : Cabs.definition list)
;;
# 1561 "src/frontc/cparser.mly"



# 6254 "src/frontc/cparser.ml"
